@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/ao_doc_objects.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/ao_doc_objects.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -472,19 +469,21 @@ module SiSU_AO_DocumentStructure
     end
   end
   class ObjectFlag
-    attr_accessor :obj,:is,:of,:flag,:mod,:tmp
+    attr_accessor :obj,:is,:of,:flag,:act,:selections,:tmp
     def initialize
       @of=:flag
-      @is=@obj=@flag=@mod=@tmp=nil
+      @is=@obj=@flag=@act=@selections=@tmp=nil
     end
     def flag(h,o=nil)
       of=     @of                                                              #Symbol, classification - group
       is=     :flag                                                            #Symbol, classification - specific type
       obj=    nil                                                              #String, text content
       flag=   h[:flag]     || ((defined? o.flag)      ? o.flag    : nil)       #String, text content
-      mod=    h[:mod]      || ((defined? o.mod)       ? o.mod     : nil)       #String, text content
+      act=    h[:act]      || ((defined? o.act)       ? o.act     : nil)       #String, text content
+      selections=    h[:selections]      || ((defined? o.selections) ? o.selections : nil)   #String, text content
       tmp=    h[:flag]     || ((defined? o.tmp)       ? o.tmp     : nil)       #available for processing, empty after use
-      @of,@is,@obj,@flag,@mod,@tmp=of,is,obj,flag,mod,tmp
+      @of, @is,@obj,@flag,@act,@selections,@tmp=
+        of,is, obj, flag, act, selections, tmp
       self
     end
     def flag_ocn(h,o=nil)
@@ -492,9 +491,11 @@ module SiSU_AO_DocumentStructure
       is=     :flag_ocn                                                        #Symbol, classification - specific type
       obj=    nil                                                              #String, text content
       flag=   h[:flag]     || ((defined? o.flag)      ? o.flag    : nil)       #String, text content
-      mod=    h[:mod]      || ((defined? o.mod)       ? o.mod     : nil)       #String, text content
+      act=    h[:act]      || ((defined? o.act)       ? o.act     : nil)       #String, text content
+      selections= h[:selections] || ((defined? o.selections) ? o.selections : nil)   #String, text content
       tmp=    h[:flag]     || ((defined? o.tmp)       ? o.tmp     : nil)       #available for processing, empty after use
-      @of,@is,@obj,@flag,@mod,@tmp=of,is,obj,flag,mod,tmp
+      @of, @is,@obj,@flag,@act,@selections,@tmp=
+        of,is, obj, flag, act, selections,tmp
       self
     end
   end
