@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/ao_expand_insertions.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/ao_expand_insertions.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -66,63 +63,76 @@ module SiSU_AO_Insertions
       @md,@data=md,data
     end
     def output_filetypes_in_cmd(cmd_shortcut,lnk=nil) #make list of file types in shortcut command (as configured), e.g. when sisu -3 is used
-      cf_defaults=SiSU_Env::InfoProcessingFlag.new
-      cmd_list=case cmd_shortcut.inspect
-      when /0/ then cf_defaults.cf_0
-      when /1/ then cf_defaults.cf_1
-      when /2/ then cf_defaults.cf_2
-      when /3/ then cf_defaults.cf_3
-      when /4/ then cf_defaults.cf_4
-      when /5/ then cf_defaults.cf_5
+      act_defaults=SiSU_Env::InfoProcessingFlag.new
+      cmd_list=case cmd_shortcut.inspect #check on expectation, string v array
+      when /0/ then act_defaults.act_0.str
+      when /1/ then act_defaults.act_1.str
+      when /2/ then act_defaults.act_2.str
+      when /3/ then act_defaults.act_3.str
+      when /4/ then act_defaults.act_4.str
+      when /5/ then act_defaults.act_5.str
+      when /6/ then act_defaults.act_6.str
+      when /7/ then act_defaults.act_7.str
+      when /8/ then act_defaults.act_8.str
+      when /9/ then act_defaults.act_9.str
       end
       file_type_names={}
       file_type_names[:gen],file_type_names[:src]=[],[]
-      file_type_names[:gen] <<= if cmd_list =~ /y/
+      file_type_names[:gen] <<= if cmd_list =~ /\b--manifest\b/
         "~^ { document manifest }#{lnk[:manifest]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /h/
+      file_type_names[:gen] <<= if cmd_list =~ /\b--html\b/
         [
           " { html, segmented text }#{lnk[:html_toc]}",
           " { html, scroll, document in one }#{lnk[:html_doc]}",
         ]
       end
-      file_type_names[:gen] <<= if cmd_list =~ /e/
+      file_type_names[:gen] <<= if cmd_list =~ /\b--epub\b/
         [" { epub }#{lnk[:epub]}"]
       end
-      file_type_names[:gen] <<= if cmd_list =~ /p/
+      file_type_names[:gen] <<= if cmd_list =~ /\b--pdf\b/ \
+      or cmd_list =~ /--pdf-landscape/
         [
           " { pdf, landscape }#{lnk[:pdf_landscape]}",
+        ]
+      end
+      file_type_names[:gen] <<= if cmd_list =~ /\b--pdf\b/ \
+      or cmd_list =~ /--pdf-portrait/
+        [
           " { pdf, portrait }#{lnk[:pdf_portrait]}",
         ]
       end
-      file_type_names[:gen] <<= if cmd_list =~ /o/
+      file_type_names[:gen] <<= if cmd_list =~ /\b(?:--odt|--odf)\b/
         " { odf:odt, open document text }#{lnk[:odt]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /b/
+      file_type_names[:gen] <<= if cmd_list =~ /\b--xhtml\b/
         " { xhtml scroll }#{lnk[:xhtml]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /x/
+      file_type_names[:gen] <<= if cmd_list =~ /\b--docbook\b/
+        " { docbook }#{lnk[:docbook]}" #CHECK
+      end
+      file_type_names[:gen] <<= if cmd_list =~ /\b--xml-sax\b/
         " { xml, sax }#{lnk[:xml_sax]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /X/
+      file_type_names[:gen] <<= if cmd_list =~ /\b--xml-dom\b/
         " { xml, dom }#{lnk[:xml_dom]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /a/
+      file_type_names[:gen] <<= if cmd_list =~ /\b(?:--txt|--text|--plaintext)\b/
         " { plain text utf-8 }#{lnk[:txt]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /g/
-        'wiki.txt'
-      end
-      file_type_names[:gen] <<= if cmd_list =~ /w/
+      #file_type_names[:gen] <<= if cmd_list =~ /g/
+      #  'wiki.txt'
+      #end
+      file_type_names[:gen] <<= if cmd_list =~ /\b--concordance\b/
         " { concordance }#{lnk[:html_concordance]}"
       end
-      file_type_names[:gen] <<= if cmd_list =~ /N/
+      file_type_names[:gen] <<= if cmd_list =~ /\b--digest\b/
         " { dcc, document content certificate (digests) }#{lnk[:digest]}"
       end
-      file_type_names[:src] <<= if source and cmd_shortcut =~ /s/
+      file_type_names[:src] <<= if source and cmd_shortcut =~ /\b--source\b/
         " { markup source text }#{lnk[:source]}"
       end
-      file_type_names[:src] <<= if cmd_shortcut =~ /S/
+      file_type_names[:src] <<= if cmd_shortcut =~ /\b--sisupod\b/
         " { markup source (zipped) pod }#{lnk[:sisupod]}"
       end
       file_type_names[:gen]=file_type_names[:gen].flatten
@@ -138,7 +148,7 @@ module SiSU_AO_Insertions
         }
       end
       def path_and_file(fn,pth)
-        "#{@base_path}/#{pth}/#{fn}"
+        @base_path + '/' + pth + '/' + fn
       end
       def manifest
         fn=@md.file.base_filename.manifest(fnh)
@@ -146,7 +156,7 @@ module SiSU_AO_Insertions
       end
       def html_toc
         fn=@md.file.base_filename.html_segtoc(fnh)
-        "#{@base_path}/html/#{@linked_doc}/#{fn}"
+        @base_path + '/html/' + @linked_doc + '/' + fn
       end
       def html_doc
         fn=@md.file.base_filename.html_scroll(fnh)
@@ -154,7 +164,7 @@ module SiSU_AO_Insertions
       end
       def html_concordance
         fn=@md.file.base_filename.html_concordance
-        "#{@base_path}/html/#{@linked_doc}/#{fn}"
+        @base_path + '/html/' + @linked_doc + '/' + fn
       end
       def epub
         fn=@md.file.base_filename.epub(fnh)
@@ -176,6 +186,10 @@ module SiSU_AO_Insertions
         fn=@md.file.base_filename.xhtml(fnh)
         path_and_file(fn,'xhtml')
       end
+      def docbook
+        fn=@md.file.base_filename.xml_docbook_book(fnh)
+        path_and_file(fn,'docbook')
+      end
       def xml_sax
         fn=@md.file.base_filename.xml_sax(fnh)
         path_and_file(fn,'xml_sax')
@@ -193,16 +207,17 @@ module SiSU_AO_Insertions
         path_and_file(fn,'digest')
       end
       def source
-        "#{@base_path}/src/#{@src}"
+        @base_path + '/src/' + @src
       end
       def sisupod
-        "#{@base_path}/src/#{@src}.zip"
+        @base_path + '/src/' + @src + '.zip'
       end
       self
     end
     def by_filetype(linked_doc,lng,src=nil)
       @linked_doc,@lng,@src=linked_doc,lng,src
-      @lc=SiSU_Env::FilenameLanguageCodeInsert.new(@md.opt,lng).language_code_insert
+      @lc=SiSU_Env::FilenameLanguageCodeInsert.new(@md.opt,lng).
+        language_code_insert
       @base_path="#{@md.file.output_path.base.url}"
       def fnh
         {
@@ -211,7 +226,7 @@ module SiSU_AO_Insertions
         }
       end
       def path_and_file(fn,pth)
-        "#{@base_path}/#{pth}/#{fn}"
+        @base_path + '/' + pth + '/' + fn
       end
       def manifest
         fn=@md.file.base_filename.manifest(fnh)
@@ -249,6 +264,10 @@ module SiSU_AO_Insertions
         fn=@md.file.base_filename.xhtml(fnh)
         path_and_file(fn,'xhtml')
       end
+      def docbook
+        fn=@md.file.base_filename.xml_docbook_book(fnh)
+        path_and_file(fn,'docbook')
+      end
       def xml_sax
         fn=@md.file.base_filename.xml_sax(fnh)
         path_and_file(fn,'xml_sax')
@@ -266,10 +285,10 @@ module SiSU_AO_Insertions
         path_and_file(fn,'digest')
       end
       def source
-        "#{@base_path}/src/#{@src}"
+        @base_path + '/src/' + @src
       end
       def sisupod
-        "#{@base_path}/src/#{@src}.zip"
+        @base_path + '/src/' + @src + '.zip'
       end
       self
     end
@@ -285,8 +304,8 @@ module SiSU_AO_Insertions
       end
       def path_and_file(fn,pth=nil)
         (pth.nil?) \
-        ? "#{@base_path}/#{fn}"
-        : "#{@base_path}/#{pth}/#{fn}"
+        ? @base_path + '/' + fn
+        : @base_path + '/' + pth + '/' + fn
       end
       def manifest
         fn=@md.file.base_filename.manifest(fnh)
@@ -324,6 +343,10 @@ module SiSU_AO_Insertions
         fn=@md.file.base_filename.xhtml(fnh)
         path_and_file(fn)
       end
+      def docbook
+        fn=@md.file.base_filename.xml_docbook_book(fnh)
+        path_and_file(fn)
+      end
       def xml_sax
         fn=@md.file.base_filename.xml_sax(fnh)
         path_and_file(fn)
@@ -341,28 +364,50 @@ module SiSU_AO_Insertions
         path_and_file(fn)
       end
       def source
-        "#{@base_path}/#{@src}"
+        @base_path + '/' + @src
       end
       def sisupod
-        "#{@base_path}/#{@src}.zip"
+        @base_path + '/' + @src + '.zip'
       end
       self
     end
     def expand_insertions?
       data=@data
       tuned_file,tuned_file_tmp=[],[]
-      codeblock_=false
+      codeblock_={
+        status: :false,
+        type:   :na,
+      }
       data.each do |para|
-        codeblock_=if para =~/^(?:code(?:\.[a-z][0-9a-z_]+)?\{|```[ ]+code(?:\.[a-z][0-9a-z_]+)?)/
-          true
-        elsif para =~/^(?:\}code|```(?:\s|$))/m
-          false
+        codeblock_=if para =~/^code(?:\.[a-z][0-9a-z_]+)?\{/ \
+        and codeblock_[:status]==:false
+          {
+            status: :true,
+            type:   :curl,
+          }
+        elsif para =~/^```[ ]+code(?:\.[a-z][0-9a-z_]+)?/ \
+        and codeblock_[:status]==:false
+          {
+            status: :true,
+            type:   :tics,
+          }
+        elsif codeblock_[:type]==:curl \
+        and para =~/^\}code/m
+          {
+            status: :false,
+            type:   :na,
+          }
+        elsif codeblock_[:type]==:tics \
+        and para =~/^```(?:\s|$)/m
+          {
+            status: :false,
+            type:   :na,
+          }
         else codeblock_
         end
         if para !~/^%+\s/ \
-        and not codeblock_ \
+        and codeblock_[:status] != :true \
         and para =~/\{(?:~\^\s+)?(.+?)\s\[(?:\d(?:[sS]*))\]\}(?:\.\.\/\S+?\/|\S+?\.ss[tm]\b)/
-          manifest=nil
           @u=SiSU_Env::InfoEnv.new.url
           m_cmd=''
           if defined? @u.remote
@@ -391,6 +436,7 @@ module SiSU_AO_Insertions
               pdf_portrait:     by_language(m_linked_doc,m_linked_doc_lang).pdf_landscape,
               odt:              by_language(m_linked_doc,m_linked_doc_lang).odt,
               xhtml:            by_language(m_linked_doc,m_linked_doc_lang).xhtml,
+              docbook:          by_language(m_linked_doc,m_linked_doc_lang).docbook,
               xml_sax:          by_language(m_linked_doc,m_linked_doc_lang).xml_sax,
               xml_dom:          by_language(m_linked_doc,m_linked_doc_lang).xml_dom,
               txt:              by_language(m_linked_doc,m_linked_doc_lang).txt,
@@ -409,6 +455,7 @@ module SiSU_AO_Insertions
               pdf_portrait:     by_filetype(m_linked_doc,m_linked_doc_lang).pdf_landscape,
               odt:              by_filetype(m_linked_doc,m_linked_doc_lang).odt,
               xhtml:            by_filetype(m_linked_doc,m_linked_doc_lang).xhtml,
+              docbook:          by_filetype(m_linked_doc,m_linked_doc_lang).docbook,
               xml_sax:          by_filetype(m_linked_doc,m_linked_doc_lang).xml_sax,
               xml_dom:          by_filetype(m_linked_doc,m_linked_doc_lang).xml_dom,
               txt:              by_filetype(m_linked_doc,m_linked_doc_lang).txt,
@@ -427,6 +474,7 @@ module SiSU_AO_Insertions
               pdf_portrait:     by_filename(m_linked_doc,m_linked_doc_lang).pdf_landscape,
               odt:              by_filename(m_linked_doc,m_linked_doc_lang).odt,
               xhtml:            by_filename(m_linked_doc,m_linked_doc_lang).xhtml,
+              docbook:          by_filename(m_linked_doc,m_linked_doc_lang).docbook,
               xml_sax:          by_filename(m_linked_doc,m_linked_doc_lang).xml_sax,
               xml_dom:          by_filename(m_linked_doc,m_linked_doc_lang).xml_dom,
               txt:              by_filename(m_linked_doc,m_linked_doc_lang).txt,
