@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/conf.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/conf.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,7 +58,7 @@
 
 =end
 module SiSU_Initialize
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
     include SiSU_Screen
   require_relative 'relaxng'                            # relaxng.rb
@@ -78,11 +75,11 @@ module SiSU_Initialize
       ConfigSite.new(@opt).dtd
       ConfigSite.new(@opt).cp_local_images
       ConfigSite.new(@opt).cp_external_images
-      ConfigSite.new(@opt).cp_webserver_images #if @opt.mod.inspect =~/--init(?:ialize)?=site/
+      ConfigSite.new(@opt).cp_webserver_images
     end
   end
   class ConfigSite #config files such as css are not updated if they already exist unless forced using the --init=site modifier
-    require_relative 'sysenv'                           # sysenv.rb
+    require_relative 'se'                               # se.rb
     def initialize(opt)
       @opt=opt
       @env=SiSU_Env::InfoEnv.new(@opt.fns)
@@ -206,10 +203,10 @@ module SiSU_Initialize
       rnc.close
       #xsd
       schema=SiSU_Env::SystemCall.new(rnc_src,xsd_file)
-      schema.relaxng(@opt.cmd)
+      schema.relaxng(@opt.selections.str)
       #rng
       schema=SiSU_Env::SystemCall.new(rnc_src,rng_file)
-      schema.relaxng(@opt.cmd)
+      schema.relaxng(@opt.selections.str)
       #rnc
       if FileTest.file?(rnc_src)
         FileUtils::cp(rnc_src,rnc_file)
@@ -228,10 +225,10 @@ module SiSU_Initialize
       rnc.close
       #xsd
       schema=SiSU_Env::SystemCall.new(rnc_src,xsd_file)
-      schema.relaxng(@opt.cmd)
+      schema.relaxng(@opt.selections.str)
       #rng
       schema=SiSU_Env::SystemCall.new(rnc_src,rng_file)
-      schema.relaxng(@opt.cmd)
+      schema.relaxng(@opt.selections.str)
       #rnc
       if FileTest.file?(rnc_src)
         FileUtils::cp(rnc_src,rnc_file)
@@ -250,10 +247,10 @@ module SiSU_Initialize
       rnc.close
       #xsd
       schema=SiSU_Env::SystemCall.new(rnc_src,xsd_file)
-      schema.relaxng(@opt.cmd)
+      schema.relaxng(@opt.selections.str)
       #rng
       schema=SiSU_Env::SystemCall.new(rnc_src,rng_file)
-      schema.relaxng(@opt.cmd)
+      schema.relaxng(@opt.selections.str)
       #rnc
       if FileTest.file?(rnc_src)
         FileUtils::cp(rnc_src,rnc_file)
@@ -268,7 +265,7 @@ module SiSU_Initialize
       rnc << @rxng.rnc_model_output_sax
       rnc.close
       schema=SiSU_Env::SystemCall.new(rnc_file,dtd_file)
-      schema.relaxng(@opt.cmd)
+      schema.relaxng(@opt.selections.str)
     end
     def trang_rnc_model_input_dom
       rnc_file=@env.processing_path.ao + '/dom.rnc'
@@ -277,7 +274,7 @@ module SiSU_Initialize
       rnc << @rxng.rnc_model_output_dom
       rnc.close
       schema=SiSU_Env::SystemCall.new(rnc_file,dtd_file)
-      schema.relaxng(@opt.cmd)
+      schema.relaxng(@opt.selections.str)
     end
     def trang_rnc_model_input_node
       rnc_file=@env.processing_path.ao + '/node.rnc'
@@ -286,7 +283,7 @@ module SiSU_Initialize
       rnc << @rxng.rnc_model_input_node
       rnc.close
       schema=SiSU_Env::SystemCall.new(rnc_file,dtd_file)
-      schema.relaxng(@opt.cmd)
+      schema.relaxng(@opt.selections.str)
     end
   end
 end
