@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/db_indexes.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/db_indexes.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -82,9 +79,23 @@ module SiSU_DbIndex
         end
       end
       def conn_execute_array(sql_arr)
-        @conn.transaction do |conn|
-          sql_arr.each do |sql|
-            conn_execute_sql(conn,sql)
+        begin
+          @conn.transaction do |conn|
+            sql_arr.each do |sql|
+              conn_execute_sql(conn,sql)
+            end
+          end
+        rescue
+          if @conn.is_a?(NilClass)
+            errmsg="No sqlite3 connection (check sqlite3 dependencies)"
+            if @opt.act[:no_stop][:set]==:on
+              SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                error("#{errmsg}, proceeding without sqlite output (as requested)")
+            else
+              SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                error("#{errmsg}, STOPPING")
+              exit
+            end
           end
         end
       end
