@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/db_select.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/db_select.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -185,12 +182,16 @@ module SiSU_DbSelect
       file=if @opt.act[:maintenance][:set]==:on
         if @opt.fns and not @opt.fns.empty?
           @env=SiSU_Env::InfoEnv.new(@opt.fns) if @opt.fns
-          if @sql_type ==:sqlite and @opt.act[:maintenance][:set]==:on
+          if @sql_type ==:sqlite
             puts "\n#{@env.processing_path.sqlite}/#{@opt.fns}.sql"
           end
           @db=SiSU_Env::InfoDb.new
           @job="sqlite3 #{@db.sqlite.db} < #{@env.processing_path.sqlite}/#{@opt.fns}.sql"
-          File.new("#{@env.processing_path.sqlite}/#{@opt.fns}.sql",'w+')
+          if @sql_type ==:sqlite
+            File.new("#{@env.processing_path.sqlite}/#{@opt.fns}.sql",'w+')
+          else
+            File.new("#{@env.processing_path.postgresql}/#{@opt.fns}.sql",'w+')
+          end
         elsif @opt.fns \
         and (@opt.act[:sqlite_create][:set] ==:on \
         || @opt.act[:psql_create][:set] ==:on)
