@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/dbi_discrete.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/dbi_discrete.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,9 +58,9 @@
 
 =end
 module  SiSU_DBI_Discrete                               #% database building
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env; include SiSU_Screen
-  require_relative 'param'                              # param.rb
+  require_relative 'dp'                                 # dp.rb
     include SiSU_Param
   require_relative 'db_dbi'                             # db_dbi.rb
     include SiSU_DbDBI
@@ -73,7 +70,8 @@ module  SiSU_DBI_Discrete                               #% database building
     require 'fileutils'
       include FileUtils::Verbose
   rescue LoadError
-    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('fileutils NOT FOUND (LoadError)')
+    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+      error('fileutils NOT FOUND (LoadError)')
   end
   class SQL
     def initialize(opt)
@@ -83,7 +81,9 @@ module  SiSU_DBI_Discrete                               #% database building
       @md=@particulars.md
       if @opt.act[:sqlite][:set]==:on
         @sql_type=:sqlite
-        maintenance_check(@opt,__FILE__,__LINE__) if @opt.act[:maintenance][:set]==:on
+        if @opt.act[:maintenance][:set]==:on
+          maintenance_check(@opt,__FILE__,__LINE__)
+        end
       end
       @output_path=@md.file.output_path.sqlite_discrete.dir
       @filename=@md.file.base_filename.sqlite_discrete
@@ -95,8 +95,7 @@ module  SiSU_DBI_Discrete                               #% database building
       create_and_populate
     end
     def maintenance_check(opt,file,line)
-      #p opt.mod
-      #p opt.cmd
+      #p opt.selections.str
       p "at #{file} #{line}"
     end
     def prepare
@@ -127,7 +126,7 @@ module  SiSU_DBI_Discrete                               #% database building
       begin
         SiSU_Screen::Ansi.new(
           @opt.act[:color_state][:set],
-          'SQLite',
+          'SQLite (discrete)',
           "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
         ).green_title_hi unless @opt.act[:quiet][:set]==:on
         sdb.create_db
@@ -169,7 +168,7 @@ module  SiSU_DBI_Discrete                               #% database building
       begin
         SiSU_Screen::Ansi.new(
           @opt.act[:color_state][:set],
-          "DBI (#{@sql_type}) #{@opt.mod}",
+          "DBI (#{@sql_type}) #{@opt.selections.str}",
           @opt.fns
         ).dbi_title unless @opt.act[:quiet][:set]==:on
         @db.sqlite_discrete.conn_sqlite3
@@ -183,13 +182,19 @@ module  SiSU_DBI_Discrete                               #% database building
     def populate
     end
     def sql_maintenance_file
-      file=if @opt.inspect =~/M/
+      file=if @opt.act[:maintenance][:set]==:on
         if @opt.fns and not @opt.fns.empty?
           @env=SiSU_Env::InfoEnv.new(@opt.fns) if @opt.fns
-          puts "\n#{@env.processing_path.sqlite}/#{@opt.fns}.sql" if @sql_type ==:sqlite and @opt.act[:maintenance][:set]==:on
+          if @sql_type ==:sqlite
+            puts "\n#{@env.processing_path.sqlite}/#{@opt.fns}.sql"
+          end
           @db=SiSU_Env::InfoDb.new
           @job="sqlite3 #{@db.sqlite.db} < #{@env.processing_path.sqlite}/#{@opt.fns}.sql"
-          File.new("#{@env.processing_path.sqlite}/#{@opt.fns}.sql",'w+')
+          if @sql_type ==:sqlite
+            File.new("#{@env.processing_path.sqlite}/#{@opt.fns}.sql",'w+')
+          else
+            File.new("#{@env.processing_path.postgresql}/#{@opt.fns}.sql",'w+')
+          end
         elsif @opt.fns \
         and @opt.fns.inspect =~/create/
           nil #sort variations later
