@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/git.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/git.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,8 +58,8 @@
 
 =end
 module SiSU_Git
-  require_relative 'param'                              # param.rb
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'dp'                                 # dp.rb
+  require_relative 'se'                                 # se.rb
   require_relative 'ao'                                 # ao.rb
   class Source
     def initialize(opt)
