@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/concordance.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/html_concordance.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -62,12 +59,10 @@
 
 =end
 module SiSU_Concordance
-  require_relative 'particulars'                        # particulars.rb
+  require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
-  require_relative 'defaults'                           # defaults.rb
-    include SiSU_Viz
   require_relative 'html_format'                        # html_format.rb
     include SiSU_HTML_Format
   require_relative 'html_minitoc'                       # html_minitoc.rb
@@ -118,7 +113,7 @@ module SiSU_Concordance
           SiSU_Concordance::Source::Words.new(@particulars).songsheet
         end
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -128,7 +123,6 @@ module SiSU_Concordance
     end
     private
     class DocTitle
-      include SiSU_Viz
       #revisit, both requires (html & xml_shared) needed for stand alone operation (sisu -w [filename])
       require_relative 'xml_shared'                     # xml_shared.rb
       require_relative 'html'                           # html.rb
@@ -139,7 +133,7 @@ module SiSU_Concordance
         @fnb=@md.fnb
         @lex_button=%{<a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" height="44" width="144" valign="center" src="#{@file.path_rel_links.html_seg_2}_sisu/image/sisu.png" alt="SiSU home --&gt;"></a>}
         @doc_details =<<WOK
-<table summary="links to text related to this rudimentary index" width="96%" border="0" bgcolor="white" cellpadding="0" align="center"><tr><td width="2%" align="right">&nbsp;</td><td width="94%" valign="top" align="justify"><h1 class="small"><a href="#{@md.file.base_filename.html_segtoc}"><b>#{@md.title.full}</b></a></h1><p class="bold">#{@md.author}</p></td></tr></table>
+<table summary="links to text related to this rudimentary index" width="96%" border="0" cellpadding="0" align="center"><tr><td width="2%" align="right">&nbsp;</td><td width="94%" valign="top" align="justify"><h1 class="small"><a href="#{@md.file.base_filename.html_segtoc}"><b>#{@md.title.full}</b></a></h1><p class="bold">#{@md.author}</p></td></tr></table>
 WOK
         @make=SiSU_Env::ProcessingSettings.new(@md)
       end
@@ -159,9 +153,10 @@ WOK
         else ''
         end
         <<WOK
-<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
+<!DOCTYPE html>
 <html>
 <head>
+  <meta charset="utf-8">
   <title>
     SiSU created WordIndex for: #{@md.title.full}
   </title>
@@ -178,10 +173,10 @@ WOK
   #{toc}
 <div class="#{div_class}">
  #{@doc_details}
-<p>Word index links are to html versions of the text the segmented version followed by the scroll (single document) version.<br />[For segmented text references [T1], [T2] or [T3] appearing without a link, indicates that the word appears in a title (or subtitle) of the text (that is identifiable by the appended object citation number).]</p>
+<p>Word index links are to html versions of the text the segmented version followed by the scroll (single document) version.<br>[For segmented text references [T1], [T2] or [T3] appearing without a link, indicates that the word appears in a title (or subtitle) of the text (that is identifiable by the appended object citation number).]</p>
 <p>(The word listing/index is Case sensitive: Capitalized words appear before lower case)</p>
   <p>
-    <b>word</b> (number of occurences)<br />linked references to word within document <br />
+    <b>word</b> (number of occurences)<br>linked references to word within document <br>
     [if number of occurences exceed number of references - word occurs more than once in at least one reference. Footnote/endnotes are either assigned to the paragraph from which they are referenced or ignored, so it is relevant to check the footnotes referenced from within a paragraph as well.]
   </p>
   <p>
@@ -208,11 +203,9 @@ WOK
     class Words
       require_relative 'i18n'                           # i18n.rb
         include SiSU_i18n
-      require_relative 'defaults'                       # defaults.rb
-        include SiSU_Viz
       require_relative 'html_format'                    # html_format.rb
         include SiSU_HTML_Format
-      require_relative 'sysenv'                         # sysenv.rb
+      require_relative 'se'                             # se.rb
         include SiSU_Screen
       @@dp=nil
       def initialize(particulars)
@@ -236,18 +229,19 @@ WOK
           @alphlst=SiSU_i18n::Alphabet.new(@md.opt.lng).hash_strings
           @rgx_scanlist=%r{#{Mx[:fa_italics_o]}[#{@alphlst[:l]}#{@alphlst[:u]}0-9"\s]{2,12}#{Mx[:fa_italics_c]}|#{Mx[:fa_bold_o]}[#{@alphlst[:l]}#{@alphlst[:u]}0-9"\s]{2,12}#{Mx[:fa_bold_c]}|(?:https?|file)://\S+|<\S+?>|[#{@alphlst[:l]}#{@alphlst[:u]}]+|\w+}mi
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
       end
       def songsheet
         begin
-          FileUtils::mkdir_p(@file.output_path.html_concordance.dir) unless FileTest.directory?(@file.output_path.html_concordance.dir)
+          FileUtils::mkdir_p(@file.output_path.html_concordance.dir) \
+            unless FileTest.directory?(@file.output_path.html_concordance.dir)
           @file_concordance=File.open(@file.place_file.html_concordance.dir,'w')
           map_para
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         ensure
