@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/html_format.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/html_format.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,7 +58,7 @@
 
 =end
 module SiSU_HTML_Format
-  include SiSU_Viz
+  require_relative 'html_parts'                         # html_parts.rb
   class ParagraphNumber
     def initialize(md,ocn)
       @md,@ocn=md,ocn.to_s
@@ -75,9 +72,7 @@ module SiSU_HTML_Format
         or @ocn.empty?
           ''
         else
-          name=(@make.build.html_strict?) ? '' :  %{ name="#{@ocn}"}
-          @ocn.gsub(/^(\d+|)$/,
-            %{<label class="ocn"><a#{name} href="##{@ocn_html_identifier}#{@ocn}" class="lnkocn">\\1</a></label>})
+          %{<label class="ocn">#{@ocn}</label>}
         end
       else
         ''
@@ -92,7 +87,7 @@ module SiSU_HTML_Format
       end
     end
     def id #w3c? "tidy" complains about numbers as identifiers ! annoying
-      (@ocn==nil || @ocn.empty?) ? '' : %{id="o#{@ocn}"}
+      (@ocn==nil || @ocn.empty?) ? '' : %{id="#{Mx[:ocn_id_char]}#{@ocn}"}
     end
     def goto
       (@ocn==nil || @ocn.empty?) ? '' : %{<a href="##{@ocn_html_identifier}#{@ocn}">}
@@ -100,13 +95,13 @@ module SiSU_HTML_Format
   end
   class HeadInformation
     require_relative 'css'                              # css.rb
+    include SiSU_Parts_HTML
     require_relative 'xml_shared'                       # xml_shared.rb
-    include SiSU_Viz
-    attr_reader :md,:rdf,:vz
+    attr_reader :md,:rdf
     def initialize(md)
       @md=md
       # DublinCore 1 - title
-      @vz=SiSU_Viz::Defaults.new
+      @bits=SiSU_Proj_HTML::Bits.new
       @seg_name_html=(SiSU_HTML::Source::Seg.new.seg_name_html || [])
       @seg_name_html_tracker=(SiSU_HTML::Source::Seg.new.seg_name_html_tracker || [])
       @tocband_scroll,@tocband_segtoc=nil,nil
@@ -167,7 +162,7 @@ module SiSU_HTML_Format
       %{
 <table summary="segment navigation available documents types: toc,doc,pdf,concordance" border="0" cellpadding="3" cellspacing="0">
 <tr>
-<td align="center" bgcolor=#{@vz.color_band2}>
+<td align="center" bgcolor=#{the_color.band2}>
   #{wgt.manifest(page)}
   #{wgt.search}
 </tr></table>}
@@ -175,15 +170,6 @@ module SiSU_HTML_Format
     def rdf
       SiSU_XML_Tags::RDF.new(md)
     end
-    def doc_type
-      %{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
-"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">\n}
-    end
-    def table_close
-      %{  </font>
-#{@vz.table_close}}
-    end
     def button_home(page=:seg)
       button=%{ <table summary="home button / home information" border="0" cellpadding="3" cellspacing="0">\n <tr><td align="left" bgcolor="#ffffff">\n}
       if @md.make.home_button_image.is_a?(Hash)
@@ -198,7 +184,7 @@ module SiSU_HTML_Format
         button +=%{   <p class="tiny_left"><a href="#{@md.make.home_button_image[:link]}" target="_top"><img border="0" src="#{image_path}/#{@md.make.home_button_image[:home_button]}"  width="#{@md.make.home_button_image[:w]}" height="#{@md.make.home_button_image[:h]}" alt="home icon --&gt;" /></a></p>\n}
       elsif @md.home_button_links.is_a?(Array)
         @md.home_button_links.each do |links|
-          button +=%{  <p class="tiny_left"><a href="#{links[:url]}/" target="_top">\n    #{links[:say]}\n  </a></p>\n}
+          button +=%{  <p class="tiny_left"><a href="#{links[:url]}" target="_top">\n    #{links[:say]}\n  </a></p>\n}
         end
       end
       button +=%{ </td></tr>\n </table>}
@@ -210,6 +196,7 @@ module SiSU_HTML_Format
     end
   end
   class Widget < HeadInformation
+    include SiSU_Parts_HTML
     def initialize(md)
       super(md)
       @md=md
@@ -220,15 +207,15 @@ module SiSU_HTML_Format
       @make=SiSU_Env::ProcessingSettings.new(md)
     end
     def home
-      %{<td align="center" bgcolor=#{@vz.color_band2}>
+      %{<td align="center" bgcolor=#{the_color.band2}>
   <a href="../index.html" target="_top">
-  #{@vz.nav_txt_homepage}</a>
+  #{the_nav.txt_homepage}</a>
 </td>
 }
     end
     def scroll(text)
       if @md.fns =~ /\.(?:-|ssm\.)?sst$/
-        %{<td align="center" bgcolor=#{@vz.color_band2}>
+        %{<td align="center" bgcolor=#{the_color.band2}>
   <a href="#{Xx[:html_relative1]}html/#{@file.base_filename.html_scroll}" target="_top">
     #{text}
   </a>
@@ -261,16 +248,15 @@ module SiSU_HTML_Format
         end
         if page==:manifest
           manifest_lnk="#{@md.file.output_path.manifest.url}/#{@file.base_filename.manifest}"
-          brace_url=SiSU_Viz::Defaults.new.url_decoration
-          %{<td align="center" bgcolor=#{@vz.color_band2}>
-  <font face="#{@vz.font_fonts}" size="2">
-  #{brace_url.xml_open}<a href="#{manifest_lnk}" target="_top">#{@md.file.output_path.manifest.url}/#{@file.base_filename.manifest}</a>#{brace_url.xml_close}
+          %{<td align="center" bgcolor=#{the_color.band2}>
+  <font face="#{the_font.set_fonts}" size="2">
+  #{the_url_decoration.xml_open}<a href="#{manifest_lnk}" target="_top">#{@md.file.output_path.manifest.url}/#{@file.base_filename.manifest}</a>#{the_url_decoration.xml_close}
   </font>
 </td>}
         else
-          %{<td align="center" bgcolor=#{@vz.color_band2}>
+          %{<td align="center" bgcolor=#{the_color.band2}>
   <a href="#{manifest_lnk}" target="_top">
-    #{@vz.nav_txt_manifest}
+    #{the_nav.txt_manifest}
   </a>
 </td>}
         end
@@ -295,7 +281,7 @@ module SiSU_HTML_Format
   #{make_scroll_search_form_and_manifest_link}
 </td>
 WOK
-        %{<table summary="table of contents scroll navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
+        %{<table summary="table of contents scroll navigation band" id="toc" width="100%" bgcolor=#{the_color.band1}>
 <tr><td width="20%">
   #{button_home(:scroll)}
 </td>
@@ -304,42 +290,51 @@ WOK
 </td>
 <td width="20%">
   &nbsp;
-#{@vz.table_close}
-<p />}
+#{the_table_close}
+<p>}
       else ''
       end
     end
     def concordance_navigation_band
+      up_button=if @make.build.html_navigation?
+        %{</td>
+<td width="5%" align="right">
+  &nbsp;<a href="toc.html" target="_top" alt="-&gt;">
+      #{png_nav.toc}
+    </a>&nbsp;
+}
+      else ''
+      end
       if @make.build.html_top_band?
-        %{<table summary="concordance navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
+        %{<table summary="concordance navigation band" id="toc" width="100%" bgcolor=#{the_color.band1}>
 <tr><td width="20%">
   #{button_home}
 </td>
 <td width="75%" align="center">
   #{doc_types}
-</td>
-<td width="5%" align="right">
-  &nbsp;<a href="toc.html" target="_top" alt="-&gt;">
-      #{png_nav.toc}
-    </a>&nbsp;
-#{@vz.table_close}
-<p />}
+#{up_button}
+#{the_table_close}
+<p>}
       else ''
       end
     end
     def seg_head_navigation_band(page=:seg)
-      if page==:manifest
-        nxt=(@file.output_dir_structure.by_language_code? \
-        || @file.output_dir_structure.by_filetype?) \
-        ? "../html/#{@md.fnb}/toc#{@md.lang_code_insert}#{Sfx[:html]}"
-        : "toc#{@md.lang_code_insert}#{Sfx[:html]}"
-        firstseg=%{<a href="#{nxt}" target="_top" alt="-&gt;">
+      if @make.build.html_navigation?
+        if page==:manifest
+          nxt=(@file.output_dir_structure.by_language_code? \
+          || @file.output_dir_structure.by_filetype?) \
+          ? "../html/#{@md.fnb}/toc#{@md.lang_code_insert}#{Sfx[:html]}"
+          : "toc#{@md.lang_code_insert}#{Sfx[:html]}"
+          firstseg=%{<a href="#{nxt}" target="_top" alt="-&gt;">
+          #{png_nav.nxt}</a>}
+        elsif @md.firstseg =~/\S+/
+          firstseg=%{<a href="#{@md.firstseg}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top" alt="-&gt;">
         #{png_nav.nxt}</a>}
-      elsif @md.firstseg =~/\S+/
-        firstseg=%{<a href="#{@md.firstseg}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top" alt="-&gt;">
-      #{png_nav.nxt}</a>}
+        end
+      else ''
       end
-      %{<table summary="table of contents segment navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
+      if @make.build.html_top_band?
+        %{<table summary="table of contents segment navigation band" id="toc" width="100%" bgcolor=#{the_color.band1}>
 <tr><td width="20%">
 #{button_home(page)}
 </td>
@@ -348,8 +343,10 @@ WOK
 </td>
 <td width="5%" align="right">
   &nbsp;#{firstseg}&nbsp;
-#{@vz.table_close}
-<p />}
+#{the_table_close}
+<p>}
+      else ''
+      end
     end
     def manifest_link(text)
 #     @file=SiSU_Env::FileOp.new(@md) if @md
@@ -369,8 +366,8 @@ WOK
     end
     def make_scroll_search_form_and_manifest_link
       wgt=SiSU_HTML_Format::Widget.new(@md)
-      %{<td align="center" bgcolor=#{@vz.color_band2}>
-  #{@vz.nav_txt_doc_link}
+      %{<td align="center" bgcolor=#{the_color.band2}>
+  #{the_nav.txt_doc_link}
 </td>
 }
       %{<table summary="toc segment and scroll with pdf" border="0" cellpadding="3" cellspacing="0">
@@ -382,13 +379,13 @@ WOK
     def make_scroll_seg_pdf
       seg=''
       wgt=SiSU_HTML_Format::Widget.new(@md)
-      seg=%{<td align="center" bgcolor=#{@vz.color_band2}>
-  #{@vz.nav_txt_toc_link}
+      seg=%{<td align="center" bgcolor=#{the_color.band2}>
+  #{the_nav.txt_toc_link}
 </td>
 }
       %{<table summary="toc scroll and segment with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
-<td align="center" bgcolor=#{@vz.color_band2}>
+<td align="center" bgcolor=#{the_color.band2}>
   #{wgt.manifest}
   #{wgt.search}
 </tr></table>}
@@ -397,15 +394,17 @@ WOK
       wgt=SiSU_HTML_Format::Widget.new(@md)
       %{<table summary="toc scroll and segment with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
-<td align="center" bgcolor=#{@vz.color_band2}>
+<td align="center" bgcolor=#{the_color.band2}>
   #{wgt.manifest}
   #{wgt.search}
 </tr></table>}
     end
     def head
       rdf=SiSU_XML_Tags::RDF.new(@md)
-      %{#{doc_type}
+      %{<!DOCTYPE html>
+<html>
 <head>
+  <meta charset="utf-8">
   <title>
     #{@md.html_title}
   </title>
@@ -413,34 +412,31 @@ WOK
 #{rdf.metatag_html}
 #{@stylesheet.css_head}
 </head>
-#{@vz.color_body}
-<a name="top" id="top"></a>
-<a name="up" id="up"></a>
-<a name="start" id="start"></a>}
+<body lang="#{@md.opt.lng}">
+<a name="top" id="top"></a>}
     end
     def concordance
       if @md.concord_make
-      %{#{@vz.margin_css}
+      %{#{the_margin.css}
   <h4 class="toc">
     <a href="./#{@md.file.base_filename.html_concordance}">
       <i>Concordance</i>
     </a>
   </h4>
-#{@vz.table_close}}
+#{table_close}}
       else
-      %{#{@vz.margin_css}
-#{@vz.table_close}}
+      %{#{the_margin.css}
+#{table_close}}
       end
     end
     def links_guide_vertical_open
 #     @file=SiSU_Env::FileOp.new(@md) if @md
-      url=((defined? @vz.url_hp) && @vz.url_hp =~/^https?:\/\/\S+$/ ? @vz.url_hp : @vz.url_home)
       %{
 <div id="vertical_links">
   <ul id="vertical">
   <li class="refbold">
-    <a href="#{url}">
-      #{@vz.txt_hp}
+    <a href="#{the_url.home}">
+      #{the_text.txt_hp}
     </a>
   </li>
   <li class="ref">
@@ -455,13 +451,12 @@ WOK
     end
     def links_guide_horizontal_open
 #     @file=SiSU_Env::FileOp.new(@md) if @md
-      url=((defined? @vz.url_hp) && @vz.url_hp =~/^https?:\/\/\S+$/ ? @vz.url_hp : @vz.url_home)
       %{
 <div id="horizontal_links">
   <ul id="horizontal">
   <li class="refbold">
-    <a href="#{url}">
-      #{@vz.txt_hp}
+    <a href="#{the_url.home}">
+      #{the_text.txt_hp}
     </a>
   </li>
   <li class="ref">
@@ -505,7 +500,7 @@ WOK
         rights=SiSU_HTML_Tune::CleanHTML.new(@md.rights.all).clean_for_html
         rights=rights.gsub(/^\s*Copyright\s+\(C\)/,'Copyright <sup>&copy;</sup>&nbsp;')
         %{<p class="small_left">Rights: #{rights}</p>
-<p />}
+<p>}
       end
       self
     end
@@ -515,69 +510,69 @@ WOK
     def scroll_head_title_banner_open
       icon=@md.icon ? %{<center>\n#{@md.icon}\n</center>} : ''
       %{#{icon}
-#{@vz.banner_instrument_cover_band_scr}}
+#{the_banner.instrument_cover_band_scr}}
     end
     def seg_head_title_banner_open
       icon=@md.icon ? %{<center>\n#{@md.icon}\n</center>} : ''
       %{#{icon}
-#{@vz.banner_instrument_cover_band_seg}}
+#{the_banner.instrument_cover_band_seg}}
     end
     def make_scroll
-      concord=concordance_link(@vz.nav_txt_concordance)
+      concord=concordance_link(the_nav.txt_concordance)
       %{<table summary="toc scroll" border="0" cellpadding="3" cellspacing="0">
 <tr><td align="center" bgcolor="white" border="0">
-  #{@vz.nav_txt_doc_link}
+  #{the_nav.txt_doc_link}
 </td>
 <td align="center" bgcolor="white">
    #{concord}
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def make_seg
-      concord=concordance_link(@vz.nav_txt_concordance)
+      concord=concordance_link(the_nav.txt_concordance)
       %{<table summary="toc segment" border="0" cellpadding="3" cellspacing="0">
 <tr><td align="center" bgcolor="white">
-  #{@vz.nav_txt_toc_link}
+  #{the_nav.txt_toc_link}
 </td>
 <td align="center" bgcolor="white">
   <font size=2>
    #{concord}
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def manifest #check structure
       if not @o_str.dump_or_redirect?
-        manifest=manifest_link(@vz.nav_txt_manifest)
-        %{#{@vz.margin_txt_3}
-  #{@vz.paragraph_font_small}
+        manifest=manifest_link(the_nav.txt_manifest)
+        %{#{the_margin.txt_3}
+  #{the_font.paragraph_font_small}
    #{manifest}
     </font>
-#{@vz.table_close}}
+#{the_table_close}}
       else ''
       end
     end
     def concordance #check structure
-      concord=concordance_link(@vz.nav_txt_concordance)
-      %{#{@vz.margin_txt_3}
-  #{@vz.paragraph_font_small}
+      concord=concordance_link(the_nav.txt_concordance)
+      %{#{the_margin.txt_3}
+  #{the_font.paragraph_font_small}
    #{concord}
     </font>
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def metadata
-      %{#{@vz.margin_css}
+      %{#{the_margin.css}
   <h4 class="toc">
     <a href="#{@metalink}">
       <i>MetaData</i>
     </a>
   </h4>
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def seg_tail
       %{
 <div class="main_column">
 <p>&nbsp;<p>
-<table summary="toc segment tail" bgcolor=#{@vz.color_band1}>
+<table summary="toc segment tail" bgcolor=#{the_color.band1}>
 <tr><td width="20%">
-  #{@vz.banner_band}
+  #{the_banner.banner_band}
 </td>
 <td width="60%">
   <center>
@@ -586,14 +581,9 @@ WOK
 </td></tr>
 </table>
 <p>&nbsp;</p>
-#{@vz.credits_splash}
-#{@vz.credits_sisu}
+#{@bits.credits_sisu}
 <a name="bottom" id="bottom"></a>
-<a name="down" id="down"></a>
 <a name="end" id="end"></a>
-<a name="finish" id="finish"></a>
-<a name="stop" id="stop"></a>
-<a name="credits"></a>
 </div>
 </div>
 </div>
@@ -604,14 +594,9 @@ WOK
       %{
 <div class="main_column">
 #{nav}
-#{@vz.credits_splash}
-#{@vz.credits_sisu}
+#{@bits.credits_sisu}
 <a name="bottom" id="bottom"></a>
-<a name="down" id="down"></a>
 <a name="end" id="end"></a>
-<a name="finish" id="finish"></a>
-<a name="stop" id="stop"></a>
-<a name="credits"></a>
 </div>
 }
     end
@@ -619,14 +604,9 @@ WOK
       %{
 <div class="main_column">
 <p>&nbsp;</p>
-#{@vz.credits_splash}
-#{@vz.credits_sisu}
+#{@bits.credits_sisu}
 <a name="bottom" id="bottom"></a>
-<a name="down" id="down"></a>
 <a name="end" id="end"></a>
-<a name="finish" id="finish"></a>
-<a name="stop" id="stop"></a>
-<a name="credits"></a>
 </div>
 </div>
 </div>
@@ -648,7 +628,7 @@ WOK
           nxt=nxt.gsub(/sisu_manifest\.html/,"../../manifest/#{@file.base_filename.manifest}")
         end
       end
-      %{<table summary="segment hidden control pre and next" width="100%" border="0" cellpadding="0" bgcolor=#{@vz.color_grey_pale} align="center">
+      %{<table summary="segment hidden control pre and next" width="100%" border="0" cellpadding="0" bgcolor=#{the_color.grey_pale} align="center">
 <tr><td align="left">
   <a href="#{pre}" target="_top">
     #{png_nav.dot_pre}
@@ -663,13 +643,13 @@ WOK
   <a href="#{nxt}" target="_top">
     #{png_nav.dot_nxt}
   </a>
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def dot_control_pre
       pre="#{@seg_name_html[@seg_name_html_tracker-2]}#{@md.lang_code_insert}#{Sfx[:html]}"
       up=@toc
       nxt="#{@md.file.base_filename.html_segtoc}"
-      %{<table summary="segment hidden control pre" width="100%" border="0" cellpadding="0" bgcolor=#{@vz.color_grey_pale} align="center">
+      %{<table summary="segment hidden control pre" width="100%" border="0" cellpadding="0" bgcolor=#{the_color.grey_pale} align="center">
 <tr><td align="left">
   <a href="#{pre}" target="_top">
     #{png_nav.dot_pre}
@@ -684,21 +664,21 @@ WOK
   <a href="#{nxt}" target="_top">
     #{png_nav.dot_nxt}
   </a>
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def toc_nav(f_pre=false,f_nxt=false,use=1)
       pre=nxt=''
-      toc=%{<td align="center" bgcolor=#{@vz.color_band1}>
+      toc=%{<td align="center" bgcolor=#{the_color.band1}>
   <a href="#{@toc}" target="_top">
     #{png_nav.toc}
   </a>
 </td>}
-      pre=%{<td align="center" bgcolor=#{@vz.color_band1}>
+      pre=%{<td align="center" bgcolor=#{the_color.band1}>
   <a href="#{@seg_name_html[@seg_name_html_tracker-use]}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top">
     #{png_nav.pre}
   </a>
 </td>} if f_pre==true
-      nxt=%{<td align="center" bgcolor=#{@vz.color_band1}>
+      nxt=%{<td align="center" bgcolor=#{the_color.band1}>
   <a href="#{@seg_name_html[@seg_name_html_tracker+1]}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top">
     #{png_nav.nxt}
   </a>
@@ -716,7 +696,7 @@ WOK
 #{toc}
 #{nxt}
 <td>
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def toc_next2
       toc_nav(false,true).dup
@@ -745,38 +725,33 @@ WOK
       end
     end
     def navigation_table
-      %{<table summary="navigation segment table" width=#{@vz.table_width_1} border="0" bgcolor="white" cellpadding="0">
+      %{<table summary="navigation segment table" width=#{the_width.table1} border="0" bgcolor="white" cellpadding="0">
 <tr><th width="#{@@indent['leve_1']}" align="right">
 </td>
 <td valign="top">
   <font size=2>}
     end
     def navigation_table1
-      %{<table summary="navigation segment table1" width=#{@vz.table_width_1} border="0" cellpadding=#{@vz.table_cellpad_box} bgcolor=#{@vz.color_table1} align="left">
+      %{<table summary="navigation segment table1" width=#{the_width.table1} border="0" cellpadding=#{the_table_cellpad_box} bgcolor=#{the_color.table1} align="left">
 <tr><td valign="top">
   <font size="2">}
     end
     def navigation_table2
-      %{<table summary="navigation segment table2" width=#{@vz.table_width_2} border="0" cellpadding=#{@vz.table_cellpad_box} bgcolor=#{@vz.color_table2} align="left">
+      %{<table summary="navigation segment table2" width=#{the_width.table2} border="0" cellpadding=#{the_table_cellpad_box} bgcolor=#{the_color.table2} align="left">
 <tr><td valign="top">
   <font size="2">}
     end
     def credit
       %{
 <div class="main_column">
-#{@vz.credits_splash}
-#{@vz.credits_sisu}
+#{@bits.credits_sisu}
 <a name="bottom" id="bottom"></a>
-<a name="down" id="down"></a>
 <a name="end" id="end"></a>
-<a name="finish" id="finish"></a>
-<a name="stop" id="stop"></a>
-<a name="credits" id="credits"></a>
 </div></div>
 }
     end
     def navigation_band(segtocband,seg_table_top_control) #change name to navigation_band_banner
-      %{<table summary="segment navigation band with banner" bgcolor=#{@vz.color_band1} width="100%"><tr>
+      %{<table summary="segment navigation band with banner" bgcolor=#{the_color.band1} width="100%"><tr>
 <td width="20%" align="left">
 #{button_home}
 </td>
@@ -792,7 +767,7 @@ WOK
     def navigation_band_bottom(segtocband,seg_table_top_control) #change name to navigation_band_bannerless
       %{
 <div class="main_column">
-  <table summary="segment navigation band" bgcolor=#{@vz.color_band1} width="100%"><tr>
+  <table summary="segment navigation band" bgcolor=#{the_color.band1} width="100%"><tr>
   <td width="70%" align="center">
     #{doc_types}
   </td>
@@ -822,20 +797,20 @@ WOK
     end
     def head_seg
       rdf=SiSU_XML_Tags::RDF.new(@md)
-      %{#{doc_type}
+      %{<!DOCTYPE html>
+<html>
 <head>
+  <meta charset="utf-8">
   <title>
     #{@seg_name_html[@seg_name_html_tracker]} -
     #{@md.html_title}
   </title>
-<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
+<meta http-equiv="Content-Type" content="text/html;charset=utf-8">
 #{rdf.metatag_html}
 #{@stylesheet.css_head_seg}
 </head>
-#{@vz.color_body}
-<a name="top" id="top"></a>
-<a name="up" id="up"></a>
-<a name="start" id="start"></a>}
+<body lang="#{@md.opt.lng}">
+<a name="top" id="top"></a>}
     end
     def title_banner(title,subtitle,creator)
       %{
@@ -851,8 +826,8 @@ WOK
   </p>
   <p class="tiny">
     copy @
-    <a href="#{@vz.url_home}">
-      #{@vz.txt_home}
+    <a href="#{the_url.home}">
+      #{the_text.txt_home}
     </a>
   </p>
 </div>
@@ -864,8 +839,8 @@ WOK
       super(md)
     end
     def toc_owner_details
-      %{#{@vz.margin_txt_3}
-#{@vz.paragraph_font_small}
+      %{#{the_margin.txt_3}
+#{the_font.paragraph_font_small}
   <a href="#owner.details">
     Owner Details
     <font size="1" color="#777777">
@@ -873,11 +848,11 @@ WOK
     </font>
   </a>
   </font>
-#{@vz.table_close}}
+#{the_table_close}}
     end
   end
   class FormatTextObject
-    @vz=SiSU_Viz::Defaults.new
+    include SiSU_Parts_HTML
     attr_accessor :md,:t_o,:txt,:ocn,:format,:table,:link,:linkname,:paranum,:p_num,:headname,:banner,:url
     def initialize(md,t_o)
       @md,@t_o=md,t_o
@@ -910,7 +885,6 @@ WOK
         @txt=@txt.gsub(/#{Mx[:mk_o]}[-~]##{Mx[:mk_c]}/,'')
       end
       @p_num=ParagraphNumber.new(@md,@ocn)
-      @vz=SiSU_Viz::Defaults.new
     end
     def nametags_scroll(dob)
       tags=''
@@ -929,15 +903,9 @@ WOK
       and dob.tags.length > 0 # insert tags "hypertargets"
         dob.tags.each do |t|
           t=t.gsub(/[^a-z0-9._-]/,'') #use for all html tags? consider limiting to strict? or implementing earlier
-          if @make.build.html_strict?
-            tags=(t =~/^[#{Mx[:ocn_id_char]}]?[0-9.]+$/) \
-            ? tags             #check what can be sorted in ao
-            : (tags << %{<a name="#{t}" ></a>})
-          else
-            tags=(t =~/^[#{Mx[:ocn_id_char]}][0-9.]+$/) \
-            ? tags             #check what can be sorted in ao
-            : (tags << %{<a name="#{t}" ></a>})
-          end
+          tags=(t =~/^[0-9.]+$/) \
+          ? tags             #check what can be sorted in ao
+          : (tags << %{<a name="#{t}" ></a>})
         end
       end
       tags
@@ -1030,7 +998,7 @@ WOK
     end
     def heading_normal(tag,attrib)
       section_break=(tag=~/h[1-5]/) \
-      ? '<br /><hr width=90% /><br />'
+      ? '<br><hr width=90% /><br>'
       : ''
       %{#{section_break}
 <div class="substance">
@@ -1065,6 +1033,9 @@ WOK
     def heading_body6
       heading_normal('h6','norm')
     end
+    def heading_body7
+      heading_normal('h7','norm')
+    end
     def title_heading(tag,attrib)
       cl=(@make.build.html_minitoc?) \
       ? 'content'
@@ -1141,21 +1112,21 @@ WOK
       end
     end
     def bold_para
-      %{#{@vz.margin_txt_0}
+      %{#{the_margin.txt_0}
   <p class="bold">
     #{@txt}
   </p>
-#{@vz.margin_num_css}
+#{the_margin.num_css}
   &nbsp;&nbsp;&nbsp;
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def bold_heading
       %{<p class="bold">
     #{@txt}
   </p>
-#{@vz.margin_num_css}
+#{the_margin.num_css}
   &nbsp;&nbsp;&nbsp;
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def toc_head_copy_at
       %{<p class="center">#{@txt}</p>\n}
@@ -1173,61 +1144,12 @@ WOK
   class FormatScroll < FormatTextObject
     def initialize(md,txt)
       super(md,txt)
-      @vz=SiSU_Viz::Defaults.new
     end
   end
   class FormatSeg < FormatTextObject
     def initialize(md,txt)
       super(md,txt)
     end
-    def navigation_toc_lev1_advert
-      %{#{@banner.home_button}\n
-<center>
-#{@txt}
-#{@two}
-</a></center><p />}
-    end
-    def navigation_toc_lev1
-      %{#{@banner.nav_toc}}
-    end
-    def navigation_toc_lev2                                                      #change bold use css
-      %{<p />
-<table summary="navigation segment level 2">
-<tr><td width ="20">
-</td>
-<td>
-  <font size="3" #{@vz.font_face}>
-    <b>#{@txt}</b>
-  </font>
-  </p>
-#{@vz.table_close}}
-    end
-    def navigation_toc_lev3                                                      #change bold use css
-      %{<p />
-<table summary="navigation segment level 3">
-<tr><td width ="20">
-</td>
-<td>
-  <font size="3" #{@vz.font_face}>
-    <b>#{@txt}</b>
-  </font>
-  </p>
-#{@vz.table_close}}
-    end
-    def navigation_toc_lev4
-      %{<table summary="navigation segment level 4">
-<tr><td width ="80">
-</td>
-<td>
-<p>
-  #{@txt}
-</p>
-#{@vz.table_close}}
-    end
-    def navigation_toc_lev5
-    end
-    def navigation_toc_lev6
-    end
     def endnote_seg_body(fn='')  #FIX                                                #url construction keep within single line... BUG WATCH 200408
       fn='doc' if fn.to_s.empty? #you may wish to reconsider, sends to 'doc' where no segment info
       %{
@@ -1265,6 +1187,9 @@ WOK
     def subtoc_lev6
       subtoc_lev('h6','subtoc') if @txt
     end
+    def subtoc_lev7
+      subtoc_lev('h7','subtoc') if @txt
+    end
     def heading_sub(tag,attrib)
       @txt=@txt.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
       %{
@@ -1299,7 +1224,7 @@ WOK
 <p class="bold">
   #{@txt}
 </p>
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def navigation_heading5
       %{<p class="bold">
@@ -1357,6 +1282,9 @@ WOK
     def lev6
       lev('h6','toc')
     end
+    def lev7
+      lev('h7','toc')
+    end
     def strip_endnotes(txt)
       txt=txt.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
       txt
@@ -1389,6 +1317,10 @@ WOK
       @txt=strip_endnotes(@txt)
       lev('h6','minitoc')
     end
+    def mini_lev7
+      @txt=strip_endnotes(@txt)
+      lev('h7','minitoc')
+    end
     def mini_lev0 #docinfo
       lev('h1','minitoc')
     end
