@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/html_promo.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/html_promo.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,7 +58,7 @@
 
 =end
 module SiSU_HTML_Promo
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   class Ad
     def initialize(md)
@@ -69,7 +66,6 @@ module SiSU_HTML_Promo
       @env=SiSU_Env::InfoEnv.new(@md.fns,@md)
       @rc=SiSU_Env::GetInit.new.sisu_yaml.rc
       @ad=SiSU_Env::GetInit.new.ads
-      @vz=SiSU_Viz::Defaults.new
       @flag=@env.widget.promo?
       @make=SiSU_Env::ProcessingSettings.new(@md)
     end
@@ -100,8 +96,6 @@ module SiSU_HTML_Promo
       && @flag[:ad]
         ads=if @md.promo && @md.promo.length > 0           #promo set in document
           promo_array=@md.promo
-        elsif @flag[:sk]                                   #promo set
-          promo_array=@vz.widget_promo
         elsif @flag[:rc]                                   #promo set in rc file
           promo_array=if @rc['html']['promo'].is_a?(String)
             @rc['html']['promo'].split(/[,;]\s*/)
@@ -148,7 +142,7 @@ module SiSU_HTML_Promo
         @prod['form'] ? %{<p class="pane">#{@prod['form']}</p>} : ''
       end
       def nick
-        @prod['nick'] ? %{(#{@prod['nick']})<br />} : ''
+        @prod['nick'] ? %{(#{@prod['nick']})<br>} : ''
       end
       def update
         @prod['update'] ? %{<p class="pane">Updated: #{@prod['update']}</p>} : ''
@@ -189,7 +183,7 @@ module SiSU_HTML_Promo
         else nil
         end
         form=if action
-          '<br />' + @env.widget.search_form('hyperestraier',action,'',table)
+          '<br>' + @env.widget.search_form('hyperestraier',action,'',table)
         else ''
         end
         form
@@ -211,7 +205,7 @@ module SiSU_HTML_Promo
         end
       end
       def image
-        @prod['image'] ? %{<img border="0" src="../_sisu/image/#{@prod['image']}" /><br />} : ''
+        @prod['image'] ? %{<img border="0" src="../_sisu/image/#{@prod['image']}" /><br>} : ''
       end
       def url_link
         @url_=if @prod['url'] =~/https?:/
@@ -299,7 +293,7 @@ module SiSU_HTML_Promo
     def output_form_sponsor(type,id)
       cell=cell(@ad[:promo][type][id],prod_id)
       <<-WOK
-<br />
+<br>
 #{cell.site_link}
 #{cell.blurb}
 #{cell.links}
@@ -309,7 +303,7 @@ module SiSU_HTML_Promo
       prod_id=id.gsub(/id_/,'')
       cell=cell(@ad[:promo][type][id],prod_id)
        <<WOK
-<br />
+<br>
 #{cell.site_link}
 #{cell.author}
 #{cell.year}
@@ -333,7 +327,7 @@ WOK
       prod_type=((id=~/id_(?:[0-9x]){10,13}/i) ? 'isbn' : 'id')
       id_detail=%{<p class="pane">#{prod_type}: #{prod_id}</p>}
        <<WOK
-<br />
+<br>
 #{cell.site_link}
 #{cell.author}
 #{cell.year}
@@ -349,7 +343,7 @@ WOK
       prod_id=id.gsub(/id_/,'')
       cell=cell(@ad[:promo][type][id],prod_id)
        <<WOK
-<br />
+<br>
 #{cell.site_link}
 #{cell.editor}
 #{cell.issn}
@@ -366,7 +360,7 @@ WOK
       cell=cell(@ad[:promo][type][id],prod_id)
 #translate date (dd month yyyy) from 2007-03-04 and ruby conversion
        <<WOK
-<br />
+<br>
 #{cell.site_link}
 #{cell.date}
 #{cell.location}
