@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/html_scroll.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/html_scroll.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -68,7 +65,6 @@ module SiSU_HTML_Scroll
   class Scroll
     def initialize(md='',data='',endnotes='')
       @md,@data,@endnotes=md,data,endnotes
-      @vz=SiSU_Viz::Defaults.new
     end
     def songsheet
       begin
@@ -76,7 +72,7 @@ module SiSU_HTML_Scroll
         scr[:tails]=SiSU_HTML_Scroll::Scroll.new(@md).tails
         scr
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -88,11 +84,13 @@ module SiSU_HTML_Scroll
       @rcdc=false
       @scr={ body: [], metadata: [], owner_details: [] }
       data.each do |dob|
-        dob.obj=dob.obj.gsub(/#{@md.file.output_path.html_seg.rel_image}/m,@md.file.output_path.html_scroll.rel_image)
+        dob.obj=dob.obj.gsub(/#{@md.file.output_path.html_seg.rel_image}/m,
+          @md.file.output_path.html_scroll.rel_image)
         if defined? dob.name and dob.name =~/^meta/ \
         and dob.obj =~/Document Information/
-          dob.obj=dob.obj.gsub(/(Document Information(?: \(metadata\))?)/,
-            '\1<a name="docinfo"></a>')
+          dob.obj=dob.obj.
+            gsub(/(Document Information(?: \(metadata\))?)/,
+              '\1<a name="docinfo"></a>')
         end
         if dob.obj =~/^Metadata$/ \
         and dob.lv =='B'
@@ -108,7 +106,8 @@ module SiSU_HTML_Scroll
           gsub(/href="#{Xx[:segment]}/m,'href="')
         if dob.obj !~/(^#{Rx[:meta]}|#{Mx[:br_eof]})/
           unless dob.is ==:code
-            dob.obj=dob.obj.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
+            dob.obj=dob.obj.
+              gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
           end
           if defined? dob.ocn
             @p_num=SiSU_HTML_Format::ParagraphNumber.new(@md,dob.ocn)
@@ -129,10 +128,12 @@ module SiSU_HTML_Scroll
               sto.heading_body5
             elsif dob.ln==6
               sto.heading_body6
+            elsif dob.ln==7
+              sto.heading_body7
             end
           elsif dob.is==:break \
           and dob.from==:markup
-            '<br /><hr width=90% /><br />'
+            '<br><hr width=90% /><br>'
           elsif dob.is==:heading_insert
             x=if dob.ln==0
               unless dob.obj.empty?
@@ -162,7 +163,8 @@ module SiSU_HTML_Scroll
             elsif dob.ln==4 \
             and dob.obj=='Index'
               sto.heading_body4
-              book_idx=SiSU_Particulars::CombinedSingleton.instance.get_idx_html(@md.opt).html_idx
+              book_idx=SiSU_Particulars::CombinedSingleton.
+                instance.get_idx_html(@md.opt).html_idx
               book_idx.each do |y| #takes book index prepared for segments & strips segment identifying info
                 y.gsub!(/<a href="\S+?\.html#(\d+)">(\1(?:-\d+)?)<\/a>/,
                   '<a href="#\1">\2</a>')
@@ -176,6 +178,10 @@ module SiSU_HTML_Scroll
               unless dob.obj.empty?
                 sto.heading_body6
               end
+            elsif dob.ln==7
+              unless dob.obj.empty?
+                sto.heading_body7
+              end
             end
           elsif dob.is==:para
             if dob.indent \
@@ -222,7 +228,9 @@ module SiSU_HTML_Scroll
     def tails
       scr_tail=[]
       format_head_scroll=SiSU_HTML_Format::HeadToc.new(@md)
-      scr_tail << format_head_scroll.scroll_tail << format_head_scroll.html_close
+      scr_tail \
+      << format_head_scroll.scroll_tail \
+      << format_head_scroll.html_close
       scr_tail
     end
   end
