@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/html_table.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/html_table.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,9 +58,10 @@
 
 =end
 module SiSU_HTML_Table
-  require_relative 'defaults'                           # defaults.rb
-  require_relative 'xhtml_table.rb'                     # xhtml_table.rb
-  class TableHTML <SiSU_XHTML_Table::TableXHTML
+  require_relative 'xhtml_table'                         # xhtml_table.rb
+  require_relative 'html_parts'                          # html_parts.rb
+  class TableHTML < SiSU_XHTML_Table::TableXHTML
+    include SiSU_Parts_HTML
   end
 end
 __END__
