@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/manpage_format.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/manpage_format.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,9 +58,8 @@
 
 =end
 module SiSU_ManpageFormat
-  require_relative 'param'                              # param.rb
+  require_relative 'dp'                                 # dp.rb
     include SiSU_Param
-  include SiSU_Viz
   class ParagraphNumber
     def initialize(paranum)
       @paranum=/(\d+)/m.match(paranum)[1]
@@ -83,7 +79,6 @@ module SiSU_ManpageFormat
       @md,@dob=md,dob
       rgx=/#{Mx[:en_a_o]}[\d*+]+\s+(.+?)#{Mx[:en_a_c]}/
       @dob.obj.gsub!(rgx,'\1') if @dob.obj =~rgx
-      @vz=SiSU_Viz::Defaults.new
     end
     def scr_endnote_body
       "<endnote>#{@dob.obj}</endnote> "
