@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/rexml.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/rexml.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -63,20 +60,23 @@
 module SiSU_Rexml
   # load XML file for REXML parsing
   begin
-    require 'rexml/document' if FileTest.directory?("#{Config::CONFIG['rubylibdir']}/rexml") #Config::CONFIG['sitedir']
+    require 'rexml/document' \
+      if FileTest.directory?("#{Config::CONFIG['rubylibdir']}/rexml") #Config::CONFIG['sitedir']
   rescue LoadError
-    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('rexml/document NOT FOUND (LoadError)')
+    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+      error('rexml/document NOT FOUND (LoadError)')
   end
-  require_relative 'param'                              # param.rb
+  require_relative 'dp'                                 # dp.rb
     include SiSU_Param
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
-  include SiSU_Viz
   class Rexml
     begin
-      require 'rexml/document' if FileTest.directory?("#{Config::CONFIG['rubylibdir']}/rexml") #Config::CONFIG['sitedir']
+      require 'rexml/document' \
+        if FileTest.directory?("#{Config::CONFIG['rubylibdir']}/rexml") #Config::CONFIG['sitedir']
     rescue LoadError
-      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('rexml/document NOT FOUND (LoadError)')
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+        error('rexml/document NOT FOUND (LoadError)')
     end
     def initialize(md,fno)
       @md,@fno=md,fno
@@ -130,7 +130,7 @@ module SiSU_Rexml
           exit
         end
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
