@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/se_file_op.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/se_file_op.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -148,6 +145,10 @@ module SiSU_Info_File
         @env.processing_path.tune + '/' \
           + @fns + '.marshal_tune'
       end
+      def xhtml_tune
+        @env.processing_path.tune + '/' \
+          + @fns + '.marshal_tune'
+      end
       self
     end
     def write_file_processing
@@ -188,7 +189,7 @@ module SiSU_File_Op
         @md,@fno=md,fno
         @env=SiSU_Env::InfoEnv.new(@md.fns)
       rescue
-        SiSU_Screen::Ansi.new(md.opt.cmd,$!,$@).rescue do
+        SiSU_Screen::Ansi.new(md.opt.selections.str,$!,$@).rescue do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
