@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/se_info_env.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/se_info_env.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -63,6 +60,7 @@
 @@current_document=Dir.pwd #nil #''
 module SiSU_Info_Env
   require_relative 'se_envcall'                            # se_envcall.rb
+  require_relative 'html_parts'                            # html_parts.rb
   begin
     require 'singleton'
     require 'fileutils'
@@ -77,7 +75,8 @@ module SiSU_Info_Env
       require 'fileutils'
         include FileUtils
     rescue LoadError
-      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('pathname or fileutils NOT FOUND (LoadError)')
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+        error('pathname or fileutils NOT FOUND (LoadError)')
     end
     attr_accessor :filename,:sys,:home,:hostname,:user,:env,:rc,:www,:fnb,:fnn,:fnt,:flv,:webserv_path,:stub_pwd,:base_markup_dir_stub,:stub_src,:webserv_host_cgi,:webserv_port_cgi,:processing,:processing_git,:etc,:yamlrc_dir
     @@image_flag,@@local_image=true,true   #warning on @@image_flag
@@ -575,7 +574,7 @@ module SiSU_Info_Env
     def widget #needs (md) #move
       @rc=SiSU_Env::GetInit.new.sisu_yaml.rc
       @ad=SiSU_Env::GetInit.new.ads
-      @vz=SiSU_Viz::Defaults.new
+      @html_bits=SiSU_Proj_HTML::Bits.new
       @flag={
         ad: false,
         md: false,
@@ -583,13 +582,14 @@ module SiSU_Info_Env
         rc: false
       }
       def promo?
-        @flag[:ad]=if @md.flag_promo && @ad[:flag_promo]
+        @flag[:ad]=if @md.flag_promo \
+        && @ad[:flag_promo]
           @flag[:md]=true
           true
-        elsif defined? @vz.widget_promo \
-        and not @vz.widget_promo.nil? \
-        and @vz.widget_promo.is_a?(Array) \
-        and @vz.widget_promo.length > 0
+        elsif defined? @html_bits.widget_promo \
+        and not @html_bits.widget_promo.nil? \
+        and @html_bits.widget_promo.is_a?(Array) \
+        and @html_bits.widget_promo.length > 0
           @flag[:sk]=true
           true
         elsif defined? @rc['html']['promo'] \
@@ -612,8 +612,8 @@ module SiSU_Info_Env
             and @rc['search'][type]['action'] =~/https?:\/\//
               flag=if promo?[:ad]
                 false
-              elsif defined? @vz.widget_search \
-              and @vz.widget_search==true
+              elsif defined? @html_bits.widget_search \
+              and @html_bits.widget_search==true
                 true
               elsif defined? @rc['search'][type]['flag'] \
               and @rc['search'][type]['flag']==true
@@ -638,8 +638,8 @@ module SiSU_Info_Env
             and @rc['search'][type]['db'] =~/\S+/
               flag=if promo?[:ad]
                 false
-              elsif defined? @vz.widget_search \
-              and @vz.widget_search==true
+              elsif defined? @html_bits.widget_search \
+              and @html_bits.widget_search==true
                 true
               elsif defined? @rc['search'][type]['flag'] \
               and @rc['search'][type]['flag']==true
@@ -758,7 +758,7 @@ WOK
     end
     def widget_static
       @rc=SiSU_Env::GetInit.new.sisu_yaml.rc
-      @vz=SiSU_Viz::Defaults.new
+      @html_bits=SiSU_Proj_HTML::Bits.new
       @flag={ ad: false, md: false, sk: false, rc: false }
       def search?
         flag=if defined? @rc['search'] \
@@ -767,8 +767,8 @@ WOK
         and @rc['search']['sisu']['action'] =~/https?:\/\// \
         and defined? @rc['search']['sisu']['db'] \
         and @rc['search']['sisu']['db'] =~/\S+/
-          flag=if defined? @vz.widget_search \
-          and @vz.widget_search==true
+          flag=if defined? @html_bits.widget_search \
+          and @html_bits.widget_search==true
             true
           elsif defined? @rc['search']['sisu']['flag'] \
           and @rc['search']['sisu']['flag']==true
@@ -789,8 +789,8 @@ WOK
         and @rc['search']['sisu']['db'] =~/\S+/ \
         and defined? @rc['search']['sisu']['db'] \
         and @rc['search']['sisu']['db'] =~/\S+/
-          flag=if defined? @vz.widget_search \
-          and @vz.widget_search==true
+          flag=if defined? @html_bits.widget_search \
+          and @html_bits.widget_search==true
             true
           elsif defined? @rc['search']['sisu']['flag'] \
           and @rc['search']['sisu']['flag']==true
@@ -1634,7 +1634,7 @@ WOK
         http=http.strip
       end
       def webserv_base_cgi(opt=nil)    #web url for local webserv (localhost, or hostname)
-        http=if opt.mod.inspect =~/--webserv-(?:cgi|db|search)[=-]["']?(\S+)["']+/
+        http_cgi=if opt.selections.str =~/--webserv-(?:cgi|db|search)[=-]["']?(\S+)["']+/
           m=$1
           (m=~/http\/\/:/) ? m : %{http://#{m}}
         elsif defined? @rc['webserv_cgi']['host'] \
@@ -1642,7 +1642,7 @@ WOK
           http=((@rc['webserv_cgi']['host'] =~ /https?:\/\//) ? '' : 'http://')
           if port.webserv_port_cgi(opt)
             http + @rc['webserv_cgi']['host'] + ':' \
-              + port.webserv_port_cgi(opt)
+            + port.webserv_port_cgi(opt).to_s
           else
             http + @rc['webserv_cgi']['host']
           end
@@ -1650,11 +1650,11 @@ WOK
           http=((webserv_host_base=~/https?:\/\//) ? '' : 'http://')
           if port.webserv_port_cgi(opt)
             http + webserv_host_base + ':' \
-              + port.webserv_port_cgi(opt)
-          else "#{http}#{webserv_host_base}"
+            + port.webserv_port_cgi(opt).to_s
+          else http + webserv_host_base
           end
         end
-        http=http.strip
+        http_cgi=http_cgi.strip
         #%q{http://#{ENV['HTTP_HOST']}}
       end
       def webrick #must have a port    #REMOVE
@@ -1666,12 +1666,13 @@ WOK
             'https://'
           else defaults
           end
-          "#{http}#{@rc['webserv_cgi']['host']}"
+          http + @rc['webserv_cgi']['host']
         elsif webserv_host_base \
         and webserv_host_base.is_a?(String)
-          http + webserv_host_base
+          webserv_host_base
         else
-          http + 'localhost'
+          #http + 'localhost'
+          'localhost'
         end
       end
       def webserv                      #web url for local webserv (localhost, or hostname)
@@ -1708,7 +1709,7 @@ WOK
         end
       end
       def webserv_files_from_db(opt=nil) #sort this out, messy
-        if opt.mod.inspect =~/--webserv-output[=-]["']?(\S+)["']+/
+        if opt.selections.str =~/--webserv-output[=-]["']?(\S+)["']+/
           m=$1
           (m=~/(?:http|file\/)\/\/:/) ? m : %{http://#{m}}
         else
@@ -1729,10 +1730,10 @@ WOK
         #%q{http://#{ENV['HTTP_HOST']}/cgi-bin}
       end
       def cgi_sample_search_form_name(opt=nil)
-        if opt.mod.inspect \
+        if opt.selections.str \
         =~/--(?:cgi-)?search-form-name[=-]["']?(\S+?\.cgi)/
           $1
-        elsif not opt.mod.inspect =~/--db[=-]["']?sqlite/ \
+        elsif not opt.selections.str =~/--db[=-]["']?sqlite/ \
         and defined? @rc['search'] \
         and defined? @rc['search']['sisu'] \
         and defined? @rc['search']['sisu']['action'] \
@@ -1740,7 +1741,7 @@ WOK
           /(?:https?:\/\/\S+?)\/([^\/]+?\.cgi)$/.
             match(@rc['search']['sisu']['action'])[1]
         else
-          (opt.mod.inspect =~/--db[=-]["']?sqlite/) \
+          (opt.selections.str =~/--db[=-]["']?sqlite/) \
           ? "#{Db[:name_prefix_db]}sqlite.cgi" \
           :  "#{Db[:name_prefix_db]}pg.cgi"
         end
@@ -1783,12 +1784,12 @@ WOK
           path.image_source_include
         else
           if @@local_image==true
-            cmd=@cmd ? @cmd : ''
+            cmd=@md.opt.selections.str ? @md.opt.selections.str : ''
             SiSU_Screen::Ansi.new(
               cmd,
               "WARNING - no local image directory or images:",
               defaults[:image_local]
-            ).warn unless cmd =~/q/
+            ).warn unless @md.opt.act[:quiet][:set]==:on
             @@local_image=false
           end
           url.images
@@ -1813,7 +1814,7 @@ WOK
               @cmd,
               'WARNING - image directory for external images or no such images:',
               :image_external
-            ).warn unless @cmd =~/q/
+            ).warn unless @md.opt.act[:quiet][:set]==:on
             @@local_image=false
           end
           url.images_external
@@ -1827,15 +1828,14 @@ WOK
     def port
       def webrick_port
         if @md \
-        and @md.opt.cmd.inspect=~/-F/ \
-        and @md.opt.mod.inspect=~/port=(\d+)/
+        and @md.opt.act[:sample_search_form][:set]==:on \
+        and @md.opt.selections.str=~/port=(\d+)/
            $1
         else
           if defined? @rc['webserv_cgi']['port']
             if @rc['webserv_cgi']['port'].nil? \
-            and (defined? @md.opt.mod \
-            and not @md.opt.mod.nil? \
-            and @md.opt.mod.inspect=~/webrick/)
+            and (defined? @md.opt.selections \
+            and @md.opt.selections.str=~/webrick/)
               defaults[:webserv_port_cgi]
             elsif not @rc['webserv_cgi']['port'].nil?
               @rc['webserv_cgi']['port']
@@ -1847,29 +1847,28 @@ WOK
       end
       def webserv_port_cgi(opt=nil)
         port=if opt \
-        and opt.cmd.inspect=~/-F/ \
-        and opt.mod.inspect=~/port=(\d+)/
+        and opt.act[:sample_search_form][:set]==:on \
+        and opt.selections.str=~/port[=-](\d+)/
            $1
         else
           port=if defined? @rc['webserv_cgi']['port']
             if @rc['webserv_cgi']['port'].nil? \
-            and (defined? opt.mod \
-            and not opt.mod.nil? \
-            and opt.mod.inspect=~/webrick/)
+            and (defined? opt.selections \
+            and opt.selections.str=~/webrick/)
               defaults[:webserv_port_cgi]
             elsif not @rc['webserv_cgi']['port'].nil?
               @rc['webserv_cgi']['port']
             else nil
             end
           else
-            if (defined? opt.mod \
-            and not opt.mod.nil? \
-            and opt.mod.inspect=~/webrick/)
+            if (defined? opt.selections \
+            and opt.selections.str=~/webrick/)
               defaults[:webserv_port_cgi]
             else nil
             end
           end
         end
+        port.to_s
       end
       self
     end
@@ -2145,7 +2144,7 @@ WOK
         SiSU_Screen::Ansi.new(
           '',
           '*WARN* file not found: ' + fns_pod
-        ).warn unless @cmd=~/q/
+        ).warn unless @md.opt.act[:quiet][:set]==:on
       end
       sisupod_processing_path
     end
@@ -2164,7 +2163,7 @@ WOK
       : (SiSU_Screen::Ansi.new(
           '',
           "*WARN* file not found: #{fns_pod}"
-        ).warn unless @cmd=~/q/)
+        ).warn unless @md.opt.act[:quiet][:set]==:on)
       sisupod_processing_path
     end
   end
