@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/se_processing.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/se_processing.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -309,7 +306,7 @@ module SiSU_Processing_Settings
         elsif env_rc.build.html_navigation_bar? ==:off
           false
         else
-          true
+          false
         end
       end
       def search_form?
@@ -465,61 +462,199 @@ module SiSU_Processing_Settings
 end
 module SiSU_Info_Processing_Flag
   class InfoProcessingFlag
-    attr_accessor :color,:cf_0,:cf_1,:cf_2,:cf_3,:cf_4,:cf_5
+    attr_accessor :color,:act_0,:act_1,:act_2,:act_3,:act_4,:act_5,:act_6,:act_7,:act_8,:act_9
     def initialize
       @rc=SiSU_Get_Init::GetInit.new.sisu_yaml.rc
     end
-    def color                          #processing flag shortcuts
+    def color                          #configurable processing flag shortcuts
       (defined? @rc['flag']['color']) \
       ? @rc['flag']['color']
       : false
     end
-    def cf_0                           #processing flag shortcuts
-      if defined? @rc['flag']['default'] \
-      and @rc['flag']['default'].is_a?(String)
-        @rc['flag']['default']
-      else #'-NQhewpotbxXdyYv'
-        '--digest --qrcode --text --html --epub --concordance --pdf --odf --docbook --xhtml --xml-sax --xml-dom --sqlite --manifest'
+    def act_0                           #configurable processing flag shortcuts
+      def default
+        '--manifest --digest --qrcode --text --html --epub --concordance --pdf --odf --docbook --xhtml --xml-sax --xml-dom --sqlite --verbose'
       end
-    end
-    def cf_1                           #processing flag shortcuts
-      if defined? @rc['flag']['i'] \
-      and @rc['flag']['i'].is_a?(String)
-        @rc['flag']['i']
-      else #'-Qhewpoty'
-        '--digest --qrcode --text --html --epub --concordance --pdf --manifest'
+      def str
+        if defined? @rc['flag']['act0'] \
+        and @rc['flag']['act0'].is_a?(String)
+          @rc['flag']['act0']
+        elsif defined? @rc['flag']['default'] \
+        and @rc['flag']['default'].is_a?(String)
+          @rc['flag']['default']
+        else default
+        end
       end
-    end
-    def cf_2                           #processing flag shortcuts
-      if defined? @rc['flag']['ii'] \
-      and @rc['flag']['ii'].is_a?(String)
-        @rc['flag']['ii']
-      else #'-NQhewpotbxXdy'
-        '--digest --qrcode --text --html --epub --concordance --pdf --odf --docbook --xhtml --xml-sax --xml-dom --manifest'
+      def arr
+        str.scan(/\S+/)
       end
+      self
     end
-    def cf_3                           #processing flag shortcuts
-      if defined? @rc['flag']['iii'] \
-      and @rc['flag']['iii'].is_a?(String)
-        @rc['flag']['iii']
-      else #'-NQhewpotbxXdyY'
-        '--digest --qrcode --text --html --epub --concordance --pdf --odf --docbook --xhtml --xml-sax --xml-dom --sqlite --manifest'
+    def act_1                           #configurable processing flag shortcuts
+      def default
+        '--manifest --text --html'
       end
-    end
-    def cf_4                           #processing flag shortcuts
-      if defined? @rc['flag']['iv'] \
-      and @rc['flag']['iv'].is_a?(String)
-        @rc['flag']['iv']
-      else #'-NQhewpotbxXdDyY --update'
-        '--digest --qrcode --text --html --epub --concordance --pdf --odf --docbook --xhtml --xml-sax --xml-dom --postresql --update --manifest'
+      def str
+        if defined? @rc['flag']['act1'] \
+        and @rc['flag']['act1'].is_a?(String)
+          @rc['flag']['act1']
+        elsif defined? @rc['flag']['i'] \
+        and @rc['flag']['i'].is_a?(String)
+          @rc['flag']['i']
+        else default
+        end
       end
+      def arr
+        str.scan(/\S+/)
+      end
+      self
     end
-    def cf_5                           #processing flag shortcuts
-      if defined? @rc['flag']['v'] \
-      and @rc['flag']['v'].is_a?(String)
-        @rc['flag']['v']
-      else #'-NQhewpotbxXdyYsS'
-        '--digest --qrcode --text --html --epub --concordance --pdf --odf --docbook --xhtml --xml-sax --xml-dom --sqlite --manifest --sisupod --source'
+    def act_2                           #configurable processing flag shortcuts
+      def default
+        '--manifest --text --html --epub --pdf'
+      end
+      def str
+        if defined? @rc['flag']['act2'] \
+        and @rc['flag']['act2'].is_a?(String)
+          @rc['flag']['act2']
+        elsif defined? @rc['flag']['ii'] \
+        and @rc['flag']['ii'].is_a?(String)
+          @rc['flag']['ii']
+        else default
+        end
+      end
+      def arr
+        str.scan(/\S+/)
+      end
+      self
+    end
+    def act_3                           #configurable processing flag shortcuts
+      def default
+        '--manifest --text --html --epub --pdf --concordance --qrcode'
+      end
+      def str
+        if defined? @rc['flag']['act3'] \
+        and @rc['flag']['act3'].is_a?(String)
+          @rc['flag']['act3']
+        elsif defined? @rc['flag']['iii'] \
+        and @rc['flag']['iii'].is_a?(String)
+          @rc['flag']['iii']
+        else default
+        end
+      end
+      def arr
+        str.scan(/\S+/)
+      end
+      self
+    end
+    def act_4                           #configurable processing flag shortcuts
+      def default
+        '--manifest --text --html --epub --pdf --concordance --qrcode --digest --odf --docbook'
+      end
+      def str
+        if defined? @rc['flag']['act4'] \
+        and @rc['flag']['act4'].is_a?(String)
+          @rc['flag']['act4']
+        elsif defined? @rc['flag']['iv'] \
+        and @rc['flag']['iv'].is_a?(String)
+          @rc['flag']['iv']
+        else default
+        end
+      end
+      def arr
+        str.scan(/\S+/)
+      end
+      self
+    end
+    def act_5                           #configurable processing flag shortcuts
+      def default
+        '--manifest --text --html --epub --pdf --concordance --qrcode --digest --odf --docbook --sqlite'
+      end
+      def str
+        if defined? @rc['flag']['act5'] \
+        and @rc['flag']['act5'].is_a?(String)
+          @rc['flag']['act5']
+        elsif defined? @rc['flag']['v'] \
+        and @rc['flag']['v'].is_a?(String)
+          @rc['flag']['v']
+        else default
+        end
+      end
+      def arr
+        str.scan(/\S+/)
+      end
+      self
+    end
+    def act_6                           #configurable processing flag shortcuts
+      def default
+        '--manifest --text --html --epub --pdf --concordance --qrcode --digest --odf --docbook --sqlite --xhtml --xml-sax --xml-dom'
+      end
+      def str
+        if defined? @rc['flag']['act6'] \
+        and @rc['flag']['act6'].is_a?(String)
+          @rc['flag']['act6']
+        else default
+        end
+      end
+      def arr
+        str.scan(/\S+/)
+      end
+      self
+    end
+    def act_7                           #configurable processing flag shortcuts
+      def default
+        '--manifest --text --html --epub --pdf --concordance --qrcode --digest --odf --docbook --sqlite --xhtml --xml-sax --xml-dom --source --sisupod'
+      end
+      def str
+        if defined? @rc['flag']['act7'] \
+        and @rc['flag']['act7'].is_a?(String)
+          @rc['flag']['act7']
+        else default
+        end
+      end
+      def arr
+        str.scan(/\S+/)
+      end
+      self
+    end
+    def act_8                           #configurable processing flag shortcuts
+      def default
+        '--manifest --text --html --epub --pdf --concordance --qrcode --digest --odf --docbook --xhtml --xml-sax --xml-dom --pg --update'
+      end
+      def str
+        if defined? @rc['flag']['act8'] \
+        and @rc['flag']['act8'].is_a?(String)
+          @rc['flag']['act8']
+        else default
+        end
+      end
+      def arr
+        str.scan(/\S+/)
+      end
+      self
+    end
+    def act_9                           #configurable processing flag shortcuts
+      def default
+        '--manifest --text --html --epub --pdf --concordance --qrcode --digest --odf --docbook --xhtml --xml-sax --xml-dom --pg --update --source --sisupod'
+      end
+      def str
+        if defined? @rc['flag']['act9'] \
+        and @rc['flag']['act9'].is_a?(String)
+          @rc['flag']['act9']
+        else default
+        end
+      end
+      def arr
+        str.scan(/\S+/)
+      end
+      self
+    end
+    def act_info
+      puts 'current "act" settings:'
+      acts=%w[ act_0 act_1 act_2 act_3 act_4 act_5 act_6 act_7 act_8 act_9 ]
+      acts.each_with_index do |m,i|
+        puts '--act-' + i.to_s + ' == ' \
+        + send(m).str
       end
     end
   end
