@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/sst_to_s_xml_sax.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/sst_to_s_xml_sax.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,13 +58,11 @@
 
 =end
 module SiSU_SimpleXML_ModelSax
-  require_relative 'particulars'                        # particulars.rb
+  require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
-  require_relative 'defaults'                           # defaults.rb
-    include SiSU_Viz
-  require_relative 'param'                              # param.rb
+  require_relative 'dp'                                 # dp.rb
     include SiSU_Param
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   require_relative 'ao_doc_str'                         # ao_doc_str.rb
   require_relative 'xml_shared'                         # xml_shared.rb
@@ -154,7 +149,6 @@ module SiSU_SimpleXML_ModelSax
       @@xml={ body: [], open: [], close: [], head: [] }
       def initialize(data='',particulars='')
         @data,@env,@md=data,particulars.env,particulars.md
-        @vz=SiSU_Viz::Defaults.new
         @regx=/^(?:#{Mx[:mk_o]}:p[bn]#{Mx[:mk_c]}\s*)?(?:#{Mx[:lv_o]}[1-9]:(\S*)#{Mx[:lv_c]})?(.+)/
         @tab="\t"
         if @md
@@ -395,8 +389,8 @@ WOK
         dir=SiSU_Env::InfoEnv.new
         @@xml[:head],@@xml[:body]=[],[]
         css=SiSU_Env::CSS_Select.new(@md).xml_sax
-        encoding=if @sys.locale =~/utf-?8/i; '<?xml version="1.0" encoding="UTF-8" standalone="no"?>'
-        else                                 '<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>'
+        encoding=if @sys.locale =~/utf-?8/i then '<?xml version="1.0" encoding="UTF-8" standalone="no"?>'
+        else                                     '<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>'
         end
         @@xml[:open] =<<WOK
 #{encoding}
