@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/texinfo.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/texinfo.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -62,9 +59,8 @@
 =end
 module SiSU_TexInfo
   require_relative 'html'                               # html.rb
-  require_relative 'param'                              # param.rb
+  require_relative 'dp'                                 # dp.rb
     include SiSU_Param
-  include SiSU_Viz
   #include Stamp ... needed removed arbitrarily 2005w05/1 (warnings about undefined flags)
   require_relative 'texinfo_format'                     # texinfo_format.rb
   include SiSU_TexInfoFormat
@@ -77,13 +73,11 @@ module SiSU_TexInfo
   @@tex_pattern_margin_number="\\\\marginpar.+?\s+"
   class Source
     include SiSU_Param
-    include SiSU_Viz
     include SiSU_TexInfo
     def initialize(opt)
       @opt=opt
       @md=SiSU_Param::Parameters.new(@opt).get
       @env=SiSU_Env::InfoEnv.new(@opt.fns)
-      @vz=SiSU_Viz::Defaults.new
     end
     def directories
       begin
@@ -132,7 +126,7 @@ module SiSU_TexInfo
         @marshalfile=SiSU_Env::InfoFile.new(@opt.fns).marshal.ao_content
         if FileTest.file?(@marshalfile)==true
           File.open(@marshalfile) { |f| @@tuned_file=Marshal.load(f)}
-          #tell.meta_verse_skipped if @opt.cmd =~/[vVM]/
+          #tell.meta_verse_skipped if @opt.selections.str =~/[vVM]/
         else
           tex_array=IO.readlines(@opt.fns,'')
           SiSU_Metaverse.songsheet(tex_array)
@@ -154,7 +148,6 @@ module SiSU_TexInfo
     def initialize(md,data)
       @md,@data=md,data
       @env=SiSU_Env::InfoEnv.new(@md.fns)
-      @vz=SiSU_Viz::Defaults.new
       @f=SiSU_Env::FileOp.new(@md)
     end
     def songsheet
@@ -418,7 +411,7 @@ module SiSU_TexInfo
         pwd=Dir.pwd
         case sfx
         when /(?:-|ssm\.)?sst$/
-          @env=SiSU_Env::InfoEnv.new(@md.fns,@md.opt.cmd)
+          @env=SiSU_Env::InfoEnv.new(@md.fns,@md.opt.selections.str)
           Dir.chdir(@env.processing_path.texi)
           texinfo=SiSU_Env::SystemCall.new("#{fnb}.texinfo")
           texinfo.makeinfo
