@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/texinfo_format.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/texinfo_format.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -62,9 +59,8 @@
 =end
 module SiSU_TexInfoFormat
   @@table_pg_break_counter=1
-  require_relative 'param'                              # param.rb
+  require_relative 'dp'                                 # dp.rb
     include SiSU_Param
-  include SiSU_Viz
   class Texinfo
     @@tex_1='\\\\~' #?? debug
     @@tabular="{tabular}"
@@ -78,7 +74,6 @@ module SiSU_TexInfoFormat
         p dob.class
         p caller
       end
-      @vz=SiSU_Viz::Defaults.new
     end
     def head
       t=Time.now
