@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/texpdf.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/texpdf.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -64,11 +61,11 @@ module SiSU_TeX
   begin
     require 'pstore'
   rescue LoadError
-    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('pstore NOT FOUND (LoadError)')
+    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+      error('pstore NOT FOUND (LoadError)')
   end
-  require_relative 'defaults'                           # defaults.rb
-    include SiSU_Viz
-  require_relative 'particulars'                        # particulars.rb
+  require_relative 'texpdf_parts'                        # texpdf_parts.rb
+  require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
   require_relative 'texpdf_format'                      # texpdf_format.rb
     include SiSU_TeX_Pdf
@@ -85,11 +82,11 @@ module SiSU_TeX
     begin
       require 'pstore'
     rescue LoadError
-      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('pstore NOT FOUND (LoadError)')
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+        error('pstore NOT FOUND (LoadError)')
     end
-    require_relative 'sysenv'                           # sysenv.rb
+    require_relative 'se'                               # se.rb
       include SiSU_Env
-    include SiSU_Viz
     require_relative 'ao'                               # ao.rb
       include SiSU_AO
     include SiSU_TeX
@@ -107,7 +104,7 @@ module SiSU_TeX
           Dir.mkdir(@env.processing_path.tex) unless FileTest.directory?(@env.processing_path.tex)
         end
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -148,7 +145,7 @@ module SiSU_TeX
           end
         end
         @md=@particulars.md
-        $flag=@md.opt.cmd                                                          #introduced to pass 0 for no object citation numbers... to texpdf_format
+        $flag=@md.opt.selections.str                                                          #introduced to pass 0 for no object citation numbers... to texpdf_format
         directories
                                                                                #% needed needs to be reprogrammed !!!
         ao_array=SiSU_AO::Source.new(@opt).get # ao file drawn here
@@ -158,7 +155,7 @@ module SiSU_TeX
         SiSU_TeX::Source::LaTeXtoPdf.new(@md,@particulars.env).latexrun_selective
         Dir.chdir(pwd)
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -180,7 +177,7 @@ module SiSU_TeX
         @@date=SiSU_Env::InfoDate.new
         @@flag={}
         $flag=1 #remove at some stage
-        SiSU_Env::Clear.new(@opt.cmd,@opt.fns).param_instantiate
+        SiSU_Env::Clear.new(@opt.selections.str,@opt.fns).param_instantiate
       end
     end
     private
@@ -194,7 +191,7 @@ module SiSU_TeX
         @texfilename=texfilename
         @@n_lpdf=@@n_lpdf+1
         tex_fn_base=@texfilename.gsub(/\.tex$/,'')
-        tell=SiSU_Screen::Ansi.new(@md.opt.cmd)
+        tell=SiSU_Screen::Ansi.new(@md.opt.selections.str)
         if @md.opt.act[:pdf_p][:set]==:on
           if (@md.opt.act[:verbose][:set]==:on \
           || @md.opt.act[:verbose_plus][:set]==:on \
@@ -204,13 +201,21 @@ module SiSU_TeX
               "#{papersize} portrait ->"
             ).dark_grey_title_hi
           end
-          cmd=SiSU_Env::SystemCall.new("#{tex_fn_base}.tex",'',@md.opt.cmd)
-          tell.grey_open if @md.opt.cmd =~/[MVv]/
+          cmd=SiSU_Env::SystemCall.new("#{tex_fn_base}.tex",'',@md.opt.selections.str)
+          if @md.opt.act[:verbose][:set]==:on \
+          || @md.opt.act[:verbose_plus][:set]==:on \
+          || @md.opt.act[:maintenance][:set]==:on
+            tell.grey_open
+          end
           if "#{tex_fn_base}" =~/\w+/ \
           and "#{papersize}" =~/\w+/
             2.times { |i| cmd.latex2pdf(@md,papersize) } #comment out to skip processing of latex portrait
           end
-          tell.p_off if @md.opt.cmd =~/[MVv]/
+          if @md.opt.act[:verbose][:set]==:on \
+          || @md.opt.act[:verbose_plus][:set]==:on \
+          || @md.opt.act[:maintenance][:set]==:on
+            tell.p_off
+          end
         end
         if @md.opt.act[:pdf_l][:set]==:on
           if (@md.opt.act[:verbose][:set]==:on \
@@ -221,7 +226,7 @@ module SiSU_TeX
               "#{papersize} landscape ->"
             ).dark_grey_title_hi
           end
-          cmd=SiSU_Env::SystemCall.new("#{tex_fn_base}.landscape.tex",'',@md.opt.cmd)
+          cmd=SiSU_Env::SystemCall.new("#{tex_fn_base}.landscape.tex",'',@md.opt.selections.str)
           if (@md.opt.act[:verbose][:set]==:on \
           || @md.opt.act[:verbose_plus][:set]==:on \
           || @md.opt.act[:maintenance][:set]==:on)
@@ -259,8 +264,16 @@ module SiSU_TeX
             FileUtils::cp(portrait_pdf,"#{@md.file.output_path.pdf.dir}/#{pdf_p}")
             FileUtils::rm(portrait_pdf)
           else
-            STDERR.puts "#{cX.fuchsia}pdf file not generated#{cX.off} <#{cX.blue}#{portrait_pdf.gsub(/.+?([^\/]+?\.pdf)$/,'\1')}#{cX.off}> (check texlive dependencies)"
             STDERR.puts "#{__FILE__}:#{__LINE__} NOT FOUND: #{portrait_pdf}" if @md.opt.act[:maintenance][:set]==:on
+            errmsg="pdf file not generated #{portrait_pdf.gsub(/.+?([^\/]+?\.pdf)$/,'\1')} (check texlive dependencies)"
+            if @md.opt.act[:no_stop][:set]==:on
+              SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                error("#{errmsg}, proceeding without pdf output (as requested)")
+            else
+              SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                error("#{errmsg}, STOPPING")
+              exit
+            end
           end
         end
         if @md.opt.act[:pdf_l][:set]==:on
@@ -268,8 +281,16 @@ module SiSU_TeX
             FileUtils::cp(landscape_pdf,"#{@md.file.output_path.pdf.dir}/#{pdf_l}")
             FileUtils::rm(landscape_pdf)
           else
-            STDERR.puts "#{cX.fuchsia}pdf file not generated#{cX.off} <#{cX.blue}#{landscape_pdf.gsub(/.+?([^\/]+?\.pdf)$/,'\1')}#{cX.off}> (check texlive dependencies)"
             STDERR.puts "#{__FILE__}:#{__LINE__} NOT FOUND: #{landscape_pdf}" if @md.opt.act[:maintenance][:set]==:on
+            errmsg="pdf file not generated #{landscape_pdf.gsub(/.+?([^\/]+?\.pdf)$/,'\1')} (check texlive dependencies)"
+            if @md.opt.act[:no_stop][:set]==:on
+              SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                error("#{errmsg}, proceeding without pdf output (as requested)")
+            else
+              SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                error("#{errmsg}, STOPPING")
+              exit
+            end
           end
         end
         if (@md.opt.act[:verbose][:set]==:on \
@@ -304,7 +325,15 @@ module SiSU_TeX
                         and File.size(texfile) > 0
                           #@tex_f_no+=1
                         else
-                          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error("\tzero file size #{@env.processing_path.tex}/#{texfile}")
+                          errmsg="zero file size #{@env.processing_path.tex}/#{texfile}"
+                          if @md.opt.act[:no_stop][:set]==:on
+                            SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                              error("#{errmsg}, proceeding without pdf output (as requested)")
+                          else
+                            SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                              error("#{errmsg}, STOPPING")
+                            exit
+                          end
                         end
                       end
                     end
@@ -357,13 +386,14 @@ module SiSU_TeX
           lst=Dir["*.{aux,log,out}"]
           lst.each {|file| File.unlink(file)} if lst
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
       end
     end
     class LaTeXcreate
+      include SiSU_Parts_TeXpdf
       @@tex_head={
         'a4'=>    { p: nil, l: nil },
         'a5'=>    { p: nil, l: nil },
@@ -380,9 +410,7 @@ module SiSU_TeX
         @data=@particulars.ao_array # ao file drawn here
         @st={ tex: {} }
         @tex_ml=SiSU_TeX_Pdf::UseTeX.new(@md)
-        @vz=SiSU_Viz::Defaults.new
         @dp=@@dp ||=SiSU_Env::InfoEnv.new.digest.pattern
-        @brace_url=SiSU_Viz::Defaults.new.url_decoration
         l=SiSU_Env::StandardiseLanguage.new(@md.opt.lng).language
         @language=l[:n]
         @translate=SiSU_Translate::Source.new(@md,@language)
@@ -414,13 +442,10 @@ module SiSU_TeX
           end
           if defined? @md.rights.all \
           and not @md.rights.all.empty?
-            rght=@md.rights #.author.dup #dup is necessary, else contents of :rights changed
-            sp_char=SiSU_TeX_Pdf::SpecialCharacters.new(@md,rght.copyright.all)
-            copymark=@md.author_copymark \
-            ? '{\begin{small}\copyright\end{small}} '
-            : ''
-            copymark='Copyright {\begin{small}\copyright\end{small}} '
-            copyright=sp_char.special_characters_safe.gsub(/^\s*Copyright \(C\)/, copymark)
+            sp_char=SiSU_TeX_Pdf::SpecialCharacters.new(@md,@md.rights.copyright.copyright_and_license.dup)
+            copymark='Copyright {\begin{small}{\copyright\end{small}} '
+           #copymark='Copyright {\begin{small}^{\copyright\end{small}} '
+            copyright=sp_char.special_characters_safe.gsub(/\s*Copyright \(C\)/, copymark)
             @@rights||="\n #{Tex[:backslash]*2}[3]\\ \\linebreak #{copyright}"
           end
           if defined? @md.notes.prefix_b \
@@ -438,7 +463,7 @@ module SiSU_TeX
           data=markup(data)
           output(data)
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         ensure
@@ -640,6 +665,8 @@ module SiSU_TeX
               tst.heading_level_2
             when 6
               tst.heading_level_3
+            when 7
+              tst.heading_level_4
             else dob
             end
           when :heading_insert
@@ -780,7 +807,7 @@ module SiSU_TeX
       end
       def markup(data)
         @tex_file=[]
-        home=@vz.txt_home.gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}|#{Mx[:br_paragraph]}|\\\\/,' - ') #no line splitting in heading neither html nor latex
+        home=the_text.txt_home.gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}|#{Mx[:br_paragraph]}|\\\\/,' - ') #no line splitting in heading neither html nor latex
         title=@md.title.full.gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}|#{Mx[:br_paragraph]}|\\\\/,' - ') #no line splitting in heading neither html nor latex
         @md.papersize_array.each do |ps|
           if @md.opt.act[:pdf_p][:set]==:on
