@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/plaintext_textile.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/plaintext_textile.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -62,15 +59,16 @@
 =end
 module SiSU_Txt_Textile
   require_relative 'ao'                                 # ao.rb
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   require_relative 'shared_metadata'                    # shared_metadata.rb
+  require_relative 'generic_parts'                      # generic_parts.rb
   require_relative 'txt_shared'                         # txt_shared.rb
   include SiSU_Param
-  include SiSU_Viz
   @@alt_id_count,@@alt_id_count,@@tablehead,@@number_of_cols=0,0,0,0
   @@tablefoot=''
   class Source
+    include SiSU_Parts_Generic
     def initialize(opt)
       @opt=opt
       unless @opt.fns =~/(.+?)\.(?:-|ssm\.)?sst$/
@@ -121,7 +119,7 @@ module SiSU_Txt_Textile
         #wrap_width=(defined? md.make.plaintext_wrap) ? md.make.plaintext_wrap : 78
         SiSU_Txt_Textile::Source::Scroll.new(md,ao_array,wrap_width).songsheet
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -129,16 +127,14 @@ module SiSU_Txt_Textile
     end
     private
     class Scroll <Source
-      require_relative 'defaults'                       # defaults.rb
-      require_relative 'txt_shared'                     # txt_shared.rb
-        include SiSU_TextUtils
+      include SiSU_Parts_Generic
+      include SiSU_TextUtils
       @@endnotes={ para: [], end: [] }
       def initialize(md,data,wrap_width)
         @md,@data,@wrap_width=md,data,wrap_width
         @env=SiSU_Env::InfoEnv.new(@md.fns)
-        @brace_url=SiSU_Viz::Defaults.new.url_decoration
         @tab="\t"
-        @@endnotes_=case md.opt.mod.inspect
+        @@endnotes_=case md.opt.selections.str
         when /--footnote/ then false
         when /--endnote/  then true
         else                   true
@@ -205,7 +201,6 @@ WOK
       end
       def plaintext_tail
 #       env=SiSU_Env::InfoEnv.new(@md.fns)
-        vz=SiSU_Viz::Defaults.new
         generator="Generated by: #{@md.sisu_version[:project]} #{@md.sisu_version[:version]} of #{@md.sisu_version[:date_stamp]} (#{@md.sisu_version[:date]})"  if @md.sisu_version[:version]
         lastdone="Last Generated on: #{Time.now}"
         rubyv="Ruby version: #{@md.ruby_version}"
@@ -227,7 +222,7 @@ at:
 * #{generator}
 * #{rubyv}
 * #{lastdone}
-* SiSU #{vz.url_sisu}
+* SiSU #{the_url.sisu_txt}
 WOK
       end
       def decorate
@@ -438,7 +433,7 @@ WOK
               gsub(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1').
               gsub(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,'\1 [link: <\2>]').
               gsub(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}image/,'\1 [link: local image]').
-              gsub(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,"#{@brace_url.txt_open}\\1#{@brace_url.txt_close}")
+              gsub(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,"#{the_text.url_open}\\1#{the_text.url_close}")
             extract_endnotes(dob)
             dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'[^\1]'). # endnote marker marked up
               gsub(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'[^\1]'). # endnote marker marked up
