@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/webrick.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/webrick.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -68,13 +65,13 @@ module SiSU_Webserv
       require 'webrick'
         include WEBrick
     rescue LoadError
-      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('time or webrick NOT FOUND (LoadError)')
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+        error('time or webrick NOT FOUND (LoadError)')
     end
-    require_relative 'sysenv'                             # sysenv.rb
+    require_relative 'se'                                 # se.rb
       include SiSU_Env
       include SiSU_Screen
     def initialize
-    begin                                                                          #%
       @cX=SiSU_Screen::Ansi.new('yes').cX
       @env=SiSU_Env::InfoEnv.new
       port=SiSU_Env::InfoPort.new
@@ -93,82 +90,14 @@ module SiSU_Webserv
       @week=Time.now.strftime(%{%Yw%W})
       puts "\n"
       @mount.each { |x,y|
-        puts "        #{@cX.cyan}#{x}#{@cX.off}\t#{@cX.grey}see#{@cX.off} #{@cX.blue}#{@host}:#{@port}#{x}/wb.cgi#{@cX.off} #{@cX.ruby}@#{@cX.off} #{@cX.blue}#{@host}:#{@port}#{x}/#{@cX.off}"
+        puts "  * #{@cX.blue}#{@host}:#{@port}#{x}/#{@cX.off}"
       }
-      puts "#{@cX.grey}"
-      wb_s2=[]
-                                                               #% writes file wb.cgi to shared directories ...
-                                                               #% wb_top
-      wb_top=%q(#!/usr/bin/env ruby
-      # * arch-tag: webrick info on environment, mounted directories, and contents of pwd
-      begin
-        require 'time'
-        require 'cgi'
-        require 'fcgi'
-      rescue LoadError
-        puts 'time, cgi or fcgi NOT FOUND (LoadError)'
-      end
-      ls=Dir.entries('./')
-      dir_contents=[]
-      ls.each { |x| dir_contents << "<a href=\"./#{x}/\">#{x}</a><br>" unless x =~/^(\.)+$/ }
-      dir_contents=dir_contents.sort.join(' ')
-      #host=ENV['HOSTNAME']
-      #host=%x{echo $HOSTNAME}
-      )
-      wb_s1=<<WOK
-
-  page=CGI.new "html3"
-  page.out {
-    page.html {
-      page.head { page.title {"#{@host} Webrick Report"} } +
-      page.body {
-        page.h1 {"Webrick #{@host}"} +
-        page.p {"Webrick is Ruby's built in webserver."} +
-        page.center {"Host name: " + page.b{"#{@host} "} + "(#{@host})  port: " + page.b{"#{@port}"}} +
-        page.center {"#{Time.now}"} +
-        page.center {"#{Time.now.strftime(%{%Yw%W})}"} +
-        page.p {''} +
-        page.p {''} +
-        page.p {page.b{"Webrick Served Directories: "}} +
-WOK
-                                                               #% wb_s2 (mounts)
-      @mount.each do |x,y| wb_s2 << <<WOK
-            page.p {page.b{'<a href="#{@host}:#{@port}#{x}/">#{x}</a> '} + '<a href="#{@host}:#{@port}#{x}/">#{@host}:#{@port}#{x}</a> (mounts: #{y}/)   <a href="#{@host}:#{@port}#{x}/wb.cgi">info (wb.cgi)</a>'} +
-WOK
-    end
-                                                               #% wb_end
-      wb_end=<<WOK
-        page.p {page.b{"Contents of PWD (see URL): "}} +
-        page.p {"#\{dir_contents}"}
-      }
-    }
-  }
-WOK
-      @mount.each { |x,y|                                      #% wb puts
-        puts y
-          filename=File.new("#{y}/wb.cgi",'w')
-          filename << wb_top
-          filename << wb_s1
-          filename << wb_s2
-          filename << wb_end
-          filename.close
-          FileUtils::chmod(0755,"#{y}/wb.cgi &") if FileTest.file?("#{y}/wb.cgi &")
-      }
-      puts "        #{@cX.off}"
-      #get=@argv.shift if @argv[0] =~/pwd/                      #% argv
       get=Dir.pwd
       brick(@port,get)
-    rescue
-      require_relative 'sysenv'                             # sysenv.rb
-      SiSU_Errors::Rescued.new($!,$@,'-W',nil).location do #fix
-        __LINE__.to_s + ':' + __FILE__
-      end
-    ensure
-    end
     end
     def brick(port,get='')
-      cgidir=if get=~/pwd/; Dir.pwd
-      else                  '/usr/lib/cgi-bin'  # @env.path.cgi
+      cgidir=if get=~/pwd/ then Dir.pwd
+      else                      '/usr/lib/cgi-bin'
       end
       port=SiSU_Env::InfoPort.new.webrick
       begin
@@ -191,6 +120,74 @@ WOK
       ensure
       end
     end
+    def wb_cgi
+      begin                                                                          #%
+        wb_s2=''
+                                                                 #% writes file wb.cgi to shared directories ...
+                                                                 #% wb_top
+        wb_top=%q(#!/usr/bin/env ruby
+        # * arch-tag: webrick info on environment, mounted directories, and contents of pwd
+        begin
+          require 'time'
+          require 'cgi'
+          require 'fcgi'
+        rescue LoadError
+          puts 'time, cgi or fcgi NOT FOUND (LoadError)'
+        end
+        ls=Dir.entries('./')
+        dir_contents=[]
+        ls.each { |x| dir_contents << "<a href=\"./#{x}/\">#{x}</a><br>" unless x =~/^(\.)+$/ }
+        dir_contents=dir_contents.sort.join(' ')
+        #host=ENV['HOSTNAME']
+        #host=%x{echo $HOSTNAME}
+        )
+        wb_s1=<<-WOK
+
+  page=CGI.new "html3"
+  page.out {
+    page.html {
+      page.head { page.title {"#{@host} Webrick Report"} } +
+      page.body {
+        page.h1 {"Webrick #{@host}"} +
+        page.p {"Webrick is Ruby's built in webserver."} +
+        page.center {"Host name: " + page.b{"#{@host} "} + "(#{@host})  port: " + page.b{"#{@port}"}} +
+        page.center {"#{Time.now}"} +
+        page.center {"#{Time.now.strftime(%{%Yw%W})}"} +
+        page.p {''} +
+        page.p {''} +
+        page.p {page.b{"Webrick Served Directories: "}} +
+        WOK
+                                                               #% wb_s2 (mounts)
+        @mount.each do |x,y| wb_s2 += <<-WOK
+          page.p {%{<a href="#{@host}:#{@port}#{x}/">#{x}</a> } +
+            %{<a href="#{@host}:#{@port}#{x}/">#{@host}:#{@port}#{x}</a> (mounts: #{y}/)   <a href="#{@host}:#{@port}#{x}/wb.cgi">info (wb.cgi)</a>}} +
+          WOK
+        end
+                                                               #% wb_end
+        wb_end=<<-WOK
+        page.p {page.b{"Contents of PWD (see URL): "}} +
+        page.p {"#\{dir_contents}"}
+      }
+    }
+  }
+        WOK
+        @mount.each { |x,y|                                      #% wb puts
+          puts y
+            filename=File.new("#{y}/wb.cgi",'w')
+            filename << wb_top
+            filename << wb_s1
+            filename << wb_s2
+            filename << wb_end
+            filename.close
+            FileUtils::chmod(0755,"#{y}/wb.cgi &") if FileTest.file?("#{y}/wb.cgi &")
+        }
+      rescue
+        SiSU_Errors::Rescued.new($!,$@,'-W',nil).location do #fix
+          __LINE__.to_s + ':' + __FILE__
+        end
+      ensure
+      end
+    end
   end
 ensure
 end
