@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/xhtml.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/xhtml.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,11 +58,9 @@
    ** Notes: tidy -xml scroll.xhtml >> index.tidy
 =end
 module SiSU_XHTML
-  require_relative 'defaults'                           # defaults.rb
-    include SiSU_Viz
-  require_relative 'particulars'                        # particulars.rb
+  require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   require_relative 'xml_shared'                         # xml_shared.rb
     include SiSU_XML_Munge
@@ -116,7 +111,7 @@ module SiSU_XHTML
         end
         SiSU_XHTML::Source::Songsheet.new(@particulars).song
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -140,7 +135,7 @@ module SiSU_XHTML
           end
           SiSU_Rexml::Rexml.new(@md,@file.place_file.xhtml.dir).xml if @md.opt.act[:maintenance][:set]==:on # test rexml parsing, comment out when not in use #debug
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         ensure
@@ -155,7 +150,6 @@ module SiSU_XHTML
       @@xml={ body: [], sisu: [], open: [], close: [], head: [] }
       def initialize(particulars)
         @env,@md,@ao_array=particulars.env,particulars.md,particulars.ao_array
-        @vz=SiSU_Viz::Defaults.new
         @tab="\t"
         @trans=SiSU_XML_Munge::Trans.new(@md)
         @sys=SiSU_Env::SystemCall.new
@@ -234,7 +228,7 @@ WOK
           end
           extract_endnotes(dob)
           dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>'). #footnote/endnote clean
-            gsub(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
+            gsub(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>')
           util=SiSU_TextUtils::Wrap.new(dob.obj,70)
           wrapped=util.line_wrap
           @@xml[:body] << if defined? dob.ocn
@@ -310,8 +304,8 @@ WOK
         @rcdc=false
         @level,@cont,@copen,@xml_contents_close=[],[],[],[]
         xml_head
-        (0..6).each { |x| @cont[x]=@level[x]=false }
-        (4..6).each { |x| @xml_contents_close[x]='' }
+        (0..7).each { |x| @cont[x]=@level[x]=false }
+        (4..7).each { |x| @xml_contents_close[x]='' }
         data.each do |dob|
           dob=@trans.char_enc.utf8(dob) if @sys.locale =~/utf-?8/i #% utf8
           dob=@trans.markup(dob)
@@ -337,6 +331,7 @@ WOK
                 when 4 then x.heading_body4
                 when 5 then x.heading_body5
                 when 6 then x.heading_body6
+                when 7 then x.heading_body7
                 end
               else
                 if dob.is ==:verse
@@ -371,8 +366,6 @@ WOK
                   format_text.scr_inden_ocn_e_no_paranum
                 end
               end
-              if dob.obj !~/#{@vz.margin_txt_0}|#{@vz.margin_txt_1}|#{@vz.margin_txt_2}/
-              end
             else #
             end
             dob.obj=dob.obj.gsub(/#{Mx[:pa_o]}:\S+#{Mx[:pa_c]}/,'') if dob.obj
@@ -391,7 +384,9 @@ WOK
         rdf=SiSU_XML_Tags::RDF.new(@md)
         @@xml[:head],@@xml[:body]=[],[]
         stylesheet=SiSU_Style::CSS_HeadInfo.new(@md,'xhtml').stylesheet
-        encoding=(@sys.locale =~/utf-?8/i) ? '<?xml version="1.0" encoding="UTF-8" standalone="no"?>' : '<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>'
+        encoding=(@sys.locale =~/utf-?8/i) \
+        ? '<?xml version="1.0" encoding="UTF-8" standalone="no"?>'
+        : '<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>'
         @@xml[:open] =<<WOK
 #{encoding}
 #{stylesheet.css_head_xml}
