@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/epub.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/epub.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -64,12 +61,13 @@ module SiSU_XHTML_EPUB2
   begin
     require 'pstore'
   rescue LoadError
-    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('pstore NOT FOUND (LoadError)')
+    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+      error('pstore NOT FOUND (LoadError)')
   end
-  require_relative 'particulars'                        # particulars.rb
+  require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
-  require_relative 'defaults'                           # defaults.rb
-    include SiSU_Viz
+  require_relative 'xml_shared'                         # xml_shared.rb
+    include SiSU_XML_Munge
   require_relative 'xhtml_table'                        # xhtml_table.rb
   require_relative 'xhtml_epub2_format'                 # xhtml_epub2_format.rb
     include SiSU_XHTML_EPUB2_Format
@@ -135,7 +133,7 @@ module SiSU_XHTML_EPUB2
         SiSU_XHTML_EPUB2::Source::Seg.new(@md,data).songsheet
         SiSU_XHTML_EPUB2::Source::Output.new(@md).songsheet
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -148,7 +146,7 @@ module SiSU_XHTML_EPUB2
             end
           end
         end
-        SiSU_Env::Clear.new(@opt.cmd,@opt.fns).param_instantiate
+        SiSU_Env::Clear.new(@opt.selections.str,@opt.fns).param_instantiate
         @@flag,@@scr,@@seg,@@seg_endnotes,@@seg_subtoc,@@seg_ad={},{},{},{},{},{}
         @@seg_total,@@tracker,@@loop_count,@@tablehead,@@number_of_cols=0,0,0,0,0
         @@seg_name,@@seg_name_html,@@seg_subtoc_array,@@seg_endnotes_array,@@segtocband,@@tablefoot=Array.new(7){[]}
@@ -161,7 +159,6 @@ module SiSU_XHTML_EPUB2
       def initialize(particulars)
         @particulars=particulars
         @md,@env=particulars.md,particulars.env
-        @vz=SiSU_Viz::Defaults.new
         @env,@css=particulars.env,SiSU_Style::CSS.new
       end
       def directories
@@ -213,7 +210,6 @@ module SiSU_XHTML_EPUB2
       @@firstseg=nil
       def initialize(md=nil,data='')
         @md,@data=md,data
-        @vz=SiSU_Viz::Defaults.new
         @epub=SiSU_XHTML_EPUB2_Format::HeadInformation.new(@md)
         @tell=SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set]) if @md
         @make=SiSU_Env::ProcessingSettings.new(@md)
@@ -268,6 +264,7 @@ module SiSU_XHTML_EPUB2
               lv_name='section_a' + @s_a_no.to_s
               @nav_no+=1
               @nav_no2=@nav_no
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[7]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[5]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[4]
@@ -275,7 +272,8 @@ module SiSU_XHTML_EPUB2
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[2]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[1]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[0]
-              @ncxo[0],@ncxo[1],@ncxo[2],@ncxo[3],@ncxo[4],@ncxo[5],@ncxo[6]=true,false,false,false,false,false,false
+              @ncxo[0],@ncxo[1],@ncxo[2],@ncxo[3],@ncxo[4],@ncxo[5],@ncxo[6],@ncxo[7]=
+                true,  false,   false,   false,   false,   false,   false,   false
               @epub.sections(dob_toc,lv_name)
               if @level_a_first_occurrence \
               && @make.build.toc?
@@ -293,13 +291,15 @@ module SiSU_XHTML_EPUB2
               lv_name='section_b' + @s_b_no.to_s
               @nav_no+=1
               @nav_no2=@nav_no
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[7]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[5]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[4]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[3]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[2]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[1]
-              @ncxo[1],@ncxo[2],@ncxo[3],@ncxo[4],@ncxo[5],@ncxo[6]=true,false,false,false,false,false
+              @ncxo[1],@ncxo[2],@ncxo[3],@ncxo[4],@ncxo[5],@ncxo[6],@ncxo[7]=
+                true,  false,   false,   false,   false,   false,   false
               @epub.sections(dob_toc,lv_name)
               @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no,lv_name) if dob_toc
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,lv_name)
@@ -311,12 +311,14 @@ module SiSU_XHTML_EPUB2
               lv_name='section_c' + @s_c_no.to_s
               @nav_no+=1
               @nav_no2=@nav_no
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[7]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[5]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[4]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[3]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[2]
-              @ncxo[2],@ncxo[3],@ncxo[4],@ncxo[5],@ncxo[6]=true,false,false,false,false
+              @ncxo[2],@ncxo[3],@ncxo[4],@ncxo[5],@ncxo[6],@ncxo[7]=
+                true,  false,   false,   false,   false,   false
               @epub.sections(dob_toc,lv_name)
               @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no,lv_name) if dob_toc
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,lv_name)
@@ -328,11 +330,13 @@ module SiSU_XHTML_EPUB2
               lv_name='section_d' + @s_d_no.to_s
               @nav_no+=1
               @nav_no3=@nav_no
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[7]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[5]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[4]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[3]
-              @ncxo[3],@ncxo[4],@ncxo[5],@ncxo[6]=true,false,false,false
+              @ncxo[3],@ncxo[4],@ncxo[5],@ncxo[6],@ncxo[7]=
+                true,  false,   false,   false,   false
               @epub.sections(dob_toc,lv_name)
               @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no,lv_name) if dob_toc
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,lv_name)
@@ -344,10 +348,12 @@ module SiSU_XHTML_EPUB2
               lv_name=dob_toc.name
               @nav_no+=1
               @dob_name=dob.name
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[7]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[5]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[4]
-              @ncxo[4],@ncxo[5],@ncxo[6]=true,false,false
+              @ncxo[4],@ncxo[5],@ncxo[6],@ncxo[7]=
+                true,  false,   false,   false
               @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no,lv_name) if dob_toc
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,lv_name)
               md_opf_a_spine << @epub.metadata_opf.spine(dob_toc,lv_name)
@@ -358,9 +364,11 @@ module SiSU_XHTML_EPUB2
               hashtag='#o' + dob_toc.ocn.to_s
               lv_name=@dob_name
               @nav_no+=1
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[7]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[5]
-              @ncxo[5],@ncxo[6]=true,false
+              @ncxo[5],@ncxo[6],@ncxo[7]=
+                true,  false, false
               @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no,lv_name,hashtag) if dob_toc
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,lv_name,hashtag)
               md_opf_a_spine << @epub.metadata_opf.spine(dob_toc,lv_name,hashtag)
@@ -371,13 +379,27 @@ module SiSU_XHTML_EPUB2
               hashtag='#o' + dob_toc.ocn.to_s
               lv_name=@dob_name
               @nav_no+=1
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[7]
               @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[6]
-              @ncxo[6]=true
+              @ncxo[6],@ncxo[7]=
+                true,  false
               @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no,lv_name,hashtag) if dob_toc
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,lv_name,hashtag)
               md_opf_a_spine << @epub.metadata_opf.spine(dob_toc,lv_name,hashtag)
               md_opf_a_guide << @epub.metadata_opf.guide(dob_toc,lv_name,hashtag)
               SiSU_XHTML_EPUB2::Source::Toc.new(@md,dob_toc).level_6
+            when 7
+              @ncx_cls=[]
+              hashtag='#o' + dob_toc.ocn.to_s
+              lv_name=@dob_name
+              @nav_no+=1
+              @@toc[:ncx] << @epub.toc_ncx.navpoint_close if @ncxo[7]
+              @ncxo[7]=true
+              @@toc[:ncx] << @epub.toc_ncx.navpoint(dob_toc,@nav_no,lv_name,hashtag) if dob_toc
+              md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,lv_name,hashtag)
+              md_opf_a_spine << @epub.metadata_opf.spine(dob_toc,lv_name,hashtag)
+              md_opf_a_guide << @epub.metadata_opf.guide(dob_toc,lv_name,hashtag)
+              SiSU_XHTML_EPUB2::Source::Toc.new(@md,dob_toc).level_7
             else nil
             end
             toc.each do |k,d|
@@ -393,7 +415,7 @@ module SiSU_XHTML_EPUB2
                 @@toc[:seg] << toc[:seg]
                 @@toc[:scr] << toc[:seg]
               rescue
-                SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+                SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
                   __LINE__.to_s + ':' + __FILE__
                 end
               end
@@ -594,11 +616,31 @@ module SiSU_XHTML_EPUB2
         end
         toc
       end
+      def level_7
+        dob=@data
+        linkname=dob.obj.gsub(/#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]}/,'').strip
+        ocn=dob.ocn
+        toc={}
+        if ocn \
+        and ocn !~/#/
+          p_num=SiSU_XHTML_EPUB2_Format::ParagraphNumber.new(@md,ocn)
+          lnk_n_txt=%{  <a href="#{@@seg_url}#{Sfx[:epub_xhtml]}#o#{ocn}">
+  #{linkname}
+</a>}
+          txt_obj={ txt: lnk_n_txt }
+          format_toc=SiSU_XHTML_EPUB2_Format::FormatToc.new(@md,txt_obj)
+          toc[:seg]=format_toc.lev7
+          title=%{#{p_num.goto}#{linkname}</a>}
+          txt_obj={ txt: title }
+          format_toc=SiSU_XHTML_EPUB2_Format::FormatToc.new(@md,txt_obj)
+          toc[:scr]=format_toc.lev7
+        end
+        toc
+      end
     end
     class ScrollHeadAndSegToc < Toc
       def initialize(md='',toc='',links_guide_toc='')
         @md,@toc,@links_guide_toc=md,toc,links_guide_toc
-        @vz=SiSU_Viz::Defaults.new
       end
       def in_common
         toc_shared=[]
@@ -726,7 +768,7 @@ module SiSU_XHTML_EPUB2
           end
           out.close
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
@@ -741,7 +783,7 @@ module SiSU_XHTML_EPUB2
           end
           out.close
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
@@ -803,7 +845,7 @@ module SiSU_XHTML_EPUB2
     <link rel="stylesheet" href="css/xhtml.css" type="text/css" />
     <style type="text/css"> img { max-width: 100%; } </style>
   </head>
-  <body bgcolor="#ffffff" text="#000000" link="#003090" lang="en" xml:lang="en">
+  <body xml:lang="en">
     <div class="svg_outer">
       <div class="svg_inner">
         <svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xl="http://www.w3.org/1999/xlink" width="100%" height="100%" viewBox="0 0 #{@md.make.cover_image[:w]} #{@md.make.cover_image[:h]}" preserveAspectRatio="xMidYMid meet">
@@ -818,7 +860,7 @@ WOK
             filename_xhtml.close
           end
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
@@ -836,7 +878,7 @@ WOK
             filename_xhtml.close
           end
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
