@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/epub_segments.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/epub_segments.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -134,7 +131,6 @@ WOK
     attr_reader :seg_name_xhtml,:seg_name_xhtml_tracker
     def initialize(md='',data='')
       @md,@data=md,data
-      @vz=SiSU_Viz::Defaults.new
       @seg_name_xhtml=@@seg_name_xhtml || nil
       @seg_name_xhtml_tracker=@@tracker || nil
       @make=SiSU_Env::ProcessingSettings.new(@md) if @md
@@ -146,7 +142,7 @@ WOK
         SiSU_XHTML_EPUB2_Seg::Seg.new.cleanup # (((( added ))))
         #### (((( END )))) ####
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -372,6 +368,8 @@ WOK
             sto.seg_heading5
           elsif dob.ln==6
             sto.seg_heading6
+          elsif dob.ln==7
+            sto.seg_heading7
           end
         elsif dob.is==:para
           if dob.indent \
@@ -486,7 +484,7 @@ WOK
           end
         end
         if dob.is==:heading \
-        and dob.ln.to_s =~/^[56]/
+        and dob.ln.to_s =~/^[5-7]/
           case dob.ln
           when 5
             format_seg=SiSU_XHTML_EPUB2_Format::FormatSeg.new(@md,dob)
@@ -494,6 +492,9 @@ WOK
           when 6
             format_seg=SiSU_XHTML_EPUB2_Format::FormatSeg.new(@md,dob)
             subtoc=format_seg.subtoc_lev6 #keep and make available, this is the subtoc
+          when 7
+            format_seg=SiSU_XHTML_EPUB2_Format::FormatSeg.new(@md,dob)
+            subtoc=format_seg.subtoc_lev7 #keep and make available, this is the subtoc
           end
           @@seg_subtoc_array << subtoc
         end
