@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/xhtml_table.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/xhtml_table.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,12 +58,13 @@
 
 =end
 module SiSU_XHTML_Table
-  require_relative 'defaults'                           # defaults.rb
+  require_relative 'xhtml_parts'                         # xhtml_parts.rb
   class TableXHTML
+    include SiSU_Parts_XHTML
     @@tablehead=0
     @@tablefoot=[] #watch
     def initialize(table)
-      @table_obj,@vz=table,SiSU_Viz::Defaults.new
+      @table_obj=table
     end
     def table
       table_obj=@table_obj
@@ -83,7 +81,7 @@ module SiSU_XHTML_Table
         trc,nc=[],0
         table_row_with_columns.each do |c|
           c=c.gsub(/^~$/,''). # tilde / empty cell
-            gsub(/<:br>/,'<br />')
+            gsub(/<:br>/,the_line_break)
           trc <<= if table_obj.head_ and nr==0; %{<th width="#{table_obj.widths[nc]}%">#{c}</th>}
           else %{<td width="#{table_obj.widths[nc]}%">#{c}</td>}
           end
