@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/xml_docbook_book.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/xml_docbook_book.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,10 +58,10 @@
 
 =end
 module SiSU_XML_Docbook_Book
-  require_relative 'particulars'                        # particulars.rb
+  require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
   require_relative 'ao'                                 # ao.rb
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   require_relative 'txt_shared'                         # txt_shared.rb
     include SiSU_TextUtils
@@ -83,12 +80,12 @@ module SiSU_XML_Docbook_Book
         report
         SiSU_XML_Docbook_Book::Source::Scroll.new(@ao_array,@md).songsheet
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
-        #SiSU_Env::CreateSite.new(@opt.cmd).cp_css
-        #SiSU_Env::CreateSite.new(@opt.cmd).cp_base_images
+        #SiSU_Env::CreateSite.new(@opt.selections.str).cp_css
+        #SiSU_Env::CreateSite.new(@opt.selections.str).cp_base_images
         Dir.chdir(@opt.f_pth[:pth])
       end
     end
