@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/xml_dom.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/xml_dom.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,11 +58,9 @@
    ** Notes: tidy -xml dom.xml >> index.tidy
 =end
 module SiSU_XML_DOM
-  require_relative 'defaults'                           # defaults.rb
-    include SiSU_Viz
-  require_relative 'particulars'                        # particulars.rb
+  require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   require_relative 'ao'                                 # ao.rb
   require_relative 'xml_shared'                         # xml_shared.rb
@@ -84,13 +79,24 @@ module SiSU_XML_DOM
     end
     def read
       begin
-        @env,@md,@ao_array=@particulars.env,@particulars.md,@particulars.ao_array
+        @env,              @md,            @ao_arr=
+          @particulars.env,@particulars.md,@particulars.ao_array
         unless @opt.act[:quiet][:set]==:on
           tool=if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
-            "#{@env.program.web_browser}  file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}\n\t#{@env.program.xml_viewer} file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}"
+            @env.program.web_browser \
+            + ' file://' \
+            + @md.file.output_path.xml_dom.dir + '/' \
+            + @md.file.base_filename.xml_dom + "\n\t" \
+            + @env.program.xml_viewer \
+            + ' file://' \
+            + @md.file.output_path.xml_dom.dir + '/' \
+            + @md.file.base_filename.xml_dom
           elsif @opt.act[:verbose][:set]==:on
-            "#{@env.program.web_browser} file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}"
+            @env.program.web_browser \
+            + ' file://' \
+            + @md.file.output_path.xml_dom.dir + '/' \
+            + @md.file.base_filename.xml_dom
           else "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
           end
           (@opt.act[:verbose][:set]==:on \
@@ -111,13 +117,15 @@ module SiSU_XML_DOM
             SiSU_Screen::Ansi.new(
               @opt.act[:color_state][:set],
               @opt.fns,
-              "file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}"
+              'file://' \
+              + @md.file.output_path.xml_dom.dir + '/' \
+              + @md.file.base_filename.xml_dom
             ).flow
           end
         end
         SiSU_XML_DOM::Source::Songsheet.new(@particulars).songsheet
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -128,7 +136,8 @@ module SiSU_XML_DOM
     private
     class Songsheet
       def initialize(particulars)
-        @env,@md,@ao_array,@particulars=particulars.env,particulars.md,particulars.ao_array,particulars
+        @env,             @md,           @ao_arr,             @particulars=
+          particulars.env,particulars.md,particulars.ao_array,particulars
         @file=SiSU_Env::FileOp.new(@md)
       end
       def songsheet
@@ -141,7 +150,7 @@ module SiSU_XML_DOM
           end
           SiSU_Rexml::Rexml.new(@md,@file.place_file.xml_dom.dir).xml if @md.opt.act[:maintenance][:set]==:on # test rexml parsing, comment out when not in use #debug
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         ensure
@@ -154,14 +163,14 @@ module SiSU_XML_DOM
       require_relative 'xhtml_shared'                   # decide use, whether xml rather than xhtml
       @@xml={ body: [], open: [], close: [], head: [], sc: [] }
       def initialize(particulars)
-        @env,@md,@ao_array=particulars.env,particulars.md,particulars.ao_array
-        @vz=SiSU_Viz::Defaults.new
+        @env,             @md,           @ao_arr=
+          particulars.env,particulars.md,particulars.ao_array
         @trans=SiSU_XML_Munge::Trans.new(@md)
         @sys=SiSU_Env::SystemCall.new
       end
       def songsheet
         pre
-        @data=markup(@ao_array)
+        @data=markup(@ao_arr)
         post
         publish
       end
@@ -226,12 +235,15 @@ WOK
 WOK
         if lv==4
           @copen[1]=true
-          @copen[2]=@copen[3]=false
+          @copen[2]=@copen[3]=@copen[4]=false
         elsif lv==5
           @copen[2]=true
-          @copen[3]=false
+          @copen[3]=@copen[4]=false
         elsif lv==6
           @copen[3]=true
+          @copen[4]=false
+        elsif lv==7
+          @copen[4]=true
         end
       end
       def xml_structure(dob,type='norm')
@@ -259,21 +271,24 @@ WOK
             @cont[2]=false if @cont[2]
             @cont[3]=false if @cont[3]
             ####### attempt to close contents
-            if @copen[3] # 6~
+            if @copen[4] # 4~
+              [4,3,2,1].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
+              @copen[1]=@copen[2]=@copen[3]=@copen[4]=false
+            elsif @copen[3] # 3~
               [3,2,1].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
               @copen[1]=@copen[2]=@copen[3]=false
-            elsif @copen[2] # 5~
+            elsif @copen[2] # 2~
               [2,1].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
               @copen[1]=@copen[2]=@copen[3]=false
-            elsif @copen[1] # 4~
+            elsif @copen[1] # 1~
               [1].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
               @copen[1]=@copen[2]=@copen[3]=false
             end
             @@xml[:body] << "#{Ax[:tab]*y}</heading#{x}>" if @level[x]
             @level[x]=false
           end
-        when 4..6
-          6.downto(lv) do |x|
+        when 4..7
+          7.downto(lv) do |x|
             if @level[x]==true
               @xml_contents_close[x]=''
             end
@@ -284,42 +299,61 @@ WOK
           case lv
           when 4
             @@xml[:body] << "#{Ax[:tab]*5}</content>" if @cont[1]
-            if @copen[3]==true # 6~
+            if @copen[4]==true # 4~
+              [4,3,2,1].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
+            elsif @copen[3]==true # 3~
               [3,2,1].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
-            elsif @copen[2]==true # 5~
+            elsif @copen[2]==true # 2~
               [2,1].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
-            elsif @copen[1]==true # 4~
+            elsif @copen[1]==true # 1~
               [1].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
             end
             @cont[1]=true
           when 5
-            if @cont[2] \
-            or @cont[1]
-              @@xml[:body] << "#{Ax[:tab]*5}</content>"
-            end
-            if @copen[3]==true  #6~
-              [3,2].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
-            elsif @copen[2]==true #5~
-              [2].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
-            end
-            @cont[2]=true
-          when 6
             if @cont[3] \
             or @cont[2] \
             or @cont[1]
               @@xml[:body] << "#{Ax[:tab]*5}</content>"
             end
-            if @copen[3] #6{
+            if @copen[4]==true  #4~
+              [4,3,2].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
+            elsif @copen[3]==true  #3~
+              [3,2].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
+            elsif @copen[2]==true #2~
+              [2].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
+            end
+            @cont[2]=true
+          when 6
+            if @cont[4] \
+            or @cont[3] \
+            or @cont[2] \
+            or @cont[1]
+              @@xml[:body] << "#{Ax[:tab]*5}</content>"
+            end
+            if @copen[4] #4~
+              [4,3].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
+            elsif @copen[3] #3~
               [3].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
             end
             @cont[3]=true
+          when 7
+            if @cont[4] \
+            or @cont[3] \
+            or @cont[2] \
+            or @cont[1]
+              @@xml[:body] << "#{Ax[:tab]*5}</content>"
+            end
+            if @copen[4] #4~
+              [4].each { |v| @@xml[:body] << "#{Ax[:tab]*n}</contents#{v}>" }
+            end
+            @cont[4]=true
           end
         end
         xml_el ||=''
         xml_element(dob,xml_el,xml_content,type)
         if lv
           @level[lv]=true
-          ((lv+1)..6).each { |x| @level[x]=false }
+          ((lv+1)..7).each { |x| @level[x]=false }
         end
       end
       def add_to_body(dob,type='norm')
@@ -367,8 +401,8 @@ WOK
         @level,@cont,@copen,@xml_contents_close=[],[],[],[]
         @rcdc=false
         type='norm'
-        (0..6).each { |x| @cont[x]=@level[x]=false }
-        (4..6).each { |x| @xml_contents_close[x]='' }
+        (0..7).each { |x| @cont[x]=@level[x]=false }
+        (4..7).each { |x| @xml_contents_close[x]='' }
         xml_head
         data.each do |dob|
           @trans.char_enc.utf8(dob) if @sys.locale =~/utf-?8/i #% utf8
@@ -420,6 +454,10 @@ WOK
                     type="heading_content_#{dob.lv}"
                     xml_structure(dob,type)
                     dob.obj=x.heading_body6
+                  elsif dob.ln==7
+                    type="heading_content_#{dob.lv}"
+                    xml_structure(dob,type)
+                    dob.obj=x.heading_body7
                   end
                 else
                   dob.ocn
@@ -478,15 +516,13 @@ WOK
                   format_text.scr_inden_ocn_e_no_paranum
                 end
               end
-              if dob.obj !~/#{@vz.margin_txt_0}|#{@vz.margin_txt_1}|#{@vz.margin_txt_2}/
-              end
             else #
             end
             dob.obj=dob.obj.gsub(/#{Mx[:pa_o]}:\S+#{Mx[:pa_c]}/,'') if dob.obj
           end
         end
         @content_flag=true
-        6.downto(4) do |x|
+        7.downto(4) do |x|
           y=x - 1; v=x - 3
           if @level[x]==true #2004w36 bug fix? watch/test previous logic broke on free.for.all @coontent_flag introduced
             if @content_flag==true
@@ -505,8 +541,8 @@ WOK
       def pre
         rdf=SiSU_XML_Tags::RDF.new(@md)
         stylesheet=SiSU_Style::CSS_HeadInfo.new(@md,'xml_dom').stylesheet
-        encoding=if @sys.locale =~/utf-?8/i; '<?xml version="1.0" encoding="UTF-8" standalone="no"?>'
-        else                                 '<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>'
+        encoding=if @sys.locale =~/utf-?8/i then '<?xml version="1.0" encoding="UTF-8" standalone="no"?>'
+        else                                     '<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>'
         end
         @@xml[:open] =<<WOK
 #{encoding}
