@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/xml_scaffold.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/xml_scaffold.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,10 +58,10 @@
 
 =end
 module SiSU_XML_Scaffold_Structure_Sisu
-  require_relative 'particulars'                        # particulars.rb
+  require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
   require_relative 'ao'                                 # ao.rb
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   class Source
     def initialize(opt)
@@ -79,7 +76,7 @@ module SiSU_XML_Scaffold_Structure_Sisu
         @md,@ao_array=@particulars.md,@particulars.ao_array
         SiSU_XML_Scaffold_Structure_Sisu::Source::Scroll.new(@ao_array,@md).songsheet
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
