@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/ao.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/ao.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -62,11 +59,9 @@
 
 =end
 module SiSU_AO
-  require_relative 'defaults'                           # defaults.rb
-    include SiSU_Viz
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
-  require_relative 'param'                              # param.rb
+  require_relative 'dp'                                 # dp.rb
     include SiSU_Param
   require_relative 'ao_doc_objects'                     # ao.rb
   require_relative 'ao_syntax'                          # ao_syntax.rb
@@ -124,7 +119,7 @@ module SiSU_AO
         : @opt.fns
         create_ao
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@@fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selection,@@fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -145,7 +140,7 @@ module SiSU_AO
         ? read_fnc
         : @@ao_array.dup
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selection,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -166,7 +161,7 @@ module SiSU_AO
         ? read_idx_sst
         : @@idx_arr[:sst].dup #check
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selection,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -187,7 +182,7 @@ module SiSU_AO
         ? read_idx_raw
         : @@idx_arr[:tex].dup #check
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selection,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -208,7 +203,7 @@ module SiSU_AO
         ? read_idx_html
         : @@idx_arr[:html].dup
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selection,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -229,7 +224,7 @@ module SiSU_AO
         ? read_idx_xhtml
         : @@idx_arr[:xhtml].dup
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selection,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -250,7 +245,7 @@ module SiSU_AO
         ? read_map_nametags
         : @@map_arr[:nametags].dup
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selection,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -271,7 +266,7 @@ module SiSU_AO
         ? read_map_ocn_htmlseg
         : @@map_arr[:ocn_htmlseg].dup
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selection,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -497,27 +492,33 @@ module SiSU_AO
     end
     def make_marshal_idx_sst_html_seg
       marshal_ao=@make.marshal.ao_idx_sst_rel_html_seg
-      File.open(marshal_ao,'w'){|f| Marshal.dump(@data,f)} if @data.is_a?(Array)
+      File.open(marshal_ao,'w'){|f| Marshal.dump(@data,f)} \
+        if @data.is_a?(Array)
     end
     def make_marshal_idx_sst_rel
       marshal_ao=@make.marshal.ao_idx_sst_rel
-      File.open(marshal_ao,'w'){|f| Marshal.dump(@data,f)} if @data.is_a?(Array)
+      File.open(marshal_ao,'w'){|f| Marshal.dump(@data,f)} \
+        if @data.is_a?(Array)
     end
     def make_marshal_idx_html
       marshal_ao=@make.marshal.ao_idx_html
-      File.open(marshal_ao,'w'){|f| Marshal.dump(@data,f)} if @data.is_a?(Array)
+      File.open(marshal_ao,'w'){|f| Marshal.dump(@data,f)} \
+        if @data.is_a?(Array)
     end
     def make_marshal_idx_xhtml
       marshal_ao=@make.marshal.ao_idx_xhtml
-      File.open(marshal_ao,'w'){|f| Marshal.dump(@data,f)} if @data.is_a?(Array)
+      File.open(marshal_ao,'w'){|f| Marshal.dump(@data,f)} \
+        if @data.is_a?(Array)
     end
     def make_marshal_map_nametags
       marshal_ao=@make.marshal.ao_map_nametags
-      File.open(marshal_ao,'w'){|f| Marshal.dump(@data,f)} if @data.is_a?(Hash)
+      File.open(marshal_ao,'w'){|f| Marshal.dump(@data,f)} \
+        if @data.is_a?(Hash)
     end
     def make_marshal_map_name_ocn_htmlseg
       marshal_ao=@make.marshal.ao_map_ocn_htmlseg
-      File.open(marshal_ao,'w'){|f| Marshal.dump(@data,f)} if @data.is_a?(Hash)
+      File.open(marshal_ao,'w'){|f| Marshal.dump(@data,f)} \
+        if @data.is_a?(Hash)
     end
   end
   class Make
