@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/ao_doc_str.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/ao_doc_str.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -230,8 +227,11 @@ module SiSU_AO_DocumentStructureExtract
             term_nodes << term_node
             use,plus=rgx_idx_ocn_seg.match(term_node)[1,2]
             @use=use.strip
-            idx_hash[@use]=
-              { sub: [], plus: plus } unless idx_hash[@use] and defined? idx_hash[@use]
+            unless idx_hash[@use] \
+            and defined? idx_hash[@use]
+              idx_hash[@use]=
+                { sub: [], plus: plus }
+            end
           when Array
             subterm_nodes=[]
             term_node.each do |subterm_node|
@@ -240,8 +240,11 @@ module SiSU_AO_DocumentStructureExtract
               : (subterm_node + '+0')
               subterm_nodes << subterm_node
               sub,sub_plus=rgx_idx_ocn_seg.match(subterm_node)[1,2]
-              idx_hash[@use]=
-                { sub: [], plus: 0 } unless idx_hash[@use] and defined? idx_hash[@use]
+              unless idx_hash[@use] \
+              and defined? idx_hash[@use]
+                idx_hash[@use]=
+                  { sub: [], plus: 0 }
+              end
               idx_hash[@use][:sub] <<
                 { sub.strip => { plus: sub_plus } }
             end
@@ -299,6 +302,18 @@ module SiSU_AO_DocumentStructureExtract
           next
         end
         t_o=t_o.gsub(/(?:\n\s*\n)+/m,"\n") if @@flag[:code]==:off
+        unless t_o =~/^(?:@\S+?:|%+)\s/                  # extract book index for paragraph if any
+          idx=if t_o=~/^=\{\s*(.+)\s*\}\s*$\Z/m
+            m=$1
+            m=m.split(/[ ]*\n/).join(' ').
+              gsub(/\s+([|:;])\s+/,'\1').
+              gsub(/\s+([+]\d+)\s+/,'\1')
+            t_o=t_o.gsub(/\n=\{.+?\}\s*$/m,'')
+            idx_array_and_hash=construct_idx_array_and_hash(m)
+            idx_array_and_hash[:hash]
+          else nil
+          end
+        end
         if t_o !~/^(?:code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|poem|alt|group|block)\{|^\}(?:code|poem|alt|group|block)|^(?:table\{|\{table)[ ~]/ \
         and t_o !~/^```[ ]+(?:code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|poem|alt|group|block|table)|^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$|^`:quote_(?:open|close)`/ \
         and @@flag[:code]==:off \
@@ -308,17 +323,6 @@ module SiSU_AO_DocumentStructureExtract
         and @@flag[:alt]==:off \
         and @@flag[:box]==:off \
         and @@flag[:table]==:off
-          unless t_o =~/^(?:@\S+?:|%+)\s/                  # extract book index for paragraph if any
-            idx=if t_o=~/^=\{\s*(.+)\s*\}\s*$\Z/m; m=$1
-              m=m.split(/[ ]*\n/).join(' ').
-                gsub(/\s+([|:;])\s+/,'\1').
-                gsub(/\s+([+]\d+)\s+/,'\1')
-              t_o=t_o.gsub(/\n=\{.+?\}\s*$/m,'')
-              idx_array_and_hash=construct_idx_array_and_hash(m)
-              idx_array_and_hash[:hash]
-            else nil
-            end
-          end
           t_o=case t_o
           when /^#{Mx[:meta_o]}\S+?#{Mx[:meta_c]}/                                 #metadata, header
             if t_o=~/^#{Mx[:meta_o]}(\S+?)#{Mx[:meta_c]}\s*(.+)/m
@@ -707,7 +711,8 @@ module SiSU_AO_DocumentStructureExtract
                 tags: tags,
                 num: @num_id[:table],
               }
-              t_o=SiSU_AO_DocumentStructure::ObjectTable.new.table(h) unless h.nil?
+              t_o=SiSU_AO_DocumentStructure::ObjectTable.new.table(h) \
+                unless h.nil?
               tuned_file << t_o
               h={
                 is_for: :table,
@@ -743,7 +748,8 @@ module SiSU_AO_DocumentStructureExtract
                 tags: tags,
                 num: @num_id[:table],
               }
-              t_o=SiSU_AO_DocumentStructure::ObjectTable.new.table(h) unless h.nil?
+              t_o=SiSU_AO_DocumentStructure::ObjectTable.new.table(h) \
+                unless h.nil?
               tuned_file << t_o
               h={
                 is_for: :table,
@@ -779,7 +785,8 @@ module SiSU_AO_DocumentStructureExtract
                 tags: tags,
                 num: @num_id[:table],
               }
-              t_o=SiSU_AO_DocumentStructure::ObjectTable.new.table(h) unless h.nil?
+              t_o=SiSU_AO_DocumentStructure::ObjectTable.new.table(h) \
+                unless h.nil?
               tuned_file << t_o
               h={
                 is_for: :table,
@@ -828,15 +835,22 @@ module SiSU_AO_DocumentStructureExtract
             t_o=nil
           end
         end
-        if @@flag[:code]==:curls or @@flag[:code]==:tics
-          if (@@flag[:code]==:curls and t_o =~/^\}code/) \
-          or (@@flag[:code]==:tics and t_o =~/^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/)
+        if @@flag[:code]==:curls \
+        or @@flag[:code]==:tics
+          if (@@flag[:code]==:curls \
+          && t_o =~/^\}code/) \
+          or (@@flag[:code]==:tics \
+          && t_o =~/^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/m)
             @@flag[:code]=:off
-            @tuned_code[-1].gsub!(/\s*(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*\Z/m,'')
+            if @tuned_code[-1]
+              @tuned_code[-1].
+                gsub!(/\s*(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*\Z/m,'')
+            end
             obj=@tuned_code.join("\n")
             tags=[]
             h={
               obj: obj,
+              idx: idx,
               syntax: @@flag[:lngsyn],
               tags: tags,
               num: @num_id[:code_block],
@@ -854,7 +868,8 @@ module SiSU_AO_DocumentStructureExtract
             }
             t_o=SiSU_AO_DocumentStructure::ObjectLayout.new.open_close(h)
           end
-          if (@@flag[:code]==:curls or @@flag[:code]==:tics) \
+          if (@@flag[:code]==:curls \
+          || @@flag[:code]==:tics) \
           and t_o.is_a?(String)
             sub_array=t_o.dup + "#{Mx[:br_nl]}"
             @line_mode=[]
@@ -863,28 +878,40 @@ module SiSU_AO_DocumentStructureExtract
             @tuned_code << t_o
             t_o=nil
           end
-        elsif (@@flag[:poem]==:curls or @@flag[:poem]==:tics) \
-        or (@@flag[:box]==:curls or @@flag[:box]==:tics) \
-        or (@@flag[:group]==:curls or @@flag[:group]==:tics) \
-        or (@@flag[:block]==:curls or @@flag[:block]==:tics) \
-        or (@@flag[:alt]==:curls or @@flag[:alt]==:tics) \
-        or (@@flag[:quote]==:open and t_o =~/`:quote_close`/m) #not
-          if (@@flag[:poem]==:curls and t_o =~/^\}poem/) \
-          or (@@flag[:poem]==:tics and t_o =~/^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/)
+        elsif (@@flag[:poem]==:curls \
+        || @@flag[:poem]==:tics) \
+        or (@@flag[:box]==:curls \
+        || @@flag[:box]==:tics) \
+        or (@@flag[:group]==:curls \
+        || @@flag[:group]==:tics) \
+        or (@@flag[:block]==:curls \
+        || @@flag[:block]==:tics) \
+        or (@@flag[:alt]==:curls \
+        || @@flag[:alt]==:tics) \
+        or (@@flag[:quote]==:open \
+        && t_o =~/`:quote_close`/m) #not
+          if (@@flag[:poem]==:curls \
+          && t_o =~/^\}poem$/m) \
+          or (@@flag[:poem]==:tics \
+          && t_o =~/^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/)
             @@flag[:poem]=:off
             h={
               is_for: :poem,
               obj: '',
+              idx: idx,
               sym: :poem_close,
               num: @num_id[:poem],
             }
             t_o=SiSU_AO_DocumentStructure::ObjectLayout.new.open_close(h)
-          elsif (@@flag[:box]==:curls and t_o =~/^\}box/) \
-          or (@@flag[:box]==:tics and t_o =~/^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/)
+          elsif (@@flag[:box]==:curls \
+          && t_o =~/^\}box/) \
+          or (@@flag[:box]==:tics \
+          && t_o =~/^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/)
             @@flag[:box]=:off
             obj,tags=extract_tags(@tuned_block.join("\n"))
             h={
               obj: obj,
+              idx: idx,
               tags: tags,
               num: @num_id[:box],
             }
@@ -894,16 +921,20 @@ module SiSU_AO_DocumentStructureExtract
             h={
               is_for: :box,
               obj: '',
+              idx: idx,
               sym: :box_close,
               num: @num_id[:box],
             }
             t_o=SiSU_AO_DocumentStructure::ObjectLayout.new.open_close(h)
-          elsif (@@flag[:group]==:curls and t_o =~/^\}group/) \
-          or (@@flag[:group]==:tics and t_o =~/^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/)
+          elsif (@@flag[:group]==:curls \
+          && t_o =~/^\}group/) \
+          or (@@flag[:group]==:tics \
+          && t_o =~/^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/)
             @@flag[:group]=:off
             obj,tags=extract_tags(@tuned_block.join("\n"))
             h={
               obj: obj,
+              idx: idx,
               tags: tags,
               num: @num_id[:group],
             }
@@ -917,12 +948,15 @@ module SiSU_AO_DocumentStructureExtract
               num: @num_id[:group],
             }
             t_o=SiSU_AO_DocumentStructure::ObjectLayout.new.open_close(h)
-          elsif (@@flag[:block]==:curls and t_o =~/^\}block/) \
-          or (@@flag[:block]==:tics and t_o =~/^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/)
+          elsif (@@flag[:block]==:curls \
+          && t_o =~/^\}block/) \
+          or (@@flag[:block]==:tics \
+          && t_o =~/^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/)
             @@flag[:block]=:off
             obj,tags=extract_tags(@tuned_block.join("\n"))
             h={
               obj: obj,
+              idx: idx,
               tags: tags,
               num: @num_id[:block],
             }
@@ -936,12 +970,15 @@ module SiSU_AO_DocumentStructureExtract
               num: @num_id[:block],
             }
             t_o=SiSU_AO_DocumentStructure::ObjectLayout.new.open_close(h)
-          elsif (@@flag[:alt]==:curls and t_o =~/^\}alt/) \
-          or (@@flag[:alt]==:tics and t_o =~/^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/)
+          elsif (@@flag[:alt]==:curls \
+          && t_o =~/^\}alt/) \
+          or (@@flag[:alt]==:tics \
+          && t_o =~/^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/)
             @@flag[:alt]=:off
             obj,tags=extract_tags(@tuned_block.join("\n"))
             h={
               obj: obj,
+              idx: idx,
               tags: tags,
               num: @num_id[:alt],
             }
@@ -955,10 +992,12 @@ module SiSU_AO_DocumentStructureExtract
               num: @num_id[:alt],
             }
             t_o=SiSU_AO_DocumentStructure::ObjectLayout.new.open_close(h)
-          elsif @@flag[:quote]==:open and t_o =~/`:quote_close`/m
+          elsif @@flag[:quote]==:open \
+          and t_o =~/`:quote_close`/m
             @@flag[:quote]=:off
             h={
               is_for: :quote,
+              idx: idx,
               obj: '',
               sym: :quote_close,
               num: @num_id[:quote],
@@ -977,9 +1016,12 @@ module SiSU_AO_DocumentStructureExtract
             }
             SiSU_AO_DocumentStructure::ObjectPara.new.paragraph(h)
           end
-          if (@@flag[:poem]==:curls or @@flag[:poem]==:tics \
-          or @@flag[:group]==:curls or @@flag[:group]==:tics \
-          or @@flag[:alt]==:curls or @@flag[:alt]==:tics) \
+          if (@@flag[:poem]==:curls \
+          || @@flag[:poem]==:tics) \
+          or (@@flag[:group]==:curls \
+          || @@flag[:group]==:tics) \
+          or (@@flag[:alt]==:curls \
+          || @@flag[:alt]==:tics) \
           and t_o =~/\S/ \
           and t_o !~/^(?:\}(?:verse|code|box|alt|group|block)|(?:verse|code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|alt|group|block)\{)/ \
           and t_o !~/^```[ ]+(?:code(?:\.[a-z][0-9a-z_]+)?|box(?:\.[a-z_]+)?|poem|alt|group|block)|^```(?:\s+[~-][#]|\s+\~\{.+?\}\~)?\s*$/ # fix logic
@@ -1223,7 +1265,7 @@ module SiSU_AO_DocumentStructureExtract
     end
     def structure_info
       def lv
-        %w[A~ B~ C~ D~ 1 2 3]
+        %w[A~ B~ C~ D~ 1 2 3 4]
       end
       def possible_parents(child)
         case child
@@ -1234,6 +1276,7 @@ module SiSU_AO_DocumentStructureExtract
         when /1/  then 'A~, B~, C~, D~'
         when /2/  then '1'
         when /3/  then '2'
+        when /4/  then '3'
         end
       end
       def possible_children(parent)
@@ -1244,24 +1287,29 @@ module SiSU_AO_DocumentStructureExtract
         when /D~/ then '1'
         when /1/  then '2'
         when /2/  then '3'
-        when /3/  then 'none'
+        when /3/  then '4'
+        when /4/  then 'none'
         end
       end
       self
     end
     def document_structure_check_info(node,node_parent,status=:ok)
-      node_ln=/^([0-6])/.match(node)[1].to_i
-      node_parent_ln=/^([0-6])/.match(node_parent)[1].to_i
+      node_ln=/^([0-7])/.match(node)[1].to_i
+      node_parent_ln=/^([0-7])/.match(node_parent)[1].to_i
       if status==:error \
       or @md.opt.act[:maintenance][:set]==:on
         puts %{node: #{node},    parent node: #{node_parent}  #{status.upcase}}
         if status==:error
-          node_ln=/^([0-6])/.match(node)[1].to_i
-          node_parent_ln=/^([0-6])/.match(node_parent)[1].to_i
+          node_ln=/^([0-7])/.match(node)[1].to_i
+          node_parent_ln=/^([0-7])/.match(node_parent)[1].to_i
           STDERR.puts %{current level: #{structure_info.lv[node_ln]} (possible parent levels: #{structure_info.possible_parents(structure_info.lv[node_ln])})
 parent level:  #{structure_info.lv[node_parent_ln]} (possible child levels: #{structure_info.possible_children(structure_info.lv[node_parent_ln])})
-SKIPPED processing file: [#{@md.opt.lng}] "#{@md.fns}"}
-          $process_document = :skip
+SKIPPED processing file:
+[#{@md.opt.lng}] "#{@md.fns}"}
+          if @md.opt.act[:no_stop][:set]==:on
+            $process_document = :skip
+          else exit
+          end
         end
       end
     end
@@ -1278,9 +1326,13 @@ has incorrect level and/or parent level
          STDERR.puts %{required header missing:
 
 @title:
-SKIPPED processing file: [#{@md.opt.lng}] "#{@md.fns}"
+SKIPPED processing file:
+[#{@md.opt.lng}] "#{@md.fns}"
 }
-        $process_document = :skip
+        if @md.opt.act[:no_stop][:set]==:on
+          $process_document = :skip
+        else exit
+        end
       end
       unless (defined? @md.creator.author \
       and @md.creator.author)
@@ -1288,21 +1340,25 @@ SKIPPED processing file: [#{@md.opt.lng}] "#{@md.fns}"
 
 @creator:
  :author: anonymous?
-SKIPPED processing file: [#{@md.opt.lng}] "#{@md.fns}"
+SKIPPED processing file:
+[#{@md.opt.lng}] "#{@md.fns}"
 }
-        $process_document = :skip
+        if @md.opt.act[:no_stop][:set]==:on
+          $process_document = :skip
+        else exit
+        end
       end
     end
     def ocn                                                                      #and auto segment numbering increment
       required_headers_present?
       data=@data
       @o_array=[]
-      node=ocn=ocn_dv=ocn_sp=ocnh=ocnh0=ocnh1=ocnh2=ocnh3=ocnh4=ocnh5=ocnh6=ocno=ocnp=ocnt=ocnc=ocng=ocni=ocnu=0 # h heading, o other, t table, g group, i image
+      node=ocn=ocn_dv=ocn_sp=ocnh=ocnh0=ocnh1=ocnh2=ocnh3=ocnh4=ocnh5=ocnh6=ocnh7=ocno=ocnp=ocnt=ocnc=ocng=ocni=ocnu=0 # h heading, o other, t table, g group, i image
       regex_exclude_ocn_and_node = /#{Rx[:meta]}|^@\S+?:\s|^4~endnotes|^#{Mx[:lv_o]}4:endnotes#{Mx[:lv_c]}|^\^~ |<:e[:_]\d+?>|^<:\#|<:- |<[:!]!4|<hr width|#{Mx[:br_endnotes]}|\A\s*\Z/mi #ocn here #&nbsp; added with Tune.code #¡
-      parent=node1=node2=node3=node4=node5=node6=nil
+      parent=node1=node2=node3=node4=node5=node6=node7=nil
       node0='0:0;0'
       @collapsed_lv0=0
-      @lev_occurences={ a: 0, b: 0, c: 0, d: 0, l1: 0, l2: 0, l3: 0 }
+      @lev_occurences={ a: 0, b: 0, c: 0, d: 0, l1: 0, l2: 0, l3: 0, l4: 0 }
       data.each do |dob|
         h={}
         if (dob.obj !~ regex_exclude_ocn_and_node || dob.is==:code) \
@@ -1336,7 +1392,8 @@ SKIPPED processing file: [#{@md.opt.lng}] "#{@md.fns}"
           or ln.to_s =~@md.lv3 \
           or ln.to_s =~@md.lv4 \
           or ln.to_s =~@md.lv5 \
-          or ln.to_s =~@md.lv6)
+          or ln.to_s =~@md.lv6 \
+          or ln.to_s =~@md.lv7)
             if not dob.obj =~/~#|-#/
               ocnh+=1
             end
@@ -1521,9 +1578,9 @@ or this level should be level :B~ rather than #{dob.lv}}
                 node5
               elsif node4
                 warning_incorrect_parent_level_or_level(dob.obj)
-                puts "parent is level 4~ & this level #{dob.lv}
-either parent should be level 5~
-or this level should be 5~ rather #{dob.lv}" #level 6
+                puts "parent is level #4 (1~) & this level ##{dob.ln} (#{dob.lv}~)
+either parent should be level #5 (2~)
+or this level should be #5 (2~) rather ##{dob.ln} (#{dob.lv}~)"
                 document_structure_check_info(node6,node4,:error)
                 @collapsed_lv6=@collapsed_lv4+1
                 node4
@@ -1549,11 +1606,67 @@ or this level should be 5~ rather #{dob.lv}" #level 6
               end
               collapsed_level=@collapsed_lv6
               node,ocn_sp=node6,"h#{ocnh}"
+            elsif ln==7 \
+            or ln=~@md.lv7
+              @lev_occurences[:l4] += 1
+              if not dob.obj =~/~#|-#/
+                ocn_flag=true
+                ocnh7+=1
+                node7="7:#{ocnh7};#{ocn}"
+              else
+                ocn_flag=false
+                node7="7:0;0"
+              end
+              parent=if node6
+                document_structure_check_info(node7,node6)
+                @collapsed_lv7=@collapsed_lv6+1
+                node5
+              elsif node5
+                warning_incorrect_parent_level_or_level(dob.obj)
+                puts "parent is level #5 (2~) & this level ##{dob.ln} (#{dob.lv}~)
+either parent should be level #6 (3~)
+or this level should be #6 (3~) rather ##{dob.ln} (#{dob.lv}~)"
+                document_structure_check_info(node7,node5,:error)
+                @collapsed_lv6=@collapsed_lv5+1
+                node5
+              elsif node4
+                warning_incorrect_parent_level_or_level(dob.obj)
+                puts "parent is level #4 (1~) & this level ##{dob.ln} (#{dob.lv}~)
+either parent should be level 6~
+or this level should be #6 (3~) rather ##{dob.ln} (#{dob.lv}~)"
+                document_structure_check_info(node7,node4,:error)
+                @collapsed_lv6=@collapsed_lv4+1
+                node4
+              elsif node3
+                warning_incorrect_parent_level_or_level(dob.obj)
+                document_structure_check_info(node7,node3,:error)
+                @collapsed_lv6=@collapsed_lv3+1
+                node3
+              elsif node2
+                warning_incorrect_parent_level_or_level(dob.obj)
+                document_structure_check_info(node7,node2,:error)
+                @collapsed_lv6=@collapsed_lv2+1
+                node2
+              elsif node1
+                warning_incorrect_parent_level_or_level(dob.obj)
+                document_structure_check_info(node7,node1,:error)
+                @collapsed_lv6=@collapsed_lv1+1
+                node1
+              else
+                warning_incorrect_parent_level_or_level(dob.obj)
+                document_structure_check_info(node7,node0,:error)
+                node0
+              end
+              collapsed_level=@collapsed_lv7
+              node,ocn_sp=node7,"h#{ocnh}"
             end
           else
             unless @lev_occurences[:l1] > 0
               STDERR.puts %{Substantive text objects must follow a level 1~ heading and there are none at this point in processing: #{@lev_occurences[:l1]}
-}
+SKIPPED processing file:
+[#{@md.opt.lng}] "#{@md.fns}"}
+              puts dob.obj #.gsub(/^(.{1,80})/,'"\1"')
+              exit
             end
             unless @ln >= 4
               lev=case @ln
@@ -1569,10 +1682,14 @@ or this level should be 5~ rather #{dob.lv}" #level 6
               when 9 then '6'
               end
               STDERR.puts %{Substantive text objects must follow a level 1~ 2~ or 3~ heading: #{lev}~
-SKIPPED processing file: [#{@md.opt.lng}] "#{@md.fns}"}
+SKIPPED processing file:
+[#{@md.opt.lng}] "#{@md.fns}"}
               puts dob.obj.gsub(/^(.{1,80})/,'"\1"')
-              $process_document = :skip
-              break
+              if @md.opt.act[:no_stop][:set]==:on
+                $process_document = :skip
+                break
+              else exit
+              end
             end
             if not dob.obj =~/~#|-#/
               ocn_flag=true
@@ -1649,14 +1766,22 @@ SKIPPED processing file: [#{@md.opt.lng}] "#{@md.fns}"}
       unless @lev_occurences[:a] == 1
         STDERR.puts %{The number of level A~ in this document: #{@lev_occurences[:a]}
 There must be one level A~ (no more and no less)
-SKIPPED processing file: [#{@md.opt.lng}] "#{@md.fns}"}
-        $process_document = :skip
+SKIPPED processing file:
+[#{@md.opt.lng}] "#{@md.fns}"}
+        if @md.opt.act[:no_stop][:set]==:on
+          $process_document = :skip
+        else exit
+        end
       end
       unless @lev_occurences[:l1] > 0
         STDERR.puts %{The number of level 1~ in this document: #{@lev_occurences[:l1]}
 There must be at least one level 1~ (and as many as required)
-SKIPPED processing file: [#{@md.opt.lng}] "#{@md.fns}"}
-        $process_document = :skip
+SKIPPED processing file:
+[#{@md.opt.lng}] "#{@md.fns}"}
+        if @md.opt.act[:no_stop][:set]==:on
+          $process_document = :skip
+        else exit
+        end
       end
       @o_array
     end
