@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/ao_doc_endnotes.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/ao_doc_endnotes.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -76,11 +73,11 @@ module SiSU_AO_Endnotes
       endnote_ref=1
       data.each do |dob|
                                                                                # manually numbered endnotes <!e(\d)!> <!e_(\d)!> -->
-        if @md.opt.mod.inspect =~/--no-asterisk|--no-annotate/
+        if @md.opt.selections.str =~/--no-asterisk|--no-annotate/
           dob.obj=dob.obj.
             gsub(/#{Mx[:en_b_o]}\s.+?#{Mx[:en_b_c]}/,'')
         end
-        if @md.opt.mod.inspect =~/--no-dagger|--no-annotate/
+        if @md.opt.selections.str =~/--no-dagger|--no-annotate/
           dob.obj=dob.obj.
             gsub(/#{Mx[:en_b_o]}[+]\s.+?#{Mx[:en_b_c]}/,'')
         end
