@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/ao_idx.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/ao_idx.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -79,7 +76,10 @@ module SiSU_AO_BookIndex
         html_idx,xhtml_idx=
           extract_book_index(data)
       data=
-        clean_and_insert_index(data,sisu_markup_idx_rel_html_seg)
+        clean_and_insert_index(
+          data,
+          sisu_markup_idx_rel_html_seg
+        )
       [
         data,
         sisu_markup_idx_rel,
@@ -99,7 +99,11 @@ module SiSU_AO_BookIndex
         end
         if defined? dob.idx \
         and dob.idx.is_a?(Hash)
-          idx_array << {idx: dob.idx, ocn: dob.ocn, seg: @seg }
+          idx_array << {
+            idx: dob.idx,
+            ocn: dob.ocn,
+            seg: @seg
+          }
         end
         tuned_file << dob if dob
       end
