@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/ao_images.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/ao_images.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -134,6 +131,17 @@ module SiSU_AO_Images
                         end
                         img_col,img_row=/(\d+)x(\d+)/m.match(imgsys)[1,2]
                         img_col,img_row=img_col.to_i,img_row.to_i
+                      else
+                        errmsg='imagemagick or graphicksmagick are required to process images'
+                        if @md.opt.act[:no_stop][:set]==:on
+                          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                            error("#{errmsg}, proceeding (as requested) without image processing")
+                          break
+                        else
+                          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                            error("#{errmsg}, STOPPING")
+                          exit
+                        end
                       end
                     end
                     row=((img && defined? img.rows) ? img.rows : img_row)
