@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/ao_syntax.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/ao_syntax.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -69,7 +66,6 @@ module SiSU_AO_Syntax
   class Markup
     def initialize(md='',data='')
       @md,@data=md,data
-      @vz=SiSU_Viz::Defaults.new
       @data_new=[]
       url_and_stub=SiSU_Env::InfoEnv.new.url
       @output_url="#{url_and_stub.remote}"
@@ -101,23 +97,13 @@ module SiSU_AO_Syntax
       #ital_line=%{^/_\s.+?(?:#{Mx[:br_line]}|\n|$)} #not implemented
       @line_scan_ital=if defined? @md.italics_match_list[:str]
         /#{@http_m}|#{bold_line}|#{@manmkp_ital}#{tail_m_ital}|#{@md.italics_match_list[:str]}#{tail_m_ital}|\S+|\n/i
-      elsif defined? @vz.markup_make_italic[:str]
-        /#{@http_m}|#{bold_line}|#{@manmkp_ital}#{tail_m_ital}|#{@vz.markup_make_italic[:str]}#{tail_m_ital}|\S+|\n/i
       end
       @manmkp_bold=emph_italics \
       ? '^!_\s.+?(?:\n|$)|[!b]\\{.+?\\}[*!b]|[*!][a-zA-Z0-9\-_]+[!]'
       : '^!_\s.+?(?:\n|$)|[*!b]\\{.+?\\}[*!b]|[*!][a-zA-Z0-9\-_]+[*!]'
-      @line_scan_bold=if (defined? @md.bold_match_list[:str] \
-      and @md.bold_match_list[:str]) \
-      and (defined? @vz.markup_make_bold[:str] \
-      and @vz.markup_make_bold[:str])
-        /#{@http_m}|#{bold_line}|(?:#{@manmkp_bold}|#{@md.bold_match_list[:str]}|#{@vz.markup_make_bold[:str]})#{tail_m_bold}|\S+|\n/i
-      elsif defined? @md.bold_match_list[:str] \
+      @line_scan_bold=if defined? @md.bold_match_list[:str] \
       and @md.bold_match_list[:str]
         /#{@http_m}|#{bold_line}|(?:#{@manmkp_bold}|#{@md.bold_match_list[:str]})#{tail_m_bold}|\S+|\n/i
-      elsif defined? @vz.markup_make_bold[:str] \
-      and @vz.markup_make_bold[:str]
-        /#{@http_m}|#{bold_line}|(?:#{@manmkp_bold}|#{@vz.markup_make_bold[:str]})#{tail_m_bold}|\S+|\n/i
       end
     end
     def songsheet
@@ -157,9 +143,7 @@ module SiSU_AO_Syntax
     def wordlist_italics(dob)
       dob=dob.dup
       if (defined? @md.italics_match_list[:str] \
-      and @md.italics_match_list[:str]) \
-      or (defined? @vz.markup_make_italic[:str] \
-      and @vz.markup_make_italic[:str])
+      and @md.italics_match_list[:str])
         dob.obj=if dob.is !=:meta \
         && dob.is !=:heading \
         && dob.is !=:heading_insert \
@@ -175,10 +159,6 @@ module SiSU_AO_Syntax
               and @md.italics_match_list[:regx]
                 w=w.gsub(@md.italics_match_list[:regx],
                   "#{Mx[:fa_italics_o]}\\1#{Mx[:fa_italics_c]}")
-              elsif defined? @vz.markup_make_italic \
-              and @vz.markup_make_italic
-                w=w.gsub(@vz.markup_make_italic,
-                  "#{Mx[:fa_italics_o]}\\1#{Mx[:fa_italics_c]}")
               else w
               end
             end
@@ -270,9 +250,7 @@ module SiSU_AO_Syntax
     def wordlist_bold(dob)
       dob=dob.dup
       if (defined? @md.bold_match_list[:str] \
-      and @md.bold_match_list[:str]) \
-      or (defined? @vz.markup_make_bold[:str] \
-      and @vz.markup_make_bold[:str])
+      and @md.bold_match_list[:str])
         dob.obj=if dob.is !=:meta \
         && dob.is !=:heading \
         && dob.is !=:heading_insert \
@@ -288,10 +266,6 @@ module SiSU_AO_Syntax
               and @md.bold_match_list[:regx]                                             #document header: @bold: [bold word list]
                 w=w.gsub(@md.bold_match_list[:regx],
                   "#{Mx[:fa_bold_o]}\\1#{Mx[:fa_bold_c]}")
-              elsif defined? @vz.markup_make_bold \
-              and @vz.markup_make_bold                                                   #defaults adjusted bold word list
-                w=w.gsub(@vz.markup_make_bold,
-                  "#{Mx[:fa_bold_o]}\\1#{Mx[:fa_bold_c]}")
               end
             else
               w=if w =~ /(?:^!_|^#{Mx[:lv_o]}[7-9]:\S*?#{Mx[:lv_c]})\s+/
@@ -544,7 +518,7 @@ module SiSU_AO_Syntax
       elsif dob.is ==:code
         dob.obj=dob.obj.
           gsub(/#{Mx[:meta_o]}(\S+?)#{Mx[:meta_c]}\s*/,'@\1: ').
-          gsub(/(^|#{Mx[:gl_c]}|\s)&lt;(br(?: \/)?)&gt;([\s,.]|$)/,'\1<\2>\3') #convert <br> <br /> back, clumsy
+          gsub(/(^|#{Mx[:gl_c]}|\s)&lt;(?:br(?: \/)?)&gt;([\s,.]|$)/,'\1<br>\2') #convert <br> <br /> back, clumsy
         if dob.number_
           codeline=[]
           ln=1
