@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/cgi_pgsql.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/cgi_pgsql.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -60,8 +57,8 @@
  ** Description: generates naive cgi search form for search of sisu database (pgsql)
 
 =end
-module  SiSU_CGI_PgSQL                                                            #% database building documents
-  require_relative 'sysenv'                             # sysenv.rb
+module  SiSU_CGI_PgSQL                                  #% database building documents
+  require_relative 'se'                                 # se.rb
   require_relative 'cgi_sql_common'                     # cgi_sql_common.rb
     include SiSU_CGI_SQL
   class SearchPgSQL < CGI_Common
@@ -236,11 +233,9 @@ module  SiSU_CGI_PgSQL
     end
     def search_query1
       <<-'WOK_SQL'
-          @search_text,@search_endnotes='',''
+          @search_text=''
           @search_text=search[:text].flatten.join(' AND ')
           @search_text=@search_text.gsub(/(doc_objects\.clean~[*]?\(\s*'[^']+'\s*\)\s+(?:(?:AND|OR)\s+doc_objects\.clean~[*]?\(\s*'[^']+'\s*\))+)/,'(\1)')
-          @search_endnotes=search[:endnotes].flatten.join(' AND ')
-          @search_endnotes=@search_endnotes.gsub(/(endnotes\.clean~\(\s*'[^']+'\s*\)\s+(?:(?:AND|OR)\s+endnotes\.clean~\(\s*'[^']+'\s*\))+)/,'(\1)')
         end
       WOK_SQL
     end
@@ -254,26 +249,12 @@ module  SiSU_CGI_PgSQL
           select=@sql_statement[:body] + ' ' + @sql_statement[:range]
           select
         end
-        def sql_select_endnotes
-          limit ||=@@limit
-          offset ||=@@offset
-          @sql_statement[:endnotes]=%{SELECT metadata_and_text.title, metadata_and_text.creator_author, metadata_and_text.src_filename, metadata_and_text.language_document_char, endnotes.body, endnotes.nr, endnotes.ocn, endnotes.metadata_tid FROM metadata_and_text, endnotes WHERE (#{@search_endnotes}) AND metadata_and_text.tid = endnotes.metadata_tid ORDER BY metadata_and_text.language_document_char, metadata_and_text.title, metadata_and_text.src_filename, endnotes.nr}
-          @sql_statement[:range]=%{LIMIT #{limit} OFFSET #{offset} ;}
-          select=@sql_statement[:endnotes] + ' ' + @sql_statement[:range]
-          select
-        end
         def sql_select_body_format
           %{<font color="#666666" size="2">#{sql_select_body}</font>}
         end
-        def sql_select_endnotes_format
-          %{<font color="#666666" size="2">#{sql_select_endnotes}</font>}
-        end
         def contents
           @conn.exec(sql_select_body)
         end
-        def endnotes
-          @conn.exec(sql_select_endnotes)
-        end
       end
       WOK_SQL
     end
