@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/cgi_sql_sqlite.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/cgi_sql_sqlite.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -60,8 +57,8 @@
  ** Description: generates naive cgi search form for search of sisu database (sqlite)
 
 =end
-module  SiSU_CGI_SQLite                                                            #% database building documents
-  require_relative 'sysenv'                             # sysenv.rb
+module  SiSU_CGI_SQLite                                 #% database building documents
+  require_relative 'se'                                 # se.rb
   require_relative 'cgi_sql_common'                     # cgi_sql_common.rb
     include SiSU_CGI_SQL
   class SearchSQLite < CGI_Common
@@ -112,7 +109,7 @@ module  SiSU_CGI_SQLite
       serve.each do |x|
         f3 << %{          when /#{Db[:name_prefix]}#{x}/ then "#{@env.path.webserv}/#{x}/\#{db_name}"\n}
       end
-      f3 << %{           else  '#{@env.path.webserv}/#{serve[0]}/\#{db_name}'\n          end\n}
+      f3 << %{           else  "#{@env.path.webserv}/#{serve[0]}/\#{db_name}"\n          end\n}
       if FileTest.writable?('.')
         output=File.open(@cgi_file_name,'w')
         output << header0 << header1 << header_desc << header2 << f1 << buttons1 << buttons2 << search_request << search_statement << search_statement_common << search_query1 << @common.pages << search_query2 << @common.tail << @common.main1 << f2 << f3 << dbi_connect << @common.main2 << @common.dir_structure << @common.main3
@@ -214,11 +211,9 @@ module  SiSU_CGI_SQLite
     end
     def search_query1
       <<-'WOK_SQL'
-          @search_text,@search_endnotes='',''
+          @search_text=''
           @search_text=search[:text].flatten.join(' AND ')
           @search_text=@search_text.gsub(/(doc_objects\.clean\s+LIKE\s+\(\s*'%[^']+%'\s*\)\s+(?:(?:AND|OR)\s+doc_objects\.clean\s+LIKE\s+\(\s*'%[^']+%'\s*\))+)/,'(\1)')
-          @search_endnotes=search[:endnotes].flatten.join(' AND ')
-          @search_endnotes=@search_endnotes.gsub(/(endnotes\.clean\s+LIKE\s+\(\s*'%[^']+%'\s*\)\s+(?:(?:AND|OR)\s+endnotes\.clean\s+LIKE\s+\(\s*'%[^']+%'\s*\))+)/,'(\1)')
         end
       WOK_SQL
     end
@@ -232,26 +227,12 @@ module  SiSU_CGI_SQLite
           select=@sql_statement[:body] + ' ' + @sql_statement[:range]
           select
         end
-        def sql_select_endnotes
-          limit ||=@@limit
-          offset ||=@@offset
-          @sql_statement[:endnotes]=%{SELECT metadata_and_text.title, metadata_and_text.creator_author, metadata_and_text.src_filename, metadata_and_text.language_document_char, endnotes.body, endnotes.nr, endnotes.ocn, endnotes.metadata_tid FROM metadata_and_text, endnotes WHERE #{@search_endnotes} AND metadata_and_text.tid = endnotes.metadata_tid ORDER BY metadata_and_text.language_document_char, metadata_and_text.title, metadata_and_text.src_filename, endnotes.nr}
-          @sql_statement[:range]=%{LIMIT #{limit} OFFSET #{offset} ;}
-          select=@sql_statement[:endnotes] + ' ' + @sql_statement[:range]
-          select
-        end
         def sql_select_body_format
           %{<font color="#666666" size="2">#{sql_select_body}</font>}
         end
-        def sql_select_endnotes_format
-          %{<font color="#666666" size="2">#{sql_select_endnotes}</font>}
-        end
         def contents
           @conn.execute(sql_select_body)
         end
-        def endnotes
-          @conn.execute(sql_select_endnotes)
-        end
       end
       WOK_SQL
     end
