@@ -47,12 +47,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/constants.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/constants.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -107,7 +104,7 @@ Mx={
   segname_prefix_auto_num_extract: 'c',
   segname_prefix_auto_num_provide: 's',
   segname_prefix_auto_num_other:   'x',
-  ocn_id_char:               'o',
+  ocn_id_char:               '',                                              #'o', now as before; remove for html5
   note:                      'note_',
   note_ref:                  'noteref_',
   note_astx:                 'note_astx_',
@@ -267,8 +264,8 @@ else
   }
 end
 Db={
-  name_prefix:               "SiSU#{SiSU_is[:version_dir]}b_",
-  name_prefix_db:            "sisu_#{SiSU_is[:version_dir]}b_",
+  name_prefix:               "SiSU#{SiSU_is[:version_dir]}c_",
+  name_prefix_db:            "sisu_#{SiSU_is[:version_dir]}c_",
   col_title:                  800,
   col_title_part:             400,
   col_title_edition:           10,
