@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/css.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/css.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,8 +58,8 @@
 
 =end
 module SiSU_Style
-  require_relative 'sysenv'                             # sysenv.rb
-  require_relative 'defaults'                           # defaults.rb
+  require_relative 'se'                                 # se.rb
+  require_relative 'html_parts'                         # html_parts.rb
   class CSS_HeadInfo
     def initialize(md,ft='html')
       @md,@ft=md,ft
@@ -162,40 +159,38 @@ module SiSU_Style
     end
   end
   class CSS
-    def initialize
-      @vz=SiSU_Viz::Defaults.new
-    end
+    include SiSU_Parts_HTML
     def fonts
-      @vz.font_fonts
+      the_font.set_fonts
     end
     def html_tables                               #stylesheet for css table_pages
 <<WOK
 /* SiSU table output stylesheet */
   body {
     color: black;
-    background: #{@vz.color_white};
+    background: #{the_color.white};
   }
   p {
     display: block;
     line-height: 1.5;
-    font-family: #{fonts};
+    font-family: #{the_font.set_fonts};
   }
   a:link {
-    color: #{@vz.color_blue_ink};
+    color: #{the_color.blue_ink};
     text-decoration: none;
   }
   a:visited {
-    color: #{@vz.color_blue_ink};
+    color: #{the_color.blue_ink};
     text-decoration: none;
-    /* background-color: #{@vz.color_blue_tinge}; */
+    /* background-color: #{the_color.blue_tinge}; */
   }
   a:hover {
-    color: #{@vz.color_black};
+    color: #{the_color.black};
     text-decoration: underline;
-    background-color: #{@vz.color_yellow_light};
+    background-color: #{the_color.yellow_light};
   }
   a:active {
-    color: #{@vz.color_blue_ink};
+    color: #{the_color.blue_ink};
     text-decoration: underline;
   }
 WOK
@@ -236,7 +231,7 @@ WOK
     margin-bottom: 0px;
     text-indent: 0mm;
   }
-  p, h0, h1, h2, h3, h4, h5, h6 {
+  p, h0, h1, h2, h3, h4, h5, h6, h7 {
     display: block;
     font-family: verdana, arial, georgia, tahoma, sans-serif, helvetica, times, roman;
     font-size: 100%;
@@ -447,7 +442,7 @@ WOK
     padding-left: 0em;
     text-indent: 0em;
   }
-  p, h0, h1, h2, h3, h4, h5, h6 {
+  p, h0, h1, h2, h3, h4, h5, h6, h7 {
     display: block;
     font-family: verdana, arial, georgia, tahoma, sans-serif, helvetica, times, roman;
     font-size: 100%;
@@ -1307,18 +1302,18 @@ WOK
     font-weight: bold;
   }
 
-  h0, h1, h2, h3, h4, h5, h6 {
+  h0, h1, h2, h3, h4, h5, h6, h7 {
     font-weight: bold;
     line-height: 120%;
     text-align: left;
     margin-top: 20px;
     margin-bottom: 10px;
   }
-  h4.norm, h5.norm, h6.norm {
+  h4.norm, h5.norm, h6.norm, h7.norm {
     margin-top: 10px;
     margin-bottom: 0px;
   }
-  h1.center, h2.center, h3.center, h4.center, h5.center, h6.center {
+  h1.center, h2.center, h3.center, h4.center, h5.center, h6.center, h7.center {
     text-align: center;
   }
   h1 { font-size: 120%; }
@@ -1327,6 +1322,7 @@ WOK
   h4 { font-size: 105%; }
   h5 { font-size: 100%; }
   h6 { font-size: 100%; }
+  h7 { font-size: 100%; }
   h0 { font-size: 80%; }
 
   h1.i {margin-left: 2em;}
@@ -1418,6 +1414,8 @@ WOK
   }
   h6.banner {
   }
+  h7.banner {
+  }
 
   .toc {
     font-weight: normal;
@@ -1454,6 +1452,11 @@ WOK
     font-size: 90%;
     line-height: 110%;
   }
+  h7.toc {
+    margin-left: 7em;
+    font-size: 85%;
+    line-height: 100%;
+  }
 
   .microtoc {
     margin-top: 2px;
@@ -1487,6 +1490,11 @@ WOK
     font-weight: normal;
     font-size: 90%;
   }
+  h7.microtoc {
+    margin-left: 30mm;
+    font-weight: normal;
+    font-size: 85%;
+  }
 
   .subtoc {
     margin-right: 34%;
@@ -1504,6 +1512,12 @@ WOK
     margin-top: 0px;
     margin-bottom: 0px;
   }
+  h7.subtoc {
+    margin-left: 4em;
+    font-size: 70%;
+    margin-top: 0px;
+    margin-bottom: 0px;
+  }
 
   div.substance {
     width: 100%;
@@ -1629,15 +1643,19 @@ WOK
     margin-left: 2em;
     font-size: 85%;
   }
+  h7.minitoc {
+    margin-left: 3em;
+    font-size: 80%;
+  }
   h0.minitoc {
     margin-left: 0em;
     font-size: 90%;
   }
 
-  h1.c, h2.c, h3.c, h4.c, h5.c, h6.c, p.c {
+  h1.c, h2.c, h3.c, h4.c, h5.c, h6.c, h7.c, p.c {
     text-align: center
   }
-  h1.red, h2.red, h3.red, h4.red, h5.red, h6.red {
+  h1.red, h2.red, h3.red, h4.red, h5.red, h6.red, h7.red {
     text-align: center;
     color: #ff0000;
     margin-left: 5mm;
@@ -1646,7 +1664,7 @@ WOK
     margin-bottom: 20px;
     margin-right: 15mm;
   }
-  h1.ruby, h2.ruby, h3.ruby, h4.ruby, h5.ruby, h6.ruby {
+  h1.ruby, h2.ruby, h3.ruby, h4.ruby, h5.ruby, h6.ruby, h7.ruby {
     text-align: center;
     color: #990000;
     margin-left: 5mm;
@@ -1659,14 +1677,14 @@ WOK
     end
     def homepage                                  #stylesheet for index, home page
 <<WOK
-  body {color: black; background: #{@vz.color_white}; margin:10px 10px 0px 10px; padding:0px;}
+  body {color: black; background: #{the_color.white}; margin:10px 10px 0px 10px; padding:0px;}
   p { line-height: 1.5 }
-  a:link      {color: #{@vz.color_blue_ink};   text-decoration: none; }
-  a:visited       {color: #{@vz.color_blue_ink};   text-decoration: none; }
-  a:hover {color: #{@vz.color_black}; text-decoration: underline; background-color: #{@vz.color_yellow_light};}
-  a:active {color: #{@vz.color_blue_ink}; text-decoration: underline;}
+  a:link      {color: #{the_color.blue_ink};   text-decoration: none; }
+  a:visited       {color: #{the_color.blue_ink};   text-decoration: none; }
+  a:hover {color: #{the_color.black}; text-decoration: underline; background-color: #{the_color.yellow_light};}
+  a:active {color: #{the_color.blue_ink}; text-decoration: underline;}
   #banner {
-    background:#{@vz.color_white};
+    background:#{the_color.white};
   }
   #column_left {
     width:25%;
@@ -1677,7 +1695,7 @@ WOK
   #column_center {
     width:55%;
     float:left;
-    background:#{@vz.color_white};
+    background:#{the_color.white};
     padding-bottom:10px;
   }
   #column_right {
@@ -1687,7 +1705,7 @@ WOK
     padding-bottom:10px;
   }
   p,h1,pre {
-    font-family: #{fonts};
+    font-family: #{the_font.set_fonts};
     margin:0px 10px 10px 10px;
   }
   h1 {
@@ -1737,7 +1755,7 @@ WOK
     }
     dc {
       display: block;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       color: blue;
       background-color: #dddddd;
       font-weight: normal;
@@ -1755,7 +1773,7 @@ WOK
     }
     keywords,copyright {
       display: block;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       color: red;
       background-color: #dddddd;
       font-weight: normal;
@@ -1811,7 +1829,7 @@ WOK
     }
     text,text[class|="norm"] {
       display: block;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       text-align: justify;
       font-weight: normal;
       font-size: 100%;
@@ -1856,6 +1874,11 @@ WOK
       font-weight: bold;
       text-align: left;
     }
+    text[class|="h7"] {
+      font-size: 110%;
+      font-weight: bold;
+      text-align: left;
+    }
     text[class|="indent0"] {
       padding-left: 10%;
     }
@@ -2352,7 +2375,7 @@ WOK
     endnote {
       display: block;
       font-size: small;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       font-weight: normal;
       line-height: 150%;
       text-align: justify;
@@ -2364,7 +2387,7 @@ WOK
     endnote_indent {
       display: block;
       font-size: small;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       font-weight: normal;
       line-height: 150%;
       text-align: justify;
@@ -2474,7 +2497,7 @@ WOK
     }
     dc {
       display: block;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       color: blue;
       background-color: #dddddd;
       font-weight: normal;
@@ -2492,7 +2515,7 @@ WOK
     }
     keywords,copyright {
       display: block;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       color: red;
       background-color: #dddddd;
       font-weight: normal;
@@ -2544,7 +2567,7 @@ WOK
     }
     text {
       display: block;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       text-align: justify;
       font-size: 100%;
       line-height: 150%;
@@ -2591,6 +2614,11 @@ WOK
       font-weight: bold;
       text-align: left;
     }
+    text[class|="h7"] {
+      font-size: 110%;
+      font-weight: bold;
+      text-align: left;
+    }
     text[class|="indent0"] {
       padding-left: 10%;
     }
@@ -3098,7 +3126,7 @@ WOK
     endnote {
       display: block;
       font-size: small;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       font-weight: normal;
       line-height: 150%;
       text-align: justify;
@@ -3110,7 +3138,7 @@ WOK
     endnote_indent {
       display: block;
       font-size: small;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       font-weight: normal;
       line-height: 150%;
       text-align: justify;
@@ -3147,7 +3175,7 @@ WOK
     }
     dc,sc {
       display: block;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       color: blue;
       background-color: #dddddd;
       font-weight: normal;
@@ -3164,7 +3192,7 @@ WOK
     }
     keywords,copyright {
       display: block;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       color: red;
       background-color: #dddddd;
       font-weight: normal;
@@ -3217,7 +3245,7 @@ WOK
     }
     para {
       display: block;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       /* font-weight: normal; */
       text-align: justify;
       font-size: 100%;
@@ -3231,12 +3259,12 @@ WOK
       text-align: left;
     }
     para.norm {
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       font-weight: normal;
     }
     para.h1, title {
       display: block;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       font-size: 120%;
       font-weight: bold;
       text-align: left;
@@ -3271,6 +3299,11 @@ WOK
       font-weight: bold;
       text-align: left;
     }
+    para.h7 {
+      font-size: 110%;
+      font-weight: bold;
+      text-align: left;
+    }
     table {
       margin-left: 5%;
       display: block;
@@ -3301,7 +3334,7 @@ WOK
     endnote {
       display: block;
       font-size: small;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       font-weight: normal;
       line-height: 150%;
       text-align: justify;
@@ -3313,7 +3346,7 @@ WOK
     endnote_indent {
       display: block;
       font-size: small;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       font-weight: normal;
       line-height: 150%;
       text-align: justify;
@@ -3367,7 +3400,7 @@ WOK
     }
     p {
       display: block;
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       font-size: 100%;
       font-weight: normal;
       line-height: 150%;
@@ -3389,7 +3422,7 @@ WOK
       text-indent: 5%
     }
     p.h1 {
-      font-family: #{fonts};
+      font-family: #{the_font.set_fonts};
       font-weight: bold;
       line-height: 120%;
       margin-left: 10mm;
@@ -3427,6 +3460,11 @@ WOK
       font-weight: bold;
       text-align: left;
     }
+    p.h7 {
+      font-size: 150%;
+      font-weight: bold;
+      text-align: left;
+    }
     ocn {
       display: block;
       text-align: right;
