@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/db_columns.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/db_columns.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -62,7 +59,7 @@
 
 =end
 module SiSU_DbColumns
-  require_relative 'sysenv'                            # sysenv.rb
+  require_relative 'se'                                # se.rb
   require_relative 'db_sqltxt'                         # db_sqltxt.rb
   class Columns < SiSU_DbText::Prepare
     def initialize(md=nil)
@@ -81,7 +78,7 @@ module SiSU_DbColumns
           @sisutxt=special_character_escape(src)
         else @sisutxt=''
         end
-        @fulltext=clean_searchable_text(txt_arr)
+        @fulltext=clean_searchable_text_from_document_objects(txt_arr)
        else @sisutxt,@fulltext='',''
       end
     end
