@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/db_create.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/db_create.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -64,7 +61,7 @@
 module SiSU_DbCreate
   require_relative 'db_columns'                         # db_columns.rb
   class Create < SiSU_DbColumns::Columns
-    require_relative 'sysenv'                           # sysenv.rb
+    require_relative 'se'                               # se.rb
     @@dl=nil
     def initialize(opt,conn,file,sql_type=:pg)
       @opt,@conn,@file,@sql_type=opt,conn,file,sql_type
@@ -117,10 +114,38 @@ module SiSU_DbCreate
         end
       end
       def conn_exec_pg(sql)
-        @conn.exec_params(sql)
+        begin
+          @conn.exec_params(sql)
+        rescue
+          if @conn.is_a?(NilClass)
+            errmsg="No pg connection (check pg dependencies)"
+            if @opt.act[:no_stop][:set]==:on
+              SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                error("#{errmsg}, proceeding without pg output (as requested)")
+            else
+              SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                error("#{errmsg}, STOPPING")
+              exit
+            end
+          end
+        end
       end
       def conn_exec_sqlite(sql)
+        begin
           @conn.execute(sql)
+        rescue
+          if @conn.is_a?(NilClass)
+            errmsg="No sqlite3 connection (check sqlite3 dependencies)"
+            if @opt.act[:no_stop][:set]==:on
+              SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                error("#{errmsg}, proceeding without sqlite output (as requested)")
+            else
+              SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+                error("#{errmsg}, STOPPING")
+              exit
+            end
+          end
+        end
       end
       def metadata_and_text
         if (@opt.act[:verbose_plus][:set]==:on \
@@ -264,6 +289,7 @@ module SiSU_DbCreate
             lev4            SMALLINT,
             lev5            SMALLINT,
             lev6            SMALLINT,
+            lev7            SMALLINT,
             en_a            SMALLINT NULL,
             en_z            SMALLINT NULL,
             en_a_asterisk   SMALLINT NULL,
@@ -506,9 +532,9 @@ module SiSU_DbCreate
           %{COMMENT ON COLUMN doc_objects.metadata_tid
             IS 'tie to title in metadata_and_text';},
           %{COMMENT ON COLUMN doc_objects.lev_an
-            IS 'doc level A-D 1-6';},
+            IS 'doc level A-D 1-4';},
           %{COMMENT ON COLUMN doc_objects.lev
-            IS 'doc level 0-6 \d\~';},
+            IS 'doc level 0-7 \d\~';},
           %{COMMENT ON COLUMN doc_objects.seg
             IS 'segment name from level number 4 (lv 1)';},
           %{COMMENT ON COLUMN doc_objects.ocn
@@ -547,6 +573,8 @@ module SiSU_DbCreate
             IS 'document structure, level number 5';},
           %{COMMENT ON COLUMN doc_objects.lev6
             IS 'document structure, level number 6';},
+          %{COMMENT ON COLUMN doc_objects.lev7
+            IS 'document structure, level number 7';},
           %{COMMENT ON COLUMN doc_objects.t_of
             IS 'document structure, type of object (object is of)';},
           %{COMMENT ON COLUMN doc_objects.t_is
