@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/db_drop.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/db_drop.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -63,7 +60,7 @@
 =end
 module SiSU_DbDrop
   class Drop
-    require_relative 'response'                          # response.rb
+    require_relative 'utils_response'                   # utils_response.rb
     def initialize(opt,conn,db_info,sql_type)
       @opt,@conn,@db_info,@sql_type=opt,conn,db_info,sql_type
       @ans=SiSU_Response::Response.new
