@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/db_import.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/db_import.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -79,7 +76,7 @@ module SiSU_DbImport
       @env=SiSU_Env::InfoEnv.new(@opt.fns)
       @dal="#{@env.processing_path.ao}"
       @fnb=if @opt.fns.empty? \
-      or @opt.cmd.empty?
+      or @opt.selections.str.empty?
         ''
       else
         @md=SiSU_Param::Parameters.new(@opt).get
@@ -105,7 +102,9 @@ module SiSU_DbImport
         ? @conn.execute( sql ).join.to_i
         : @conn.exec( sql ).getvalue(0,0).to_i
       rescue
-        puts "#{__FILE__}:#{__LINE__}" if @opt.act[:maintenance][:set]==:on
+        if @opt.act[:maintenance][:set]==:on
+          puts "#{__FILE__}:#{__LINE__}"
+        end
       end
       @col[:lid]=0 if @col[:lid].nil? or @col[:lid].to_s.empty?
       sql='SELECT MAX(nid) FROM endnotes'
@@ -115,10 +114,12 @@ module SiSU_DbImport
         : @conn.exec( sql ).getvalue(0,0).to_i
         @id_n ||=0
       rescue
-        puts "#{__FILE__}:#{__LINE__}" if @opt.act[:maintenance][:set]==:on
+        if @opt.act[:maintenance][:set]==:on
+          puts "#{__FILE__}:#{__LINE__}"
+        end
       end
       @id_n =0 if @col[:lid].nil? or @col[:lid].to_s.empty?
-      @col[:lv0]=@col[:lv1]=@col[:lv2]=@col[:lv3]=@col[:lv4]=@col[:lv5]=@col[:lv6]=0
+      @col[:lv0]=@col[:lv1]=@col[:lv2]=@col[:lv3]=@col[:lv4]=@col[:lv5]=@col[:lv6]=@col[:lv7]=0
       @db=SiSU_Env::InfoDb.new
       @pdf_fn=SiSU_Env::FileOp.new(@md).base_filename
       @@dl ||=SiSU_Env::InfoEnv.new.digest.length
@@ -233,7 +234,7 @@ module SiSU_DbImport
             @conn.exec("COMMIT")
           end
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
           sqlfn="#{@env.processing_path.sql}/#{@md.fnb}.sql"
@@ -292,7 +293,7 @@ module SiSU_DbImport
         src=txt_arr.join("\n")
         src=special_character_escape(src)
         @tp[:sisutxt_f],@tp[:sisutxt_i]='sisutxt, ',"'#{src}', "
-        txt=clean_searchable_text(txt_arr)
+        txt=clean_searchable_text_from_document_source(txt_arr)
         #txt=special_character_escape(txt)
         @tp[:fulltxt_f],@tp[:fulltxt_i]='fulltxt, ',"'#{txt}', "
       end
@@ -310,7 +311,9 @@ module SiSU_DbImport
           : @conn.exec( sql ).getvalue(0,0).to_i
           @@id_t=id_t if id_t
         rescue
-          puts "#{__FILE__} #{__LINE__}" if @opt.act[:maintenance][:set]==:on
+          if @opt.act[:maintenance][:set]==:on
+            puts "#{__FILE__} #{__LINE__}"
+          end
         end
         @@id_t+=1 #bug related, needs to be performed once at start of file, but consider moving, as, placed here it means program will fail if document header lacks @title:
         if (@opt.act[:verbose][:set]==:on \
@@ -331,17 +334,17 @@ module SiSU_DbImport
         @en,@en_ast,@en_pls,@tuple_array=[],[],[],[]
         @col[:en_a],@col[:en_z]=nil,nil
         ao_array.each do |data|
-          data.obj.gsub!(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,'\1')
-          data.obj.gsub!(/#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}/,'\1')
-          data.obj.gsub!(/#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}/,'\1')
-          data.obj.gsub!(/#{Mx[:fa_superscript_o]}(.+?)#{Mx[:fa_superscript_c]}/,'\1')
-          data.obj.gsub!(/#{Mx[:fa_subscript_o]}(.+?)#{Mx[:fa_subscript_c]}/,'\1')
-          data.obj.gsub!(/#{Mx[:fa_insert_o]}(.+?)#{Mx[:fa_insert_c]}/,'\1')
-          data.obj.gsub!(/#{Mx[:fa_cite_o]}(.+?)#{Mx[:fa_cite_c]}/,'\1')
-          data.obj.gsub!(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,'\1')
-          data.obj.gsub!(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,'\1')
-          data.obj.gsub!(/#{Mx[:gl_o]}(●)#{Mx[:gl_c]}\s*/,'\1 ')
-          data.obj.gsub!(/#{Mx[:tag_o]}\S+?#{Mx[:tag_c]}/,'') #check
+          data.obj=data.obj.gsub(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,'\1').
+            gsub(/#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}/,'\1').
+            gsub(/#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}/,'\1').
+            gsub(/#{Mx[:fa_superscript_o]}(.+?)#{Mx[:fa_superscript_c]}/,'\1').
+            gsub(/#{Mx[:fa_subscript_o]}(.+?)#{Mx[:fa_subscript_c]}/,'\1').
+            gsub(/#{Mx[:fa_insert_o]}(.+?)#{Mx[:fa_insert_c]}/,'\1').
+            gsub(/#{Mx[:fa_cite_o]}(.+?)#{Mx[:fa_cite_c]}/,'\1').
+            gsub(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,'\1').
+            gsub(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,'\1').
+            gsub(/#{Mx[:gl_o]}(●)#{Mx[:gl_c]}\s*/,'\1 ').
+            gsub(/#{Mx[:tag_o]}\S+?#{Mx[:tag_c]}/,'') #check
           @col[:seg]=@@seg
           if data.of ==:para \
           || data.of ==:heading \
@@ -371,12 +374,12 @@ module SiSU_DbImport
               @col[:lid]+=1
               txt=endnotes(txt).extract_any
               body=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_minus
-              @col[:body]=special_character_escape(body)
+              @col[:body]=clean_document_objects_body(body)
               plaintext=@col[:body].dup
               plaintext=strip_markup(plaintext)
-              @col[:plaintext]=clean_searchable_text(plaintext)
+              @col[:plaintext]=clean_searchable_text_from_document_objects(plaintext)
               book_idx=book_idx_hash_to_str(data.idx)
-              @col[:book_idx]=clean_searchable_text(book_idx)
+              @col[:book_idx]=clean_searchable_text_from_document_objects(book_idx)
               if @en[0] then @en_a,@en_z=@en[0].first,@en[0].last
               end
               if @en_ast[0] then @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last
@@ -390,6 +393,7 @@ module SiSU_DbImport
               when /1/ then @col[:lv1]+=1
               when /2/ then @col[:lv2]+=1
               when /3/ then @col[:lv3]+=1
+              when /4/ then @col[:lv4]+=1
               end
               @col[:lev]=@col[:plaintext]=@col[:body]=''
             elsif data.is==:heading \
@@ -421,12 +425,12 @@ module SiSU_DbImport
               @base_url="#{@env.url.root}/#{@md.fnb}/#{@hname}.html"
               txt=endnotes(txt).extract_any
               body=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_plus
-              @col[:body]=special_character_escape(body)
+              @col[:body]=clean_document_objects_body(body)
               plaintext=@col[:body].dup
               plaintext=strip_markup(plaintext)
-              @col[:plaintext]=clean_searchable_text(plaintext)
+              @col[:plaintext]=clean_searchable_text_from_document_objects(plaintext)
               book_idx=book_idx_hash_to_str(data.idx)
-              @col[:book_idx]=clean_searchable_text(book_idx)
+              @col[:book_idx]=clean_searchable_text_from_document_objects(book_idx)
               @en_a,@en_z=@en[0].first,@en[0].last if @en[0]
               @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last if @en_ast[0]
               @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last if @en_pls[0]
@@ -466,12 +470,12 @@ module SiSU_DbImport
               @base_url="#{@env.url.root}/#{@md.fnb}/#{@hname}.html"
               txt=endnotes(txt).extract_any
               body=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_plus
-              @col[:body]=special_character_escape(body)
+              @col[:body]=clean_document_objects_body(body)
               plaintext=@col[:body].dup
               plaintext=strip_markup(plaintext)
-              @col[:plaintext]=clean_searchable_text(plaintext)
+              @col[:plaintext]=clean_searchable_text_from_document_objects(plaintext)
               book_idx=book_idx_hash_to_str(data.idx)
-              @col[:book_idx]=clean_searchable_text(book_idx)
+              @col[:book_idx]=clean_searchable_text_from_document_objects(book_idx)
               @en_a,@en_z=@en[0].first,@en[0].last if @en[0]
               @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last if @en_ast[0]
               @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last if @en_pls[0]
@@ -480,7 +484,8 @@ module SiSU_DbImport
               @col[:lev]=@col[:plaintext]=@col[:body]=''
             elsif data.is==:heading \
             && data.ln==6
-              txt,@col[:ocn],@col[:lev_an],@col[:ocnd],@col[:ocns],@col[:t_of],@col[:t_is],@col[:node],@col[:parent],@col[:digest_clean],@col[:digest_all]=data.obj,data.ocn,data.lv,data.odv,data.osp,data.of,data.is,data.node,data.parent,'',''
+              txt,       @col[:ocn],@col[:lev_an],@col[:ocnd],@col[:ocns],@col[:t_of],@col[:t_is],@col[:node],@col[:parent],@col[:digest_clean],@col[:digest_all]=
+                data.obj,data.ocn,  data.lv,      data.odv,   data.osp,   data.of,    data.is,    data.node,  data.parent,  '',                 ''
               @@seg_full=data.name if data.is==:heading && data.ln==6 && data.name #check data.name
               @@seg ||='' #nil # watch
               @col[:seg]=@@seg
@@ -496,12 +501,43 @@ module SiSU_DbImport
               @base_url="#{@env.url.root}/#{@md.fnb}/#{@hname}.html"
               txt=endnotes(txt).extract_any
               body=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_plus
-              @col[:body]=special_character_escape(body)
+              @col[:body]=clean_document_objects_body(body)
               plaintext=@col[:body].dup
               plaintext=strip_markup(plaintext)
-              @col[:plaintext]=clean_searchable_text(plaintext)
+              @col[:plaintext]=clean_searchable_text_from_document_objects(plaintext)
               book_idx=book_idx_hash_to_str(data.idx)
-              @col[:book_idx]=clean_searchable_text(book_idx)
+              @col[:book_idx]=clean_searchable_text_from_document_objects(book_idx)
+              @en_a,@en_z=@en[0].first,@en[0].last if @en[0]
+              @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last if @en_ast[0]
+              @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last if @en_pls[0]
+              t=SiSU_DbTuple::LoadDocuments.new(@conn,@col,@opt,@file_maint)
+              @tuple_array << t.tuple
+              @col[:lev]=@col[:plaintext]=@col[:body]=''
+            elsif data.is==:heading \
+            && data.ln==7
+              txt,       @col[:ocn],@col[:lev_an],@col[:ocnd],@col[:ocns],@col[:t_of],@col[:t_is],@col[:node],@col[:parent],@col[:digest_clean],@col[:digest_all]=
+                data.obj,data.ocn,  data.lv,      data.odv,   data.osp,   data.of,    data.is,    data.node,  data.parent,  '',                 ''
+              @@seg_full=data.name if data.is==:heading && data.ln==7 && data.name #check data.name
+              @@seg ||='' #nil # watch
+              @col[:seg]=@@seg
+              @col[:lv7]+=1
+              @col[:lid]+=1
+              @col[:lev]=7
+              @hname=if @col[:seg] \
+              and not @col[:seg].to_s.empty?
+                @@hname=@col[:seg].to_s
+              else @@hname
+              end
+              @env=SiSU_Env::InfoEnv.new(@md.fns)
+              @base_url="#{@env.url.root}/#{@md.fnb}/#{@hname}.html"
+              txt=endnotes(txt).extract_any
+              body=SiSU_FormatShared::CSS_Format.new(@md,data).lev4_plus
+              @col[:body]=clean_document_objects_body(body)
+              plaintext=@col[:body].dup
+              plaintext=strip_markup(plaintext)
+              @col[:plaintext]=clean_searchable_text_from_document_objects(plaintext)
+              book_idx=book_idx_hash_to_str(data.idx)
+              @col[:book_idx]=clean_searchable_text_from_document_objects(book_idx)
               @en_a,@en_z=@en[0].first,@en[0].last if @en[0]
               @en_a_asterisk,@en_z_asterisk=@en_ast[0].first,@en_ast[0].last if @en_ast[0]
               @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last if @en_pls[0]
@@ -567,12 +603,12 @@ module SiSU_DbImport
               else
                 SiSU_FormatShared::CSS_Format.new(@md,data).norm
               end
-              @col[:body]=special_character_escape(body)
+              @col[:body]=clean_document_objects_body(body)
               plaintext=@col[:body].dup
               plaintext=strip_markup(plaintext)
-              @col[:plaintext]=clean_searchable_text(plaintext)
+              @col[:plaintext]=clean_searchable_text_from_document_objects(plaintext)
               book_idx=book_idx_hash_to_str(data.idx)
-              @col[:book_idx]=clean_searchable_text(book_idx)
+              @col[:book_idx]=clean_searchable_text_from_document_objects(book_idx)
               t=SiSU_DbTuple::LoadDocuments.new(@conn,@col,@opt,@file_maint)
               @tuple_array << t.tuple
               @en,@en_ast,@en_pls=[],[],[]
@@ -700,7 +736,7 @@ module SiSU_DbImport
           end
         end
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -833,7 +869,7 @@ module SiSU_DbImport
         t=SiSU_DbTuple::LoadUrls.new(@conn,f,u,@@id_t,@opt,@file_maint)
         tuple=t.tuple
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
