@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/db_sqltxt.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/db_sqltxt.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -63,15 +60,51 @@
 module SiSU_DbText
   class Prepare
     def special_character_escape(str)
-      str=str.gsub(/'/,"''"). #string.gsub!(/'/,"\047") #string.gsub!(/'/,"\\'")
+      str=str.gsub(/'/m,"''"). #string.gsub!(/'/,"\047") #string.gsub!(/'/,"\\'")
         gsub(/(\\)/m,'\1\1'). #ok but with warnings, double backslash on sqlite #str.gsub!(/[\\]/m,'\\x5C') #ok but with warnings, but not for sqlite #str.gsub!(/(\\)/m,'\1') #ok for sqlite not for pgsql
-        gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,"<br />\n").
-        gsub(/#{Mx[:tag_o]}\S+?#{Mx[:tag_c]}/,''). #check
-        gsub(/#{Mx[:lnk_o]}\s*(\S+?\.(?:png|jpg))(?:\s+\d+x\d+)?(.+?)#{Mx[:lnk_c]}\S+/,'[image: \1] \2').
-        gsub(/#{Mx[:lnk_o]}\s*(.+?)\s*#{Mx[:lnk_c]}(?:file|ftp):\/\/\S+?([.,!?]?(?:\s|$))/,'\1\2').
-        gsub(/#{Mx[:lnk_o]}\s*(.+?)\s*#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/,'\1')
+        gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}/m,"<br>\n").
+        gsub(/#{Mx[:tag_o]}\S+?#{Mx[:tag_c]}/m,''). #check
+        gsub(/#{Mx[:lnk_o]}\s*(\S+?\.(?:png|jpg))(?:\s+\d+x\d+)?(.+?)#{Mx[:lnk_c]}\S+/m,'[image: \1] \2').
+        gsub(/#{Mx[:lnk_o]}\s*(.+?)\s*#{Mx[:lnk_c]}(?:file|ftp):\/\/\S+?([.,!?]?(?:\s|$))/m,'\1\2').
+        gsub(/#{Mx[:lnk_o]}\s*(.+?)\s*#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/m,'\1')
     end
-    def clean_searchable_text(arr) #produce clean, searchable, plaintext from document source
+    def clean_searchable_text_from_document_objects(arr)
+      txt_arr,en=[],[]
+      arr=(arr.is_a?(String)) ? [ arr ] : arr
+      arr.each do |s|
+        s=s.gsub(/#{Mx[:fa_o]}[a-z]{1,4}#{Mx[:fa_o_c]}/m,'').
+            gsub(/#{Mx[:fa_c_o]}[a-z]{1,4}#{Mx[:fa_c]}/m,'').
+            gsub(/<br>/m,' ')
+        en << s.scan(/#{Mx[:en_a_o]}\s*(.+?)\s*#{Mx[:en_a_c]}/m)
+        s=s.gsub(/#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}/m,'').
+          gsub(/#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]}/m,'').
+          gsub(/ \s+/m,' ')
+        #p s if s =~/[^ \nA-Za-z0-9'"`?!#@$%^&*=+,.;:\[\]()<>{}‹›|\\\/~_-]/
+        txt_arr << s
+      end
+      txt_arr=txt_arr << en
+      txt=txt_arr.flatten.join("\n")
+      special_character_escape(txt)
+    end
+    def clean_document_objects_body(arr)
+      txt_arr,en,en_arr=[],[],[]
+      arr=(arr.is_a?(String)) ? [ arr ] : arr
+      arr.each do |s|
+        en << s.scan(/#{Mx[:en_a_o]}\s*(.+?)\s*#{Mx[:en_a_c]}/m)
+        s=s.gsub(/#{Mx[:en_a_o]}\s*(\d+).+?#{Mx[:en_a_c]}/m,'<sup>\1</sup>').
+          gsub(/#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]}/m,'').
+          gsub(/ \s+/m,' ')
+        txt_arr << s
+      end
+      en.flatten.each do |e|
+        e=e.sub(/^(\d+)\s*/,'<sup>\1</sup> ')
+        en_arr << e
+      end
+      txt_arr=txt_arr << en_arr
+      txt=txt_arr.flatten.join("\n<br>")
+      special_character_escape(txt)
+    end
+    def clean_searchable_text_from_document_source(arr)
       txt_arr,en=[],[]
       arr=(arr.is_a?(String)) ? arr.split(/\n+/m) : arr
       arr.each do |s|
@@ -107,14 +140,14 @@ module SiSU_DbText
           gsub(/^(?::?[A-C]\~(\S+)?)\s+/m,'').
           gsub(/^%{1,3} .+/m,''). #removed even if contained in code block
           gsub(/<br>/m,' ')
-        en << s.scan(/~\{\s*(.+?)\s*\}~/m)
+        #en << s.scan(/~\{\s*(.+?)\s*\}~/m)
         s=s.gsub(/~\{.+?\}~/m,'').
           gsub(/ \s+/m,' ')
-        #special_character_escape(s)
+        ##special_character_escape(s)
+        #p s if s =~/[^ \nA-Za-z0-9'"`?!#@$%^&*=+,.;:\[\]()<>{}‹›|\\\/~_-]/
         s
       end
       txt_arr << arr << en
-      #txt_arr=txt_arr.flatten
       txt=txt_arr.flatten.join("\n")
       txt=special_character_escape(txt)
       txt
