@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/dbi.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/dbi.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,9 +58,9 @@
 
 =end
 module  SiSU_DBI                                                                 #% database building
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env; include SiSU_Screen
-  require_relative 'param'                              # param.rb
+  require_relative 'dp'                                 # dp.rb
     include SiSU_Param
   require_relative 'db_dbi'                             # db_dbi.rb
     include SiSU_DbDBI
@@ -97,13 +94,17 @@ module  SiSU_DBI
       end
     end
     def maintenance_check(opt,file,line)
-      p opt.mod
-      p opt.cmd
+      p opt.selections.str
       p "at #{file} #{line}"
     end
     def read_psql
       begin
-        require 'pg'
+        begin
+          require 'pg'
+        rescue LoadError
+          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+            error('pg NOT FOUND (LoadError)')
+        end
         @conn=@db.psql.conn_pg
       rescue
         if @opt.act[:psql_create][:set]==:on
@@ -120,10 +121,23 @@ manually create the database: "#{cX.green}#{@db.db}#{cX.off}" if it does not yet
     def read_sqlite
       begin
         begin
-          require 'sqlite3'
+          begin
+            require 'sqlite3'
+          rescue LoadError
+            SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+              error('sqlite3 NOT FOUND (LoadError)')
+          end
           @conn=@db.sqlite.conn_sqlite3
         rescue LoadError
-          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('sqlite3 NOT FOUND (LoadError)')
+          errmsg='sqlite3 NOT FOUND (LoadError)'
+          if @opt.act[:no_stop][:set]==:on
+            SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+              error(errmsg + ', ' + 'attempt to proceed without sqlite output (as requested)')
+          else
+            SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+              error(errmsg + ', ' + 'STOPPING')
+            exit
+          end
         end
       end
     end
@@ -134,7 +148,7 @@ manually create the database: "#{cX.green}#{@db.db}#{cX.off}" if it does not yet
       end
       SiSU_Screen::Ansi.new(
         @opt.act[:color_state][:set],
-        "DBI (#{@sql_type}) #{@opt.mod}",
+        "SQL DB #{@sql_type.upcase}",
         @opt.fno
       ).dbi_title unless @opt.act[:quiet][:set]==:on
       begin
