@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/html.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/html.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -64,13 +61,13 @@ module SiSU_HTML
   begin
     require 'pstore'
   rescue LoadError
-    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('pstore NOT FOUND (LoadError)')
+    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+      error('pstore NOT FOUND (LoadError)')
   end
-  require_relative 'particulars'                        # particulars.rb
+  require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
-  require_relative 'defaults'                           # defaults.rb
-    include SiSU_Viz
   require_relative 'html_table'                         # html_table.rb
+  require_relative 'html_parts'                         # html_parts.rb
   require_relative 'html_format'                        # html_format.rb
     include SiSU_HTML_Format
   require_relative 'html_segments'                      # html_segments.rb
@@ -146,11 +143,18 @@ module SiSU_HTML
         data=tuned_file_array
         if @opt.act[:html_scroll][:set]==:on
           scr=SiSU_HTML::Source::Scroll.new(@md,data,scr_endnotes).songsheet
-          scroll=SiSU_HTML::Source::ScrollOutput.new(scr_toc,scr[:body],scr[:metadata],scr[:owner_details],scr[:tails],@md).publish
+          scroll=SiSU_HTML::Source::ScrollOutput.new(
+            scr_toc,
+            scr[:body],
+            scr[:metadata],
+            scr[:owner_details],
+            scr[:tails],
+            @md
+          ).publish
           SiSU_HTML::Source::Output.new(scroll,@md).scroll
         end
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -163,7 +167,7 @@ module SiSU_HTML
             end
           end
         end
-        SiSU_Env::Clear.new(@opt.cmd,@opt.fns,@md).param_instantiate
+        SiSU_Env::Clear.new(@opt.selections.str,@opt.fns,@md).param_instantiate
         @@flag,@@scr,@@seg,@@seg_endnotes,@@seg_subtoc,@@seg_ad={},{},{},{},{},{}
         @@seg_total,@@tracker,@@loop_count,@@tablehead,@@number_of_cols=0,0,0,0,0
         @@seg_name,@@seg_name_html,@@seg_subtoc_array,@@seg_endnotes_array,@@segtocband,@@tablefoot=Array.new(7){[]}
@@ -176,7 +180,6 @@ module SiSU_HTML
       def initialize(particulars)
         @particulars=particulars
         @md,@env=particulars.md,particulars.env
-        @vz=SiSU_Viz::Defaults.new
         @env,@css=particulars.env,SiSU_Style::CSS.new
       end
       def tuned_file_instructions
@@ -206,7 +209,11 @@ module SiSU_HTML
                 ? 'external'
                 : '_top'
                 s_lnk_url,s_lnk_lnk=l[:url],l[:say]
-                txt_obj={ lnk_url: s_lnk_url, lnk_txt: s_lnk_lnk, target: target }
+                txt_obj={
+                  lnk_url: s_lnk_url,
+                  lnk_txt: s_lnk_lnk,
+                  target: target,
+                }
                 lev_dob_ocn=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
                 @links_guide_toc << lev_dob_ocn.links_guide if s_lnk_lnk
               end
@@ -258,8 +265,8 @@ module SiSU_HTML
       @@firstseg=nil
       def initialize(md=nil,data='')
         @data,@md=data,md
-        @vz=SiSU_Viz::Defaults.new
-        @ocn_html_identifier=SiSU_Env::ProcessingSettings.new(@md).ocn_html_identifier
+        @ocn_html_identifier=
+          SiSU_Env::ProcessingSettings.new(@md).ocn_html_identifier
         @tell=SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set]) if @md
       end
       def songsheet #extracts toc for scroll & seg
@@ -305,7 +312,7 @@ module SiSU_HTML
                 @@toc[:seg_mini] << toc[:seg_mini] if toc[:seg_mini]
                 @@toc[:scr] << toc[:scr] if toc[:scr]
               rescue
-                SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+                SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
                   __LINE__.to_s + ':' + __FILE__
                 end
               end
@@ -324,11 +331,11 @@ module SiSU_HTML
         @@toc[:seg] <<<<WOK
 <center>
 <table><tr><td>
-<p><font color="#222222" #{@font.face} size="2">
-(relatively static) RSS feeds for DOCUMENTS:<br />
-<a href="../rssfeed/documents.xml"><img border="0" height="14" width="36" src="../_sisu/image/rss.png" alt="RSS feed"></a>&nbsp;http://www.jus.uio.no/lm/rssfeed/documents.xml<br />
-<a href="../rssfeed/tradelaw.xml"><img border="0" height="14" width="36" src="../_sisu/image/rss.png" alt="RSS feed"></a>&nbsp;http://www.jus.uio.no/lm/rssfeed/tradelaw.xml<br />
-<a href="../rssfeed/environmental.xml"><img border="0" height="14" width="36" src="../_sisu/image/rss.png" alt="RSS feed"></a>&nbsp;http://www.jus.uio.no/lm/rssfeed/environmental.xml<br />
+<p><font color="#222222" #{the_font.set_face} size="2">
+(relatively static) RSS feeds for DOCUMENTS:<br>
+<a href="../rssfeed/documents.xml"><img border="0" height="14" width="36" src="../_sisu/image/rss.png" alt="RSS feed"></a>&nbsp;http://www.jus.uio.no/lm/rssfeed/documents.xml<br>
+<a href="../rssfeed/tradelaw.xml"><img border="0" height="14" width="36" src="../_sisu/image/rss.png" alt="RSS feed"></a>&nbsp;http://www.jus.uio.no/lm/rssfeed/tradelaw.xml<br>
+<a href="../rssfeed/environmental.xml"><img border="0" height="14" width="36" src="../_sisu/image/rss.png" alt="RSS feed"></a>&nbsp;http://www.jus.uio.no/lm/rssfeed/environmental.xml<br>
 <center><a href="mailto:info@address.com" target="_top">info@address.com</a></center>
 </font></p>
 </td></tr></table>
@@ -373,7 +380,7 @@ WOK
         toc[:seg_mini]=format_toc.mini_lev0
         title=if dob.ocn ==0 then linkname
         else
-          @@toc[:scr] <<  '<br />'
+          @@toc[:scr] <<  '<br>'
           %{<b><a href="##{@ocn_html_identifier}#{dob.ocn}">#{linkname}</a></b>}
         end
         txt_obj={ txt: title }
@@ -415,7 +422,7 @@ WOK
           else linkname
           end
         else
-          @@toc[:scr] <<  '<br />'
+          @@toc[:scr] <<  '<br>'
           %{<b><a href="##{@ocn_html_identifier}#{dob.ocn}">#{linkname}</a></b>}
         end
         txt_obj={ txt: title }
@@ -597,9 +604,9 @@ WOK
       end
     end
     class ScrollHeadAndSegToc < Toc
+      include SiSU_Parts_HTML
       def initialize(md='',toc='',links_guide_toc='')
         @md,@toc,@links_guide_toc=md,toc,links_guide_toc
-        @vz=SiSU_Viz::Defaults.new
         @make=SiSU_Env::ProcessingSettings.new(@md)
       end
       def in_common
@@ -652,11 +659,11 @@ WOK
           toc_shared << format_txt_obj.center_bold
           @segtoc << format_txt_obj.center_bold
         end
-        toc_shared << "#{@vz.table_close*1}\n"
-        @segtoc << "#{@vz.table_close*1}\n"
+        toc_shared << "#{the_table_close*1}\n"
+        @segtoc << "#{the_table_close*1}\n"
         tmp_head=nil
         if @md.prefix_a
-          tmp_head ||= %{<p />#{@md.prefix_a}\n}
+          tmp_head ||= %{<p>#{@md.prefix_a}\n}
           toc_shared << tmp_head.dup
           @segtoc << tmp_head.dup
         end
@@ -729,7 +736,7 @@ WOK
               end
             end
           rescue
-            SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+            SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
               __LINE__.to_s + ':' + __FILE__
             end
           ensure
@@ -751,7 +758,7 @@ WOK
               end
             end
           rescue
-            SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+            SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
               __LINE__.to_s + ':' + __FILE__
             end
           ensure
