@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/manpage.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/manpage.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -63,13 +60,13 @@
 =end
 module SiSU_Manpage
   require_relative 'ao'                                 # ao.rb
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   include SiSU_Param
-  include SiSU_Viz
   require_relative 'manpage_format'                     # manpage_format.rb
     include SiSU_ManpageFormat
   require_relative 'shared_metadata'                    # shared_metadata.rb
+  require_relative 'generic_parts'                      # generic_parts.rb
   require_relative 'txt_shared'                         # txt_shared.rb
   @@alt_id_count,@@alt_id_count,@@tablehead,@@number_of_cols=0,0,0,0
   @@tablefoot=''
@@ -94,7 +91,7 @@ module SiSU_Manpage
         (@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on) \
-        && @opt.cmd !~/q/ \
+        && @opt.act[:quiet][:set]==:on \
         ? SiSU_Screen::Ansi.new(
             @opt.act[:color_state][:set],
             'Manpage',
@@ -116,7 +113,7 @@ module SiSU_Manpage
         @ao_array=SiSU_AO::Source.new(@opt).get # ao file drawn here
         SiSU_Manpage::Source::Scroll.new(@md,@ao_array).songsheet
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -125,14 +122,11 @@ module SiSU_Manpage
     end
     private
     class Scroll <Source
-      require_relative 'defaults'                       # defaults.rb
-      require_relative 'txt_shared'                     # txt_shared.rb
-        include SiSU_TextUtils
+      include SiSU_Parts_Generic
+      include SiSU_TextUtils
       @@endnotes={ para: [], end: [] }
       def initialize(md,data)
         @md,@data=md,data
-        @brace_url=SiSU_Viz::Defaults.new.url_decoration
-        @vz=SiSU_Viz::Defaults.new
         @tab="\t"
         @@notes=:end
         @manpage={ body: [], open: [], close: [], head: [], metadata: [], tail: [], endnotes: [] }
@@ -210,7 +204,7 @@ GSUB
        More information about SiSU can be found at <http://www.sisudoc.org/> or <http://www.jus.uio.no/sisu/>
 .TP
 .SH SOURCE
-       <http://sources.sisudoc.org/>
+       <http://git.sisudoc.org/>
 .TP
 .SH AUTHOR
        SiSU is written by Ralph Amissah <ralph@amissah.com>
@@ -303,9 +297,9 @@ WOK
               "\n.I \\1\\2#{Mx[:br_line]}")
           unless dob.is==:code
             dob.obj=dob.obj.gsub(/(?:^|\s)#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}([,.:!?](?: |$))?/,
-                "\\1 #{@brace_url.txt_open}\\2#{@brace_url.txt_close}\\3").
+                "\\1 #{the_text.url_open}\\2#{the_text.url_close}\\3").
               gsub(/(^|#{Mx[:gl_c]}|\s)#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}([,.:!?](?: |$))?/,
-                "\\1#{@brace_url.txt_open}\\2#{@brace_url.txt_close}\\3")
+                "\\1#{the_text.url_open}\\2#{the_text.url_close}\\3")
             @manpage[:endnotes]=extract_endnotes(dob)
             dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d*+]+)\s*(?:.+?)#{Mx[:en_a_c]}/m,'[^\1]'). # endnote marker marked up
               gsub(/#{Mx[:en_b_o]}([\d*+]+)\s*(?:.+?)#{Mx[:en_b_c]}/m,'[^\1]'). # endnote marker marked up
