@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/po4a.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/po4a.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -63,13 +60,12 @@
 =end
 module SiSU_Po4a
   require_relative 'ao'                                 # ao.rb
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   require_relative 'ao_composite'                       # ao_composite.rb
   require_relative 'shared_metadata'                    # shared_metadata.rb
   require_relative 'po4a_set'                           # po4a_set.rb
   include SiSU_Param
-  include SiSU_Viz
   class Source
     @@opt_src,@@opt_trn,@@opt_src_,@@opt_trn_,@@md_src,@@md_trn=nil,nil,nil,nil,nil,nil
     def initialize(opt,fn=nil)
@@ -167,7 +163,7 @@ module SiSU_Po4a
           SiSU_Po4a::Source::Scroll.new(fn,@ao_array_lang_src,@ao_array_lang_translation,@@md_src,@@md_trn,wrap_width).songsheet
         end
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -175,8 +171,6 @@ module SiSU_Po4a
     end
     private
     class Scroll <Source
-      require_relative 'defaults'                       # defaults.rb
-      require_relative 'po4a_set'                       # po4a_set.rb
       include SiSU_Po4aUtils
       @@endnotes={ para: [], end: [] }
       def initialize(fn,data_src,data_trn,md_src,md_trn,wrap_width)
@@ -184,11 +178,9 @@ module SiSU_Po4a
         @md=(md_trn.nil?) \
         ? md_src
         : md_trn
-        @brace_url=SiSU_Viz::Defaults.new.url_decoration
-        @vz=SiSU_Viz::Defaults.new
         @tab="\t"
-        @@endnotes_=(@md.opt.mod.inspect =~/--endnote/) ? true : false    # --footnote
-        @br=(@md.opt.mod.inspect =~/--dos/) ? "\r\n" : "\n"               # --unix
+        @@endnotes_=(@md.opt.selections.str =~/--endnote/) ? true : false    # --footnote
+        @br=(@md.opt.selections.str =~/--dos/) ? "\r\n" : "\n"               # --unix
         @pot={ body: [], open: [], close: [], head: [], metadata: [], tail: [] }
       end
       def songsheet
@@ -874,7 +866,6 @@ GSUB
             gsub(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,'\1 [link: <\2>]').
             gsub(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}image/,'\1 [link: local image]').
             gsub(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,'\1')
-          #dob.obj.gsub!(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,"#{@brace_url.txt_open}\\1#{@brace_url.txt_close}")
           notes=extract_endnotes(dob)
           #% ### footnotes current state - extracted
           dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'~^').   # endnote marker marked up
