@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/qrcode.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/qrcode.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,16 +58,16 @@
 
 =end
 module SiSU_QRcode
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   require_relative 'prog_text_translation'              # prog_text_translation.rb
-  require_relative 'particulars'                        # particulars.rb
+  require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
   require_relative 'html'                               # html.rb
-  require_relative 'param'                              # param.rb
+  require_relative 'dp'                                 # dp.rb
     include SiSU_Param
+  require_relative 'generic_parts'                      # generic_parts.rb
   require_relative 'i18n'                               # i18n.rb
-  include SiSU_Viz
   class Source
     def initialize(opt)
       @opt=opt
@@ -111,7 +108,7 @@ module SiSU_QRcode
         data=SiSU_HTML::Source::HTML_Environment.new(@particulars).tuned_file_instructions
         OutputInfo.new(@md).check_output(data)
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -119,6 +116,7 @@ module SiSU_QRcode
     end
     private
     class OutputInfo <Source
+      include SiSU_Parts_Generic
       def initialize(md)
         @manifest={ txt: [], txt_title: [] }
         @md,@fns=md,md.fns
@@ -132,7 +130,6 @@ module SiSU_QRcode
         l=SiSU_Env::StandardiseLanguage.new(@md.opt.lng).language
         @language=l[:n]
         @translate=SiSU_Translate::Source.new(@md,@language)
-        @brace_url=SiSU_Viz::Defaults.new.url_decoration
         @f.make_path(@f.output_path.qrcode.dir)
       end
       def spaces
@@ -152,7 +149,7 @@ module SiSU_QRcode
           mn += x
         end
         manifest.close if @md.opt.act[:maintenance][:set]==:on
-        cmd=SiSU_Env::SystemCall.new(mn,@f.place_file.qrcode_md.dir,@md.opt.cmd)
+        cmd=SiSU_Env::SystemCall.new(mn,@f.place_file.qrcode_md.dir,@md.opt.selections.str)
         cmd.qrencode
       end
       def output_metadata_short
@@ -160,7 +157,7 @@ module SiSU_QRcode
         @manifest[:txt_title].each do |x|
           mn += x
         end
-        cmd=SiSU_Env::SystemCall.new(mn,@f.place_file.qrcode_title.dir,@md.opt.cmd)
+        cmd=SiSU_Env::SystemCall.new(mn,@f.place_file.qrcode_title.dir,@md.opt.selections.str)
         cmd.qrencode
       end
       def summarize(id,file,pth='',rel='',url='',img='● ')
@@ -168,7 +165,7 @@ module SiSU_QRcode
         kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
         @manifest[:txt] <<<<WOK
 #{id} #{kb}
-  #{@brace_url.txt_open}#{url}/#{file}#{@brace_url.txt_close}
+  #{the_text.url_open}#{url}/#{file}#{the_text.url_close}
 WOK
       end
       def summarize_html_seg(id,file,pth='',rel='',url='',img='● ')
@@ -176,24 +173,25 @@ WOK
         kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
         @manifest[:txt] <<<<WOK
 #{id} #{kb}
-  #{@brace_url.txt_open}#{url}/#{file}#{@brace_url.txt_close}
+  #{the_text.url_open}#{url}/#{file}#{the_text.url_close}
 WOK
       end
       def summarize_sources(id,file,pth,rel,url)
         sys=SiSU_Env::SystemCall.new
         dgst=case @dg
         when :sha512
-          (sys.sha516("#{pth}/#{file}")) #check
+          (sys.sha512("#{pth}/#{file}")) #check
         when :md5
           (sys.md5("#{pth}/#{file}"))
         else
           (sys.sha256("#{pth}/#{file}"))
         end
+        dgst=dgst ? dgst : [ '', 'n/a' ]
         if (@md.opt.act[:verbose][:set]==:on \
         || @md.opt.act[:verbose_plus][:set]==:on \
         || @md.opt.act[:maintenance][:set]==:on)
           SiSU_Screen::Ansi.new(
-            @md.opt.cmd,
+            @md.opt.selections.str,
             "#{dgst[1]} #{file}"
           ).warn
         end
@@ -201,7 +199,7 @@ WOK
         kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
         @manifest[:txt] <<<<WOK
 #{id} #{dgst[1]} #{kb}
-  #{@brace_url.txt_open}#{url}/#{file}#{@brace_url.txt_close}
+  #{the_text.url_open}#{url}/#{file}#{the_text.url_close}
 WOK
       end
       def published_manifests?
@@ -249,7 +247,7 @@ WOK
       def published_languages(id,file)
         flv=published_manifests?
         flv.each do |l|
-          @manifest[:txt] << "#{l[:l]}  #{@brace_url.txt_open}#{l[:mu]}#{@brace_url.txt_close}\n"
+          @manifest[:txt] << "#{l[:l]}  #{the_text.url_open}#{l[:mu]}#{the_text.url_close}\n"
         end
       end
       def metadata(id,info)
@@ -265,7 +263,7 @@ WOK
         elsif url =~/^\.\.\//   then url.gsub(/^\.(\.)?/,@env.url.root)
         else                         url
         end
-        @manifest[:txt] << %{#{url} #{lnk} #{@brace_url.txt_open}#{static}#{@brace_url.txt_close}\n}
+        @manifest[:txt] << %{#{url} #{lnk} #{the_text.url_open}#{static}#{the_text.url_close}\n}
       end
       def output_tests
         if FileTest.file?(@f.place_file.html_segtoc.dir)==true
@@ -403,12 +401,13 @@ WOK
           summarize(id,file,pth,rel,url)
         end
         if FileTest.file?(@f.place_file.txt.dir)==true
-          id=if @md.opt.cmd =~/a/ then 'Plaintext (Unix (UTF-8) with footnotes)'
-          elsif @md.opt.cmd =~/e/ then 'Plaintext (Unix (UTF-8) with endnotes)'
-          elsif @md.opt.cmd =~/A/ then 'Plaintext (dos (UTF-8) with footnotes)'
-          elsif @md.opt.cmd =~/E/ then 'Plaintext (dos (UTF-8) with endnotes)'
-          else                         'Plaintext (UTF-8)'
-          end
+          id='Plaintext (UTF-8)'
+          #id=if @md.opt.selections.str =~/a/ then 'Plaintext (Unix (UTF-8) with footnotes)'
+          #elsif @md.opt.selections.str =~/e/ then 'Plaintext (Unix (UTF-8) with endnotes)'
+          #elsif @md.opt.selections.str =~/A/ then 'Plaintext (dos (UTF-8) with footnotes)'
+          #elsif @md.opt.selections.str =~/E/ then 'Plaintext (dos (UTF-8) with endnotes)'
+          #else                         'Plaintext (UTF-8)'
+          #end
           pth=@f.output_path.txt.dir
           rel=@f.output_path.txt.rel_sm
           url=@f.output_path.txt.url
@@ -732,11 +731,11 @@ WOK
           end
           @manifest[:txt] <<<<WOK
 #{@translate.manifest_description_metadata}
-  #{@brace_url.txt_open}#{@en_manifest}#{@brace_url.txt_close}
+  #{the_text.url_open}#{@en_manifest}#{the_text.url_close}
 WOK
           metadata_tests
           @manifest[:txt_title] <<<<WOK
-  #{@brace_url.txt_open}#{@en_manifest}#{@brace_url.txt_close}
+  #{the_text.url_open}#{@en_manifest}#{the_text.url_close}
 WOK
           source_tests
           @manifest[:txt] <<<<WOK
@@ -746,7 +745,7 @@ WOK
           output_metadata
           output_metadata_short
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         ensure
