@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/relaxng.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/relaxng.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,7 +58,7 @@
 
 =end
 module SiSU_Relaxng
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
   class RelaxNG
     def gpl3_or_later
       @gpl3_or_later =<<RELAXNG
@@ -110,9 +107,6 @@ module SiSU_Relaxng
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
-
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
