@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/remote.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/remote.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,7 +58,7 @@
 
 =end
 module SiSU_Remote
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   class Put
     def initialize(opt)
@@ -152,7 +149,8 @@ module SiSU_Remote
         require 'open-uri'
         require 'pp'
       rescue LoadError
-        SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('open-uri or pp NOT FOUND (LoadError)')
+        SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+          error('open-uri or pp NOT FOUND (LoadError)')
       end
       require_relative 'ao_composite'                   # ao_composite.rb
       @rgx_image=/(?:^|[^_\\])\{\s*(\S+?\.(?:png|jpg|gif))/
@@ -201,7 +199,8 @@ module SiSU_Remote
         begin
           require 'net/http'
         rescue LoadError
-          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('net/http NOT FOUND (LoadError)')
+          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).
+            error('net/http NOT FOUND (LoadError)')
         end
         for requested_pod in get_p
           pod_info=RemoteDownload.new(requested_pod)
