@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/shared_metadata.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/shared_metadata.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,7 +58,10 @@
 
 =end
 module SiSU_Metadata
+  require_relative 'xml_parts'                          # xml_parts.rb
+  require_relative 'xml_shared'                         # xml_shared.rb
   class Summary
+    include SiSU_Parts_XML
     attr_accessor :tag,:inf,:class,:attrib
     def initialize(md,display_heading=false)
       @md,@display_heading=md,display_heading
@@ -73,6 +73,14 @@ module SiSU_Metadata
       language=l[:n]
       tr=SiSU_Translate::Source.new(@md,language)
       @attrib='md'
+      def meta_content_clean(content='')
+        content=if not content.nil?
+          content=content.tr('"',"'").
+            gsub(/&/,'&amp;')
+          content=SiSU_XML_Munge::Trans.new(@md).char_enc.utf8(content)
+        else content
+        end
+      end
       if @display_heading
         @tag,@inf=%{<b><u>Document Metadata</u></b>},''
         meta << self.meta_para
@@ -114,7 +122,7 @@ module SiSU_Metadata
       end
       if defined? @md.rights.all \
       and @md.rights.all=~/\S+/
-        @tag,@inf,@class=tr.rights,@md.rights.all,'dc' #15
+        @tag,@inf,@class=tr.rights,meta_content_clean(@md.rights.all),'dc' #15
         meta << self.meta_para
       end
       if defined? @md.classify.subject \
@@ -809,7 +817,8 @@ module SiSU_Metadata
     end
     def xml_docbook
       def meta_para
-        inf_xml=char_enc(@inf).utf8
+        inf_xml=char_enc(@inf).amp
+        inf_xml=char_enc(inf_xml).utf8
         inf_xml=char_enc(inf_xml).br
         <<WOK
 #{Ax[:tab]}<#{@tag}>
@@ -822,6 +831,20 @@ WOK
       end
       self
     end
+    def html_display
+      def meta_para
+        inf_xml=char_enc(@inf).amp
+        inf_xml=char_enc(inf_xml).utf8
+        inf_xml=char_enc(inf_xml).br
+        %{<p class="norm">
+  <b>#{@tag}</b>: #{inf_xml}
+</p>}
+      end
+      def metadata
+        SiSU_Metadata::Summary.new(@md,true).metadata_base
+      end
+      self
+    end
     def xml_sax
       def meta_para
         inf_xml=char_enc(@inf).utf8
@@ -842,6 +865,7 @@ WOK
     end
     def xml_dom
       def meta_para
+        inf_xml=char_enc(inf_xml).amp
         inf_xml=char_enc(@inf).utf8
         inf_xml=char_enc(inf_xml).br
         <<WOK
@@ -860,6 +884,7 @@ WOK
     end
     def xhtml_scroll
       def meta_para
+        inf_xml=char_enc(inf_xml).amp
         inf_xml=char_enc(@inf).utf8
         inf_xml=char_enc(inf_xml).br
         <<WOK
@@ -893,7 +918,6 @@ WOK
     end
     def odf
       def meta_para
-        url_brace=SiSU_Viz::Defaults.new.url_decoration
         if @inf.is_a?(String)
           @inf=@inf.gsub(/</,'&lt;').gsub(/>/,'&gt;').
             gsub(/&lt;br(?: \/)?&gt;/,'<br />')
@@ -915,13 +939,13 @@ WOK
               '\1<text:a xl:type="simple" xl:href="\2">\2</text:a>') #special case \{ e.g. \}http://url
           @inf=if @inf =~/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/
             @inf.gsub(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,
-              %{#{url_brace.xml_open}<text:a xl:type="simple" xl:href="\\1">\\1</text:a>#{url_brace.xml_close}}) #http ftp matches with decoration
+              %{#{the_url_decoration.xml_open}<text:a xl:type="simple" xl:href="\\1">\\1</text:a>#{the_url_decoration.xml_close}}) #http ftp matches with decoration
           else
             @inf.gsub(/(https?:\/\/[^<>()'"\s]+)/,
-              %{#{url_brace.xml_open}<text:a xl:type="simple" xl:href="\\1">\\1</text:a>#{url_brace.xml_close}}) #http ftp matches with decoration
+              %{#{the_url_decoration.xml_open}<text:a xl:type="simple" xl:href="\\1">\\1</text:a>#{the_url_decoration.xml_close}}) #http ftp matches with decoration
           end
           @inf=@inf.gsub(/([a-zA-Z0-9._-]+@[a-zA-Z0-9._-]+)/,
-            %{#{url_brace.xml_open}<text:a xl:type="simple" xl:href="mailto:\\1">\\1</text:a>#{url_brace.xml_close}}) if @inf !~/http:\/\// # improve upon, document crash where url contains '@' symbol
+            %{#{the_url_decoration.xml_open}<text:a xl:type="simple" xl:href="mailto:\\1">\\1</text:a>#{the_url_decoration.xml_close}}) if @inf !~/http:\/\// # improve upon, document crash where url contains '@' symbol
         end
         <<WOK
 <text:p text:style-name="P1">#{@tag.capitalize}: #{@inf}</text:p>
