@@ -46,24 +46,21 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/sitemaps.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/sitemaps.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
    <ralph.amissah@gmail.com>
 
- ** Description: sitemap created from parameters extracted from input file(s)
+ ** Description: sitemap created from document parameters
 
 =end
 module SiSU_Sitemaps
-  require_relative 'param'                              # param.rb
+  require_relative 'dp'                                 # dp.rb
     include SiSU_Param
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   require_relative 'xml_shared'                         # xml_shared.rb
     include SiSU_XML_Munge
@@ -86,9 +83,10 @@ module SiSU_Sitemaps
 #         @file=SiSU_Env::FileOp.new(@md)
           @rdf=SiSU_XML_Tags::RDF.new(@md)
           @fnb_utf8_xml=@md.fnb.dup
-          @trans.char_enc.utf8(@fnb_utf8_xml) if @sys.locale =~/utf-?8/i #% utf8
+          @trans.char_enc.utf8(@fnb_utf8_xml) \
+            if @sys.locale =~/utf-?8/i
           output_map(sitemap)
-        elsif @opt.mod.inspect =~/--sitemaps/
+        elsif @opt.selections.str =~/--sitemaps/
           @sitemap_idx_fn='sitemapindex.xml'
           @env=SiSU_Env::InfoEnv.new
           output_idx(sitemap_index)
@@ -144,7 +142,8 @@ module SiSU_Sitemaps
 WOK
       sitemap_files.each do |s|
         f=s.gsub(/.+?\/sitemap_([^\/]+?)\.xml$/,'\1')
-        @trans.char_enc.utf8(f) if @sys.locale =~/utf-?8/i #% utf8
+        @trans.char_enc.utf8(f) \
+          if @sys.locale =~/utf-?8/i
 sitemap_idx << <<WOK
   <sitemap>
     <loc>#{@env.path.url.remote}/#{f}/sitemap.xml</loc>
