@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/src_shared.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/src_shared.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -63,8 +60,8 @@
 module SiSU_Source
   include SiSU_Env
   class SiSUpodSource
-    require_relative 'sysenv'                           # sysenv.rb
-    require_relative 'particulars'                      # particulars.rb
+    require_relative 'se'                               # se.rb
+    require_relative 'se_hub_particulars'               # se_hub_particulars.rb
     def initialize(opt,build=nil,place=nil)
       @opt=opt
       @date=SiSU_Env::InfoDate.new.dt
