@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/src_sisupod_make.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/src_sisupod_make.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -63,10 +60,10 @@
 module SiSU_Doc
   require_relative 'src_shared'                         # scr_shared.rb
     include SiSU_Source
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   class Source < SiSU_Source::SiSUpodSource
-    require_relative 'response'                         # response.rb
+    require_relative 'utils_response'                   # utils_response.rb
     def initialize(opt,build=nil,place=nil)
       super(opt,build,place)
       @zipfile=@opt.fno.gsub(/(?:\~\S{2,3})?(\.ss[tm])$/,'\1')
