@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/sst_convert_markup.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/sst_convert_markup.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -65,7 +62,7 @@
 module SiSU_Modify
   require_relative 'sst_identify_markup'                # sst_identify_markup.rb
   require_relative 'sst_from_xml'                       # sst_from_xml.rb
-  require_relative 'response'                           # response.rb
+  require_relative 'utils_response'                     # utils_response.rb
   class ConvertMarkup
     def initialize(opt)
       @opt=opt
@@ -201,22 +198,22 @@ WOK
       and @opt.files.length > 0
         mr=nil
         #%% changes to make m match, r replace      -------------------------->
-        if @opt.mod.inspect =~/--help/ then help
-        elsif @opt.mod.inspect =~/(?:convert|to)[=-](?:xml |sxs|sax|sxd|dom|sxn|node)/
-          ext=case @opt.mod.inspect
+        if @opt.selections.str =~/--help/ then help
+        elsif @opt.selections.str =~/(?:convert|to)[=-](?:xml |sxs|sax|sxd|dom|sxn|node)/
+          ext=case @opt.selections.str
           when /(?:convert|to)[=-](?:xml|sxs|sax)/ then '.sxs.xml'
           when /(?:convert|to)[=-](?:sxd|dom)/     then '.sxd.xml'
           when /(?:convert|to)[=-](?:sxn|node)/    then '.sxn.xml'
           end
           message("#{@opt.files.inspect}\n\nWARNING, PROCEED AT YOUR OWN RISK,\noverwriting any equivalent file with the extension #{ext}")
-          mr=case @opt.mod.inspect
+          mr=case @opt.selections.str
           when /(?:convert|to)[=-](?:sxs|sax|xml )/ then convert_to_simple_xml_model_sax
           when /(?:convert|to)[=-](?:sxd|dom)/      then convert_to_simple_xml_model_dom
           when /(?:convert|to)[=-](?:sxn|node)/     then convert_to_simple_xml_model_node
           else help
           end
         else
-          mr=case @opt.mod.inspect
+          mr=case @opt.selections.str
           when /(?:(?:37)?to-?38|--(?:convert|to)[=-](?:current|0.38))/           then convert_37_to_38
           when /(?:(?:38)?to-?37|--(?:convert|to)[=-](?:0.37))/                   then convert_38_to_37
           when /(?:36to37)/                                                       then convert_filename_36_to_37
@@ -227,7 +224,7 @@ WOK
           else help
           end
         end
-        unless @opt.mod.inspect =~/kdi/
+        unless @opt.selections.str =~/kdi/
           match_and_replace=mr
           #start_processing =/not used in this example/i
           end_processing =/END\s+OF\s+FILE/
@@ -236,8 +233,8 @@ WOK
             @new,@matched,@flag_start,@flag_end,@empty1,@empty2=true,false,false,false,false,false
             o="#{i}.bk" #o is for old
             markup_version=SiSU_Markup::MarkupIdentify.new(@opt).markup_version?
-            if (@opt.mod.inspect=~/37/ and markup_version=~/0.38/) \
-            or (@opt.mod.inspect=~/current|38/ and markup_version=~/0.37/)
+            if (@opt.selections.str=~/37/ and markup_version=~/0.38/) \
+            or (@opt.selections.str=~/current|38/ and markup_version=~/0.37/)
               puts "#{i} #{markup_version}"
               file=File.open(i,'r')
               cont=file.readlines
@@ -300,7 +297,7 @@ WOK
               if (@opt.act[:verbose][:set]==:on \
               || @opt.act[:verbose_plus][:set]==:on \
               || @opt.act[:maintenance][:set]==:on)
-                puts "Requested conversion #{@opt.mod.inspect} markup #{markup_version} identified in #{i}"
+                puts "Requested conversion #{@opt.selections.str} markup #{markup_version} identified in #{i}"
               end
             end
           end
@@ -311,11 +308,11 @@ WOK
   end
 end
 #%% files to match for this conversion set  ------------------------->
-require_relative 'options'                              # options.rb
+require_relative 'hub_options'                          # hub_options.rb
 argv=$*
 base_path=Dir.pwd
 @opt=SiSU_Commandline::Options.new(argv,base_path)
-case @opt.mod.inspect
+case @opt.selections.str
 when /=kdi/
   SiSU_Modify::ConvertMarkup.new(@opt).conversion
 when /(?:36|37|38)?to-?(?:37|38)|--convert|--to|--from|default/
@@ -324,7 +321,7 @@ when /(?:36|37|38)?to-?(?:37|38)|--convert|--to|--from|default/
   SiSU_Modify::ConvertMarkup.new(@opt).conversion
 end
 else
-  @opt.mod='--help'
+  @opt.selections.str='--help'
  SiSU_Modify::ConvertMarkup.new(@opt).help
 end
 __END__
