@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/txt_shared.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/txt_shared.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,6 +58,7 @@
 
 =end
 module SiSU_TextUtils
+  require_relative 'generic_parts'                      # generic_parts.rb
   class Wrap
     def initialize(para='',n_char_max=76,n_indent=0,n_hang=nil,post='')
       @para,@n_char_max,@n_indent,@post,=para,n_char_max,n_indent,post
