@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/utils.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/utils.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -130,7 +127,10 @@ module SiSU_Utils
     def set(v=nil,x=nil)
       v=var(v,x)
       file,path=File.basename(@file),File.dirname(@file)
-      v[:c][:on] + @line + v[:c][:off] + ' ' + path + '/' "#{v[:c][:on]}#{file}#{v[:c][:off]}" + v[:m]
+      v[:c][:on] + @line + v[:c][:off] + ' ' \
+      + path + '/' \
+      + "#{v[:c][:on]}#{file}#{v[:c][:off]}" \
+      + v[:m]
     end
     def mark(v=nil,x=nil)
       puts set(v,x)
@@ -150,9 +150,9 @@ module SiSU_Utils
     def warn(v=nil,x=nil)
       if (v.is_a?(Symbol) \
       and x.is_a?(String))
-        x= '*WARN* ' + x
+        x="\n  " + '*WARN* ' + x
       elsif v.is_a?(String)
-        v='*WARN* ' + v
+        v="\n  " + '*WARN* ' + v
         x=nil
       else
         v,x='*WARN*',nil
@@ -162,9 +162,9 @@ module SiSU_Utils
     def error(v=nil,x=nil)
       if (v.is_a?(Symbol) \
       and x.is_a?(String))
-        x= '*ERROR* ' + x
+        x="\n  " + '*ERROR* ' + x
       elsif v.is_a?(String)
-        v='*ERROR* ' + v
+        v="\n  " + '*ERROR* ' + v
         x=nil
       else
         v,x='*ERROR*',nil
