@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/wikispeak.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/wikispeak.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -62,12 +59,12 @@
 =end
 module SiSU_Wikispeak
   require_relative 'ao'                                 # ao.rb
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   include SiSU_Param
-  include SiSU_Viz
   require_relative 'plaintext_format'                   # plaintext_format.rb
     include Format
+  require_relative 'html_parts'                         # html_parts.rb
   require_relative 'txt_shared'
   @@alt_id_count,@@alt_id_count,@@tablehead,@@number_of_cols=0,0,0,0
   @@tablefoot=''
@@ -102,7 +99,7 @@ module SiSU_Wikispeak
         @ao_array=SiSU_AO::Source.new(@opt).get # ao file drawn here
         SiSU_Wikispeak::Source::Scroll.new(@ao_array,@md).songsheet
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -112,7 +109,6 @@ module SiSU_Wikispeak
     class SplitTextObject <Source
       require_relative 'plaintext_format'               # plaintext_format.rb
         include Format
-      include SiSU_Viz
       @@alt_id_count=0
       @@dp=nil
       attr_reader :format,:lev,:text,:ocn,:lev_para_ocn
@@ -158,14 +154,13 @@ module SiSU_Wikispeak
       end
     end
     class Scroll <Source
-      require_relative 'txt_shared'                     # txt_shared.rb
-        include SiSU_TextUtils
+      include SiSU_TextUtils
+      include SiSU_Parts_HTML
       @@endnotes_para=[]
       @@wiki={ body: [], open: [], close: [], head: [], metadata: [], tail: [], endnotes: [] }
       @@dp=nil
       def initialize(data,md)
         @data,@md=data,md
-        @vz=SiSU_Viz::Defaults.new
         @dp=@@dp ||=SiSU_Env::InfoEnv.new.digest.pattern
         @regx=/^(?:(?:#{Mx[:br_line]}\s*|#{Mx[:br_nl]}\s*)?#{Mx[:lv_o]}\d:(\S*?)#{Mx[:lv_c]}\s*)?(.+)/ #fix Mx[:lv_o] #m # 2004w18 pb pn removal added
         @tab="\t"
@@ -192,7 +187,6 @@ WOK
         end
       end
       def wiki_tail
-        vz=SiSU_Viz::Defaults.new
         generator="Generated by: #{@md.sisu_version[:project]} #{@md.sisu_version[:version]} of #{@md.sisu_version[:date_stamp]} (#{@md.sisu_version[:date]})"  if @md.sisu_version[:version]
         lastdone="Last Generated on: #{Time.now}"
         rubyv="Ruby version: #{@md.ruby_version}"
@@ -336,7 +330,7 @@ WOK
                 para=format_text.scr_indent_one_no_paranum
               end
             end
-            if para !~/#{@vz.margin_txt_0}|#{@vz.margin_txt_1}|#{@vz.margin_txt_2}/
+            if para !~/#{the_margin.txt_0}|#{the_margin.txt_1}|#{the_margin.txt_2}/
               # i don't get the condition for no paranum
             end
             if para =~/<:center>/
