@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/epub_concordance.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/epub_concordance.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -62,12 +59,11 @@
 
 =end
 module SiSU_XHTML_EPUB2_Concordance
-  require_relative 'particulars'                        # particulars.rb
+  require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
-  require_relative 'defaults'                           # defaults.rb
-    include SiSU_Viz
+  require_relative 'xhtml_parts'                        # xhtml_parts.rb
   require_relative 'xhtml_epub2_format'                 # xhtml_epub2_format.rb
     include SiSU_XHTML_EPUB2_Format
   class Source
@@ -96,7 +92,7 @@ module SiSU_XHTML_EPUB2_Concordance
           SiSU_XHTML_EPUB2_Concordance::Source::Words.new(@particulars).songsheet
         end
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -104,13 +100,11 @@ module SiSU_XHTML_EPUB2_Concordance
     end
     private
     class DocTitle
-      include SiSU_Viz
       #revisit, both requires (html & xml_shared) needed for stand alone operation (sisu -w [filename])
       require_relative 'xhtml_epub2'                    # xhtml_epub2.rb
       def initialize(particulars)
         @particulars,@md=particulars,particulars.md
         @data=SiSU_XHTML_EPUB2::Source::XHTML_Environment.new(particulars).tuned_file_instructions
-        @vz=SiSU_Viz::Defaults.new
         @fnb=@md.fnb
         @lex_button=%{<a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" height="44" width="144" valign="center" src="../_sisu/image/sisu.png" alt="SiSU home"></a>}
         @doc_details =<<WOK
@@ -153,16 +147,13 @@ WOK
       end
     end
     class Words
-      require_relative 'defaults'                       # defaults.rb
-        include SiSU_Viz
       require_relative 'xhtml_epub2_format'             # xhtml_epub2_format.rb
         include SiSU_XHTML_EPUB2_Format
-      require_relative 'sysenv'                         # sysenv.rb
+      require_relative 'se'                             # se.rb
         include SiSU_Screen
       def initialize(particulars)
         @particulars=particulars
         begin
-          @vz=SiSU_Viz::Defaults.new
           @env,@md,@ao_array=particulars.env,particulars.md,particulars.ao_array
           @path="#{@env.processing_path.epub}"
           @freq=Hash.new(0)
@@ -181,7 +172,7 @@ WOK
           @rgx_splitlist=%r{[—.,;:-]+|#{Mx[:nbsp]}+}mi
           @rgx_scanlist=%r{#{Mx[:fa_italics_o]}[a-zA-Z0-9"\s]{2,12}#{Mx[:fa_italics_c]}|#{Mx[:fa_bold_o]}[a-zA-Z0-9"\s]{2,12}#{Mx[:fa_bold_c]}|#{Mx[:url_o]}https?://\S+?#{Mx[:url_c]}|file://\S+|<\S+?>|\w+|[a-zA-Z]+}mi
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         end
@@ -195,7 +186,7 @@ WOK
           @file_concordance=File.open("#{@path}/content/#{@md.fn[:epub_concord]}",'w')
           map_para
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         ensure
@@ -326,7 +317,7 @@ WOK
           end
           # special cases endnotes and header levels 1 - 3
         end
-        credits=@vz.credits_sisu_epub
+        credits=SiSU_Proj_XHTML::Bits.new.credits_sisu_epub
         @file_concordance << %{</div>>#{credits}</body>\n</html>} # footer
       end
     end
