@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/epub_format.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/epub_format.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,7 +58,6 @@
 
 =end
 module SiSU_XHTML_EPUB2_Format
-  include SiSU_Viz
   class ParagraphNumber
     def initialize(md,ocn)
       @md,@ocn=md,ocn.to_s
@@ -162,7 +158,7 @@ module SiSU_XHTML_EPUB2_Format
     padding-left: 0em;
     text-indent: 0mm;
   }
-  p, h0, h1, h2, h3, h4, h5, h6 {
+  p, h0, h1, h2, h3, h4, h5, h6, h7 {
     display: block;
     font-family: verdana, arial, georgia, tahoma, sans-serif, helvetica, times, roman;
     font-size: 100%;
@@ -992,18 +988,18 @@ module SiSU_XHTML_EPUB2_Format
     font-weight: bold;
   }
 
-  h0, h1, h2, h3, h4, h5, h6 {
+  h0, h1, h2, h3, h4, h5, h6, h7 {
     font-weight: bold;
     line-height: 120%;
     text-align: left;
     margin-top: 20px;
     margin-bottom: 10px;
   }
-  h4.norm, h5.norm, h6.norm {
+  h4.norm, h5.norm, h6.norm, h7.norm {
     margin-top: 10px;
     margin-bottom: 0px;
   }
-  h1.center, h2.center, h3.center, h4.center, h5.center, h6.center {
+  h1.center, h2.center, h3.center, h4.center, h5.center, h6.center, h7.center {
     text-align: center;
   }
   h1 { font-size: 120%; }
@@ -1012,6 +1008,7 @@ module SiSU_XHTML_EPUB2_Format
   h4 { font-size: 105%; }
   h5 { font-size: 100%; }
   h6 { font-size: 100%; }
+  h7 { font-size: 100%; }
   h0 { font-size: 80%; }
 
   h1.i {margin-left: 2em;}
@@ -1059,6 +1056,11 @@ module SiSU_XHTML_EPUB2_Format
     font-size: 90%;
     line-height: 110%;
   }
+  h7.toc {
+    margin-left: 7em;
+    font-size: 90%;
+    line-height: 105%;
+  }
 
   .microtoc {
     margin-top: 2px;
@@ -1092,6 +1094,11 @@ module SiSU_XHTML_EPUB2_Format
     font-weight: normal;
     font-size: 90%;
   }
+  h7.microtoc {
+    margin-left: 30mm;
+    font-weight: normal;
+    font-size: 85%;
+  }
 
   .subtoc {
     margin-right: 34%;
@@ -1109,6 +1116,12 @@ module SiSU_XHTML_EPUB2_Format
     margin-top: 0px;
     margin-bottom: 0px;
   }
+  h7.subtoc {
+    margin-left: 4em;
+    font-size: 70%;
+    margin-top: 0px;
+    margin-bottom: 0px;
+  }
 
   div.substance {
     width: 100%;
@@ -1196,10 +1209,10 @@ module SiSU_XHTML_EPUB2_Format
     background-color: #f9f9aa;
   }
 
-  h1.c, h2.c, h3.c, h4.c, h5.c, h6.c, p.c {
+  h1.c, h2.c, h3.c, h4.c, h5.c, h6.c, h7.c, p.c {
     text-align: center
   }
-  h1.red, h2.red, h3.red, h4.red, h5.red, h6.red {
+  h1.red, h2.red, h3.red, h4.red, h5.red, h6.red, h7.red {
     text-align: center;
     color: #ff0000;
     margin-left: 5mm;
@@ -1208,7 +1221,7 @@ module SiSU_XHTML_EPUB2_Format
     margin-bottom: 20px;
     margin-right: 15mm;
   }
-  h1.ruby, h2.ruby, h3.ruby, h4.ruby, h5.ruby, h6.ruby {
+  h1.ruby, h2.ruby, h3.ruby, h4.ruby, h5.ruby, h6.ruby, h7.ruby {
     text-align: center;
     color: #990000;
     margin-left: 5mm;
@@ -1221,6 +1234,7 @@ module SiSU_XHTML_EPUB2_Format
     end
   end
   module SanitizeXML
+    require_relative 'xhtml_parts'                        # xhtml_parts.rb
     def self.xml(x)
       if x.is_a?(String)
         x=x.gsub(/&nbsp;/,' ') if Ep[:alt]==:on
@@ -1235,12 +1249,10 @@ module SiSU_XHTML_EPUB2_Format
     end
   end
   class HeadInformation
-    include SiSU_Viz
-    attr_reader :md,:rdf,:vz
+    attr_reader :md,:rdf
     def initialize(md)
       @md=md
       # DublinCore 1 - title
-      @vz=SiSU_Viz::Defaults.new
       @css=SiSU_Env::CSS_Stylesheet.new(md)
       @seg_name_xhtml=(SiSU_XHTML_EPUB2::Source::Seg.new.seg_name_xhtml || [])
       @seg_name_xhtml_tracker=(SiSU_XHTML_EPUB2::Source::Seg.new.seg_name_xhtml_tracker || [])
@@ -1316,7 +1328,7 @@ application/epub+zip
     <meta http-equiv='Content-Type' content='text/html; charset=utf-8' />
     #{@css.xhtml_epub}
   </head>
-  #{@vz.color_body}
+    <body lang="#{@md.opt.lng}">
     <div class="content">
       <div class="substance">
         <label class="ocn"><a href="#o#{dob.ocn}" class="lnkocn">#{dob.ocn}</a></label>
@@ -1708,15 +1720,16 @@ output_epub_cont_seg.close
     end
     def table_close
       %{  </font>
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def xhtml_close
-    %{#{@vz.credits_sisu_epub}
+    %{#{SiSU_Proj_XHTML::Bits.new.credits_sisu_epub}
   </body>
 </html>}
     end
   end
   class HeadToc < HeadInformation
+    include SiSU_Parts_XHTML
     def initialize(md)
       super(md)
       @md=md
@@ -1739,20 +1752,20 @@ output_epub_cont_seg.close
     <meta http-equiv='Content-Type' content='text/html; charset=utf-8' />
     #{@css.xhtml_epub}
   </head>
-  #{@vz.color_body}}
+    <body lang="#{@md.opt.lng}">}
     end
     def concordance
       if @md.concord_make
-      %{#{@vz.margin_css}
+      %{#{the_margin.css}
       <h4 class="toc">
         <a href="./#{@md.file.base_filename.html_concordance}">
           <i>Concordance</i>
         </a>
       </h4>
-#{@vz.table_close}}
+#{the_table_close}}
       else
-      %{#{@vz.margin_css}
-#{@vz.table_close}}
+      %{#{the_margin.css}
+#{the_table_close}}
       end
     end
     def links_guide_open(type='horizontal')
@@ -1773,40 +1786,40 @@ output_epub_cont_seg.close
       %{<p class="small_left">Prefix: #{@md.prefix_b}}
     end
     def make_seg
-      concord=concordance_link(@vz.nav_txt_concordance)
+      concord=concordance_link(the_nav.txt_concordance)
       %{<table summary="toc segment" border="0" cellpadding="3" cellspacing="0">
 <tr><td align="center" bgcolor="white">
-  #{@vz.nav_txt_toc_link}
+  #{the_nav.txt_toc_link}
 </td>
 <td align="center" bgcolor="white">
   <font size=2>
    #{concord}
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def manifest #check structure
-      manifest=manifest_link(@vz.nav_txt_manifest)
-      %{#{@vz.margin_txt_3}
-  #{@vz.paragraph_font_small}
+      manifest=manifest_link(the_nav.txt_manifest)
+      %{#{the_margin.txt_3}
+  #{the_font.paragraph_font_small}
    #{manifest}
     </font>
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def concordance #check structure
-      concord=concordance_link(@vz.nav_txt_concordance)
-      %{#{@vz.margin_txt_3}
-  #{@vz.paragraph_font_small}
+      concord=concordance_link(the_nav.txt_concordance)
+      %{#{the_margin.txt_3}
+  #{the_font.paragraph_font_small}
    #{concord}
     </font>
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def metadata
-      %{#{@vz.margin_css}
+      %{#{the_margin.css}
   <h4 class="toc">
     <a href="#{@metalink}">
       <i>MetaData</i>
     </a>
   </h4>
-#{@vz.table_close}}
+#{the_table_close}}
     end
   end
   class HeadSeg < HeadInformation
@@ -1823,7 +1836,7 @@ output_epub_cont_seg.close
     <meta http-equiv='Content-Type' content='text/html; charset=utf-8' />
     #{@css.xhtml_epub}
   </head>
-  #{@vz.color_body}}
+    <body lang="#{@md.opt.lng}">}
     end
     def endnote_mark
 %{
@@ -1836,8 +1849,8 @@ output_epub_cont_seg.close
       super(md)
     end
     def toc_owner_details
-      %{#{@vz.margin_txt_3}
-#{@vz.paragraph_font_small}
+      %{#{the_margin.txt_3}
+#{the_font.paragraph_font_small}
   <a href="#owner.details">
     Owner Details
     <font size="1" color="#777777">
@@ -1845,11 +1858,11 @@ output_epub_cont_seg.close
     </font>
   </a>
   </font>
-#{@vz.table_close}}
+#{the_table_close}}
     end
   end
   class FormatTextObject
-    @vz=SiSU_Viz::Defaults.new
+    include SiSU_Parts_XHTML
     attr_accessor :md,:t_o,:txt,:ocn,:format,:table,:link,:linkname,:paranum,:p_num,:headname,:banner,:url
     def initialize(md,t_o)
       @md,@t_o=md,t_o
@@ -1893,7 +1906,6 @@ output_epub_cont_seg.close
         @txt=@txt.gsub(/#{Mx[:mk_o]}[-~]##{Mx[:mk_c]}/,'')
       end
       @p_num=ParagraphNumber.new(@md,@ocn)
-      @vz=SiSU_Viz::Defaults.new
     end
     def nametags_seg(dob) #FIX
       tags=''
@@ -2043,6 +2055,9 @@ output_epub_cont_seg.close
     def seg_heading6
       seg_heading_sub('p','bold',@txt)
     end
+    def seg_heading7
+      seg_heading_sub('p','bold',@txt)
+    end
     def dl #check :trailer
       "<dl><b>#{@txt}</b> #{@trailer}</dl>"
     end
@@ -2067,13 +2082,13 @@ output_epub_cont_seg.close
       end
     end
     def bold_para
-      %{#{@vz.margin_txt_0}
+      %{#{the_margin.txt_0}
   <p class="bold">
     #{@txt}
   </p>
-#{@vz.margin_num_css}
+#{the_margin.num_css}
   #{$ep[:hsp]*3}
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def bold_heading #unused
       @txt=@txt.gsub(/[1-9]~\S+/,'').
@@ -2081,9 +2096,9 @@ output_epub_cont_seg.close
       %{<p class="bold">
     #{@txt}
   </p>
-#{@vz.margin_num_css}
+#{the_margin.num_css}
   #{$ep[:hsp]*3}
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def toc_head_copy_at
       @txt=SanitizeXML.xml(@txt)
@@ -2105,7 +2120,6 @@ output_epub_cont_seg.close
   class FormatScroll < FormatTextObject
     def initialize(md,txt)
       super(md,txt)
-      @vz=SiSU_Viz::Defaults.new
     end
   end
   class FormatSeg < FormatTextObject
@@ -2149,6 +2163,9 @@ output_epub_cont_seg.close
     def subtoc_lev6
       subtoc_lev('h6','subtoc') if @txt
     end
+    def subtoc_lev7
+      subtoc_lev('h7','subtoc') if @txt
+    end
     def heading_sub(tag,attrib,txt)
       txt=txt.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
       %{
@@ -2177,13 +2194,16 @@ output_epub_cont_seg.close
     def heading6
       heading_sub('p','bold',@txt)
     end
+    def heading7
+      heading_sub('h7','bold',@txt)
+    end
     def navigation_heading4
       %{<table summary="navigation segment heading 4" width=100% bgcolor="#08163f" border="0">
 <tr><td align="center">
 <p class="bold">
   #{@txt}
 </p>
-#{@vz.table_close}}
+#{the_table_close}}
     end
     def navigation_heading5
       %{<p class="bold">
@@ -2193,6 +2213,11 @@ output_epub_cont_seg.close
     def navigation_heading6
       %{<p class="bold">
   #{@txt}
+</p>}
+    end
+    def navigation_heading7
+      %{<p class="bold">
+  #{@txt}
 </p>}
     end
     def navigation_center
@@ -2238,6 +2263,9 @@ output_epub_cont_seg.close
     def lev6
       lev('h6','toc')
     end
+    def lev7
+      lev('h7','toc')
+    end
     def lev0 #docinfo
       lev('h0','toc')
     end
