@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/epub_tune.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/epub_tune.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -60,10 +57,11 @@
  ** Description: epub generation, epub pre-processing
 
 =end
-require_relative 'param'
+require_relative 'dp'                                   # dp.rb
 module SiSU_XHTML_EPUB2_Tune
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env; include SiSU_Screen
+  require_relative 'xhtml_parts'                        # xhtml_parts.rb
   require_relative 'xhtml_epub2_format'                 # xhtml_epub2_format.rb #watch
   @@line_mode=''
   @@endnote_array=[]
@@ -80,7 +78,7 @@ module SiSU_XHTML_EPUB2_Tune
   class Output
     def initialize(data,md)
       @data,@md=data,md
-      @file=SiSU_Env::FileOp.new(@md)
+      @file=SiSU_Env::InfoFile.new(@md.fns)
       @cX=SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set]).cX
     end
     def hard_output
@@ -92,7 +90,7 @@ module SiSU_XHTML_EPUB2_Tune
       end
     end
     def marshal
-      File.open(@file.marshal.html_tune,'w') {|f| Marshal.dump(@data.to_a,f)}
+      File.open(@file.marshal.xhtml_tune,'w') {|f| Marshal.dump(@data.to_a,f)}
     end
   end
   class CleanXHTML
@@ -112,13 +110,11 @@ module SiSU_XHTML_EPUB2_Tune
     end
   end
   class Tune
+    include SiSU_Parts_XHTML
     def initialize(data,md)
       @data,@md=data,md
-      @vz=SiSU_Viz::Defaults.new
-      @env=SiSU_Env::InfoEnv.new(@md.fns)
       @sys=SiSU_Env::SystemCall.new
       @env=SiSU_Env::InfoEnv.new(@md.fns)
-      @brace_url=SiSU_Viz::Defaults.new.url_decoration
     end
     def songsheet
       begin
@@ -141,7 +137,7 @@ module SiSU_XHTML_EPUB2_Tune
         end
         SiSU_XHTML_EPUB2_Tune::Tune.new(@data,@md).output
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -265,18 +261,18 @@ module SiSU_XHTML_EPUB2_Tune
             dob.obj.gsub(/\<:ad\s+(\S+)?\s+(\S+\.png)\s+(.+)?\;\s+(.+)?\;\s*\>/,
               %{\n<center><a href="\\1" target="_top"><img src="#{@env.url.images_epub}/\\2" alt="\\3" /></a></center>\n})
           end
-          dob.obj=dob.obj.gsub(/!pick/,%{<img border="0" height="15" width="15" src="#{@env.url.images_epub}/#{@vz.icon_choice}" alt="stellar" />}).
-            gsub(/!new/,%{#{$ep[:hsp]}<img border="0" height="15" width="15" src="#{@env.url.images_epub}/#{@vz.icon_new}" alt="new" />}).
+          dob.obj=dob.obj.gsub(/!pick/,%{<img border="0" height="15" width="15" src="#{@env.url.images_epub}/#{the_icon.i_choice}" alt="stellar" />}).
+            gsub(/!new/,%{#{$ep[:hsp]}<img border="0" height="15" width="15" src="#{@env.url.images_epub}/#{the_icon.i_new}" alt="new" />}).
             gsub(/<:h(.{1,7}?)>/,'<a href="#h\1">\1</a>').
             gsub(/<:to(\d{1,7}?)>/,%{<a href="#to\\1">to#{$ep[:hsp]}\{#{$ep[:hsp]}\\1#{$ep[:hsp]}\}</a> }).
             gsub(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'<a href="\1" target="_top">\1</a>'). #http ftp matches escaped, no decoration
-            gsub(/#{Mx[:url_o]}([a-zA-Z0-9._-]+\@\S+?\.[a-zA-Z0-9._-]+)#{Mx[:url_c]}/,%{#{@brace_url.xml_open}<a href="mailto:\\1">\\1</a>#{@brace_url.xml_close}}).
-            gsub(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,%{#{@brace_url.xml_open}<a href="\\1" target="_top">\\1</a>#{@brace_url.xml_close}}) #http ftp matches with decoration
+            gsub(/#{Mx[:url_o]}([a-zA-Z0-9._-]+\@\S+?\.[a-zA-Z0-9._-]+)#{Mx[:url_c]}/,%{#{the_url_decoration.xml_open}<a href="mailto:\\1">\\1</a>#{the_url_decoration.xml_close}}).
+            gsub(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,%{#{the_url_decoration.xml_open}<a href="\\1" target="_top">\\1</a>#{the_url_decoration.xml_close}}) #http ftp matches with decoration
           if dob.obj =~/..\/\S+/ \
           and dob.obj !~/(\"..\/\S+?\"|>\s*..\/\S+<)/
             dob.obj=dob.obj.gsub(/(\.\.\/\S+)/,'<a href="\1">\1</a>')
           end
-          dob.obj=dob.obj.gsub(/<a href="\.\.\//,%{<a href="#{@vz.url_site}/})
+          dob.obj=dob.obj.gsub(/<a href="\.\.\//,%{<a href="#{the_url.site}/})
         else
           dob.obj=dob.obj.gsub(/</m,'&lt;').gsub(/>/m,'&gt;')
         end
