@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/xml.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/xml.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,11 +58,9 @@
 
 =end
 module SiSU_XML_SAX
-  require_relative 'defaults'                           # defaults.rb
-    include SiSU_Viz
-  require_relative 'particulars'                        # particulars.rb
+  require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   require_relative 'xml_shared'                         # xml_shared.rb
     include SiSU_XML_Munge
@@ -83,13 +78,24 @@ module SiSU_XML_SAX
     end
     def read
       begin
-        @env,@md,@ao_array=@particulars.env,@particulars.md,@particulars.ao_array
+        @env,              @md,            @ao_arr=
+          @particulars.env,@particulars.md,@particulars.ao_array
         unless @opt.act[:quiet][:set]==:on
           tool=if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
-            "#{@env.program.web_browser} file://#{@md.file.output_path.xml_sax.dir}/#{@md.file.base_filename.xml_sax}\n\t#{@env.program.xml_viewer} file://#{@md.file.output_path.xml_sax.dir}/#{@md.file.base_filename.xml_sax}"
+            @env.program.web_browser \
+            + ' file://' \
+            + @md.file.output_path.xml_sax.dir + '/' \
+            + @md.file.base_filename.xml_sax + "\n\t" \
+            + @env.program.xml_viewer \
+            + ' file://' \
+            + @md.file.output_path.xml_sax.dir + '/' \
+            + @md.file.base_filename.xml_sax
           elsif @opt.act[:verbose][:set]==:on
-            "#{@env.program.web_browser} file://#{@md.file.output_path.xml_sax.dir}/#{@md.file.base_filename.xml_sax}"
+            @env.program.web_browser \
+            + ' file://' \
+            + @md.file.output_path.xml_sax.dir + '/' \
+            + @md.file.base_filename.xml_sax
           else "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
           end
           (@opt.act[:verbose][:set]==:on \
@@ -110,13 +116,15 @@ module SiSU_XML_SAX
             SiSU_Screen::Ansi.new(
               @opt.act[:color_state][:set],
               @opt.fns,
-              "file://#{@md.file.output_path.xml_sax.dir}/#{@md.file.base_filename.xml_sax}"
+              'file://' \
+              + @md.file.output_path.xml_sax.dir + '/' \
+              + @md.file.base_filename.xml_sax
             ).flow
           end
         end
         SiSU_XML_SAX::Source::Songsheet.new(@particulars).song
       rescue
-        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
+        SiSU_Errors::Rescued.new($!,$@,@opt.selections.str,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -128,7 +136,8 @@ module SiSU_XML_SAX
     private
     class Songsheet
       def initialize(particulars)
-        @env,@md,@ao_array,@particulars=particulars.env,particulars.md,particulars.ao_array,particulars
+        @env,             @md,           @ao_arr,             @particulars=
+          particulars.env,particulars.md,particulars.ao_array,particulars
         @file=SiSU_Env::FileOp.new(@md)
       end
       def song
@@ -141,7 +150,7 @@ module SiSU_XML_SAX
           end
           SiSU_Rexml::Rexml.new(@md,@file.place_file.xml_sax.dir).xml if @md.opt.act[:maintenance][:set]==:on # test rexml parsing, comment out when not in use #debug
         rescue
-          SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
+          SiSU_Errors::Rescued.new($!,$@,@md.opt.selections.str,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
           end
         ensure
@@ -155,14 +164,14 @@ module SiSU_XML_SAX
       require_relative 'xhtml_shared'                   # decide use, whether xml rather than xhtml
       @@xml={ body: [], open: [], close: [], head: [] }
       def initialize(particulars)
-        @env,@md,@ao_array=particulars.env,particulars.md,particulars.ao_array
-        @vz=SiSU_Viz::Defaults.new
+        @env,             @md,           @ao_arr=
+          particulars.env,particulars.md,particulars.ao_array
         @trans=SiSU_XML_Munge::Trans.new(@md)
         @sys=SiSU_Env::SystemCall.new
       end
       def songsheet
         pre
-        @data=markup(@ao_array)
+        @data=markup(@ao_arr)
         post
         publish
       end
@@ -302,7 +311,7 @@ WOK
         @@xml[:body] << %{#{Ax[:tab]*1}<text class="verse">#{Ax[:tab]*1}}
         @@xml[:body] << %{#{Ax[:tab]*2}#{dob.obj}#{Ax[:tab]*1}}
         @@xml[:body] << %{#{Ax[:tab]*1}</text>}
-        @@xml[:body] << "#{Ax[:tab]*0}</object>"
+        @@xml[:body] << %{#{Ax[:tab]*0}</object>}
       end
       def code_structure(dob='')
         dob=@trans.markup_group(dob)
@@ -333,8 +342,8 @@ WOK
         @endnotes,@level,@cont,@copen,@xml_contents_close=[],[],[],[],[]
         @rcdc=false
         xml_head
-        (0..6).each { |x| @cont[x]=@level[x]=false }
-        (4..6).each { |x| @xml_contents_close[x]='' }
+        (0..7).each { |x| @cont[x]=@level[x]=false }
+        (4..7).each { |x| @xml_contents_close[x]='' }
         data.each do |dob|
           @trans.char_enc.utf8(dob) if @sys.locale =~/utf-?8/i #% utf8
           dob=@trans.markup(dob)
@@ -361,6 +370,7 @@ WOK
                   when 4 then x.heading_body4
                   when 5 then x.heading_body5
                   when 6 then x.heading_body6
+                  when 7 then x.heading_body7
                   end
                 else
                   if dob.is==:verse
@@ -415,7 +425,7 @@ WOK
             dob.obj=dob.obj.gsub(/#{Mx[:pa_o]}:\S+#{Mx[:pa_c]}/,'') if dob.obj
           end
         end
-        6.downto(4) do |x|
+        7.downto(4) do |x|
           y=x - 1; v=x - 3
           @@xml[:body] << "#{Ax[:tab]*5}</content>\n#{Ax[:tab]*y}</contents#{v}>" if @level[x]==true
         end
@@ -423,14 +433,14 @@ WOK
           y=x - 1
           @@xml[:body] << "#{Ax[:tab]*y}</heading#{x}>" if @level[x]==true
         end
-        #6.downto(1) { |x| y=x - 1; @@xml[:body] << "#{Ax[:tab]*y}</level #{x}>" if @level[x]==true }
+        #7.downto(1) { |x| y=x - 1; @@xml[:body] << "#{Ax[:tab]*y}</level #{x}>" if @level[x]==true }
       end
       def pre
         rdf=SiSU_XML_Tags::RDF.new(@md)
         @@xml[:head],@@xml[:body]=[],[]
         stylesheet=SiSU_Style::CSS_HeadInfo.new(@md,'xml_sax').stylesheet
-        encoding=if @sys.locale =~/utf-?8/i; '<?xml version="1.0" encoding="UTF-8" standalone="no"?>'
-        else                                 '<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>'
+        encoding=if @sys.locale =~/utf-?8/i then '<?xml version="1.0" encoding="UTF-8" standalone="no"?>'
+        else                                     '<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>'
         end
         @@xml[:open] =<<WOK
 #{encoding}
