@@ -46,12 +46,9 @@
    <http://www.jus.uio.no/sisu>
    <http://www.sisudoc.org>
 
- * Download:
-   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
-
  * Git
-   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v6/zap.rb;hb=HEAD>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
+   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v6/zap.rb;hb=HEAD>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -61,7 +58,7 @@
 
 =end
 module SiSU_Zap
-  require_relative 'sysenv'                             # sysenv.rb
+  require_relative 'se'                                 # se.rb
     include SiSU_Env
   class Source
     def initialize(opt)
@@ -75,7 +72,7 @@ module SiSU_Zap
         unless @opt.act[:quiet][:set]==:on
           tell=SiSU_Screen::Ansi.new(
             @opt.act[:color_state][:set],
-            "Clean files related to processing #{@opt.cmd} ->",
+            "Clean files related to processing #{@opt.selections.str} ->",
             "#{@opt.fns} -> #{zap_path}"
           )
           tell.warn
